CREATE SCHEMA [dbo15] AUTHORIZATION [dbo]
GO

CREATE TABLE [dbo15].[KeywordModel](
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [Campaign] [nvarchar](50) NULL,
    [KeywordSet] [nvarchar](50) NULL,
    [Col1] [nvarchar](50) NULL,
    [Col2] [nvarchar](50) NULL,
    [Col3] [nvarchar](50) NULL,
    [Col4] [nvarchar](50) NULL,
    [Col5] [nvarchar](50) NULL,
    [Col6] [nvarchar](50) NULL,
    [Col7] [nvarchar](50) NULL,
 CONSTRAINT [PK_KeywordModel_dbo15] PRIMARY KEY CLUSTERED ([ID] ASC)
)
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     2015-04-13
-- Description: Keywords
-- =============================================

CREATE VIEW [dbo15].[viewModelKeywords]
AS

SELECT
    m.Campaign
    , m.KeywordSet
    , m.Col1
    , m.Col2
    , m.Col3
    , m.Col4
    , m.Col5
    , m.Col6
    , m.Col7
    , LEN(m.Keyword) - LEN(REPLACE(m.Keyword, ' ', '')) + 1  AS [Words]
    , LEN(m.Keyword) AS [Length]
    , m.Keyword
FROM
    (
        SELECT
            m1.Campaign
            , m1.KeywordSet
            , m1.Col1
            , m2.Col2
            , m3.Col3
            , m4.Col4
            , m5.Col5
            , m6.Col6
            , m7.Col7
            , LTRIM(RTRIM(REPLACE(CASE WHEN m1.Col1 = '*' THEN '' ELSE m1.Col1 END
                + CASE WHEN m2.Col2 = '*' THEN '' ELSE ' ' + m2.Col2 END
                + CASE WHEN m3.Col3 = '*' THEN '' ELSE ' ' + m3.Col3 END
                + CASE WHEN m4.Col4 = '*' THEN '' ELSE ' ' + m4.Col4 END
                + CASE WHEN m5.Col5 = '*' THEN '' ELSE ' ' + m5.Col5 END
                + CASE WHEN m6.Col6 = '*' THEN '' ELSE ' ' + m6.Col6 END
                + CASE WHEN m7.Col7 = '*' THEN '' ELSE ' ' + m7.Col7 END
                , '  ', ' '))) AS Keyword
        FROM
            dbo15.KeywordModel m1
            , dbo15.KeywordModel m2
            , dbo15.KeywordModel m3
            , dbo15.KeywordModel m4
            , dbo15.KeywordModel m5
            , dbo15.KeywordModel m6
            , dbo15.KeywordModel m7
        WHERE
            m1.Col1 IS NOT NULL
            AND m2.Col2 IS NOT NULL AND m2.Campaign = m1.Campaign AND m2.KeywordSet = m1.KeywordSet
            AND m3.Col3 IS NOT NULL AND m3.Campaign = m1.Campaign AND m3.KeywordSet = m1.KeywordSet
            AND m4.Col4 IS NOT NULL AND m4.Campaign = m1.Campaign AND m4.KeywordSet = m1.KeywordSet
            AND m5.Col5 IS NOT NULL AND m5.Campaign = m1.Campaign AND m5.KeywordSet = m1.KeywordSet
            AND m6.Col6 IS NOT NULL AND m6.Campaign = m1.Campaign AND m6.KeywordSet = m1.KeywordSet
            AND m7.Col7 IS NOT NULL AND m7.Campaign = m1.Campaign AND m7.KeywordSet = m1.KeywordSet
    ) m


GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     2015-04-13
-- Description: Sorts the KeywordModel table
-- =============================================

CREATE PROCEDURE [dbo15].[uspSortKeywordModel]
AS
BEGIN
    
UPDATE dbo15.KeywordModel
SET
    Col1 = t.Col1
    , Col2 = t.Col2
    , Col3 = t.Col3
    , Col4 = t.Col4
    , Col5 = t.Col5
    , Col6 = t.Col6
    , Col7 = t.Col7
FROM
    dbo15.KeywordModel m
    INNER JOIN (
        SELECT
            m0.ID
            , m1.Col1
            , m2.Col2
            , m3.Col3
            , m4.Col4
            , m5.Col5
            , m6.Col6
            , m7.Col7
        FROM
            (
                SELECT
                    m.Campaign
                    , m.KeywordSet
                    , m.ID
                    , ROW_NUMBER() OVER (PARTITION BY m.Campaign, m.KeywordSet ORDER BY m.ID) AS N
                FROM
                    dbo15.KeywordModel m
            ) m0
            LEFT OUTER JOIN (
                SELECT
                    m.Campaign
                    , m.KeywordSet
                    , m.Col1
                    , ROW_NUMBER() OVER (PARTITION BY m.Campaign, m.KeywordSet ORDER BY m.Col1) AS N
                FROM
                    dbo15.KeywordModel m
                WHERE
                    m.Col1 IS NOT NULL
            ) m1 ON m1.Campaign = m0.Campaign AND m1.KeywordSet = m0.KeywordSet AND m1.N = m0.N
            LEFT OUTER JOIN (
                SELECT
                    m.Campaign
                    , m.KeywordSet
                    , m.Col2
                    , ROW_NUMBER() OVER (PARTITION BY m.Campaign, m.KeywordSet ORDER BY m.Col2) AS N
                FROM
                    dbo15.KeywordModel m
                WHERE
                    m.Col2 IS NOT NULL
            ) m2 ON m2.Campaign = m0.Campaign AND m2.KeywordSet = m0.KeywordSet AND m2.N = m0.N
            LEFT OUTER JOIN (
                SELECT
                    m.Campaign
                    , m.KeywordSet
                    , m.Col3
                    , ROW_NUMBER() OVER (PARTITION BY m.Campaign, m.KeywordSet ORDER BY m.Col3) AS N
                FROM
                    dbo15.KeywordModel m
                WHERE
                    m.Col3 IS NOT NULL
            ) m3 ON m3.Campaign = m0.Campaign AND m3.KeywordSet = m0.KeywordSet AND m3.N = m0.N
            LEFT OUTER JOIN (
                SELECT
                    m.Campaign
                    , m.KeywordSet
                    , m.Col4
                    , ROW_NUMBER() OVER (PARTITION BY m.Campaign, m.KeywordSet ORDER BY m.Col4) AS N
                FROM
                    dbo15.KeywordModel m
                WHERE
                    m.Col4 IS NOT NULL
            ) m4 ON m4.Campaign = m0.Campaign AND m4.KeywordSet = m0.KeywordSet AND m4.N = m0.N
            LEFT OUTER JOIN (
                SELECT
                    m.Campaign
                    , m.KeywordSet
                    , m.Col5
                    , ROW_NUMBER() OVER (PARTITION BY m.Campaign, m.KeywordSet ORDER BY m.Col5) AS N
                FROM
                    dbo15.KeywordModel m
                WHERE
                    m.Col5 IS NOT NULL
            ) m5 ON m5.Campaign = m0.Campaign AND m5.KeywordSet = m0.KeywordSet AND m5.N = m0.N
            LEFT OUTER JOIN (
                SELECT
                    m.Campaign
                    , m.KeywordSet
                    , m.Col6
                    , ROW_NUMBER() OVER (PARTITION BY m.Campaign, m.KeywordSet ORDER BY m.Col6) AS N
                FROM
                    dbo15.KeywordModel m
                WHERE
                    m.Col6 IS NOT NULL
            ) m6 ON m6.Campaign = m0.Campaign AND m6.KeywordSet = m0.KeywordSet AND m6.N = m0.N
            LEFT OUTER JOIN (
                SELECT
                    m.Campaign
                    , m.KeywordSet
                    , m.Col7
                    , ROW_NUMBER() OVER (PARTITION BY m.Campaign, m.KeywordSet ORDER BY m.Col7) AS N
                FROM
                    dbo15.KeywordModel m
                WHERE
                    m.Col7 IS NOT NULL
            ) m7 ON m7.Campaign = m0.Campaign AND m7.KeywordSet = m0.KeywordSet AND m7.N = m0.N
    ) t ON t.ID = m.ID
WHERE
    NOT (
            COALESCE(m.Col1, '') = COALESCE(t.Col1, '')
        AND COALESCE(m.Col2, '') = COALESCE(t.Col2, '')
        AND COALESCE(m.Col3, '') = COALESCE(t.Col3, '')
        AND COALESCE(m.Col4, '') = COALESCE(t.Col4, '')
        AND COALESCE(m.Col5, '') = COALESCE(t.Col5, '')
        AND COALESCE(m.Col6, '') = COALESCE(t.Col6, '')
        AND COALESCE(m.Col7, '') = COALESCE(t.Col7, '')
    )

END
GO

INSERT [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo15', N'KeywordModel', NULL, N'Actions', N'dbo15', N'uspSortKeywordModel', N'PROCEDURE', N'_Reload', NULL, NULL, 1)
GO

-- Test Data

INSERT [dbo15].[KeywordModel] ([Campaign], [KeywordSet], [Col1], [Col2], [Col3], [Col4], [Col5], [Col6], [Col7]) VALUES (N'RealTimeToExcel', N'quotes', N'*', N'*', N'option', N'data', N'*', N'*', N'excel')
INSERT [dbo15].[KeywordModel] ([Campaign], [KeywordSet], [Col1], [Col2], [Col3], [Col4], [Col5], [Col6], [Col7]) VALUES (N'RealTimeToExcel', N'quotes', N'download', N'delayed', N'stock', N'prices', NULL, N'google finance', NULL)
INSERT [dbo15].[KeywordModel] ([Campaign], [KeywordSet], [Col1], [Col2], [Col3], [Col4], [Col5], [Col6], [Col7]) VALUES (N'RealTimeToExcel', N'quotes', NULL, NULL, N'stock option', N'qoutes', NULL, N'msn', NULL)
INSERT [dbo15].[KeywordModel] ([Campaign], [KeywordSet], [Col1], [Col2], [Col3], [Col4], [Col5], [Col6], [Col7]) VALUES (N'RealTimeToExcel', N'quotes', NULL, NULL, NULL, N'quotes', NULL, N'yahoo finance', NULL)
INSERT [dbo15].[KeywordModel] ([Campaign], [KeywordSet], [Col1], [Col2], [Col3], [Col4], [Col5], [Col6], [Col7]) VALUES (N'RealTimeToExcel', N'quotes', NULL, NULL, NULL, NULL, NULL, NULL, NULL)
INSERT [dbo15].[KeywordModel] ([Campaign], [KeywordSet], [Col1], [Col2], [Col3], [Col4], [Col5], [Col6], [Col7]) VALUES (N'RealTimeToExcel', N'quotes', NULL, NULL, NULL, NULL, NULL, NULL, NULL)
INSERT [dbo15].[KeywordModel] ([Campaign], [KeywordSet], [Col1], [Col2], [Col3], [Col4], [Col5], [Col6], [Col7]) VALUES (N'SaveToDB', N'import-export', N'export', N'*', N'*', N'*', N'*', N'excel', N'db2')
INSERT [dbo15].[KeywordModel] ([Campaign], [KeywordSet], [Col1], [Col2], [Col3], [Col4], [Col5], [Col6], [Col7]) VALUES (N'SaveToDB', N'import-export', N'import', NULL, NULL, N'data', NULL, NULL, N'ms sql')
INSERT [dbo15].[KeywordModel] ([Campaign], [KeywordSet], [Col1], [Col2], [Col3], [Col4], [Col5], [Col6], [Col7]) VALUES (N'SaveToDB', N'import-export', N'save', NULL, NULL, NULL, NULL, NULL, N'mysql')
INSERT [dbo15].[KeywordModel] ([Campaign], [KeywordSet], [Col1], [Col2], [Col3], [Col4], [Col5], [Col6], [Col7]) VALUES (N'SaveToDB', N'import-export', N'upload', NULL, NULL, NULL, NULL, NULL, N'oracle')
INSERT [dbo15].[KeywordModel] ([Campaign], [KeywordSet], [Col1], [Col2], [Col3], [Col4], [Col5], [Col6], [Col7]) VALUES (N'SaveToDB', N'import-export', NULL, NULL, NULL, NULL, NULL, NULL, N'sql server')
INSERT [dbo15].[KeywordModel] ([Campaign], [KeywordSet], [Col1], [Col2], [Col3], [Col4], [Col5], [Col6], [Col7]) VALUES (N'SaveToDB', N'import-export', NULL, NULL, NULL, NULL, NULL, NULL, N'sql server compact')

print N'The application has been installed';
GO
