-- =============================================
-- Database Help Generator for Microsoft SQL Server
-- Version 1.0, April 13, 2015
--
-- Copyright 2015 Gartle Technology Corporation
-- =============================================

SET NOCOUNT ON

DECLARE @Language char(2) = 'en'

DECLARE @Results TABLE (Line nvarchar(2000))

-- Cursor variables

DECLARE @ROUTINE_SCHEMA nvarchar(128)
DECLARE @ROUTINE_NAME nvarchar(128)
DECLARE @TRANSLATED_DESC nvarchar(2000)
DECLARE @TRANSLATED_COMMENT nvarchar(4000)

DECLARE @PARAMETER_NAME nvarchar(128)
DECLARE @DATA_TYPE nvarchar(128)
DECLARE @PARAMETER_MODE nvarchar(128)

DECLARE @PREV_SCHEMA nvarchar(128)
DECLARE @PREV_NAME nvarchar(128)
DECLARE @PREV_COMMENT nvarchar(4000)
DECLARE @HAS_PARAMETERS tinyint

-- Object output

DECLARE ObjectCursor CURSOR FORWARD_ONLY LOCAL READ_ONLY FOR
    SELECT
        t.ROUTINE_SCHEMA
        , t.ROUTINE_NAME
        , tr.TRANSLATED_DESC
    FROM
        INFORMATION_SCHEMA.ROUTINES t
        LEFT OUTER JOIN dbo01.ObjectTranslation tr
            ON tr.TABLE_SCHEMA = t.ROUTINE_SCHEMA AND tr.TABLE_NAME = t.ROUTINE_NAME AND tr.LANGUAGE_NAME = @Language
    WHERE
        t.ROUTINE_TYPE = 'PROCEDURE'
        AND t.ROUTINE_SCHEMA NOT IN ('etl01', 'dbo01', 'xls01')
    ORDER BY
        t.ROUTINE_SCHEMA
        , t.ROUTINE_NAME

INSERT INTO @Results (Line) VALUES('<table class="objects">')
INSERT INTO @Results (Line) VALUES('<tr><th>Procedure</th><th>Description</th></tr>')
    
OPEN ObjectCursor
FETCH NEXT FROM ObjectCursor
INTO 
    @ROUTINE_SCHEMA
    , @ROUTINE_NAME
    , @TRANSLATED_DESC

WHILE @@FETCH_STATUS = 0
    BEGIN

    INSERT INTO @Results (Line) VALUES(+ '<tr><td><a href="#' + @ROUTINE_SCHEMA + '.' + @ROUTINE_NAME + '" >'
        + @ROUTINE_SCHEMA + '.' + @ROUTINE_NAME + '</a></td><td>' + COALESCE(@TRANSLATED_DESC, '') + '</td></tr>')

    FETCH NEXT FROM ObjectCursor
    INTO
        @ROUTINE_SCHEMA
        , @ROUTINE_NAME
        , @TRANSLATED_DESC
    END

CLOSE ObjectCursor
DEALLOCATE ObjectCursor

INSERT INTO @Results (Line) VALUES('</table>')

-- Details output

DECLARE FieldCursor CURSOR FORWARD_ONLY LOCAL READ_ONLY FOR
    SELECT
        r.ROUTINE_SCHEMA
        , r.ROUTINE_NAME
        , p.PARAMETER_NAME
        , CASE
            WHEN RIGHT(p.DATA_TYPE, 4) = 'char' AND p.CHARACTER_MAXIMUM_LENGTH = -1 THEN p.DATA_TYPE + '(max)'
            WHEN RIGHT(p.DATA_TYPE, 4) = 'char' THEN p.DATA_TYPE + '(' + CAST(p.CHARACTER_MAXIMUM_LENGTH AS varchar) + ')'
            ELSE p.DATA_TYPE END AS DATA_TYPE
        , p.PARAMETER_MODE
        , trc.TRANSLATED_DESC
        , tr.TRANSLATED_COMMENT
    FROM
        INFORMATION_SCHEMA.ROUTINES r
        LEFT OUTER JOIN INFORMATION_SCHEMA.PARAMETERS p ON p.SPECIFIC_SCHEMA = r.SPECIFIC_SCHEMA AND p.SPECIFIC_NAME = r.SPECIFIC_NAME

        -- SaveToDB Framework Tables

        LEFT OUTER JOIN dbo01.ObjectTranslation tr
            ON tr.TABLE_SCHEMA = r.ROUTINE_SCHEMA AND tr.TABLE_NAME = r.ROUTINE_NAME AND tr.LANGUAGE_NAME = @Language

        LEFT OUTER JOIN dbo01.ColumnTranslation trc
            ON trc.TABLE_SCHEMA = r.ROUTINE_SCHEMA AND trc.TABLE_NAME = r.ROUTINE_NAME AND trc.COLUMN_NAME = p.PARAMETER_NAME AND trc.LANGUAGE_NAME = @Language
    WHERE
        r.ROUTINE_SCHEMA NOT IN ('etl01', 'dbo01', 'xls01')
        AND r.ROUTINE_TYPE = 'PROCEDURE'
    ORDER BY
        r.ROUTINE_SCHEMA
        , r.ROUTINE_NAME
        , p.ORDINAL_POSITION

SET @PREV_SCHEMA = ''
SET @PREV_NAME = ''
SET @PREV_COMMENT = ''
SET @HAS_PARAMETERS = 0

OPEN FieldCursor
FETCH NEXT FROM FieldCursor
INTO 
    @ROUTINE_SCHEMA
    , @ROUTINE_NAME
    , @PARAMETER_NAME
    , @DATA_TYPE
    , @PARAMETER_MODE
    , @TRANSLATED_DESC
    , @TRANSLATED_COMMENT

WHILE @@FETCH_STATUS = 0
    BEGIN

    IF @PREV_SCHEMA <> @ROUTINE_SCHEMA OR @PREV_NAME <> @ROUTINE_NAME
        BEGIN
        IF @HAS_PARAMETERS = 1
            BEGIN
            INSERT INTO @Results (Line) VALUES(+ '</table>')
            END
            
        INSERT INTO @Results (Line) VALUES('<p>' + COALESCE(REPLACE(@PREV_COMMENT, CHAR(10), CHAR(10) + '<br/>' ), '') + '</p>')

        SET @PREV_SCHEMA = @ROUTINE_SCHEMA
        SET @PREV_NAME = @ROUTINE_NAME
        SET @PREV_COMMENT = @TRANSLATED_COMMENT

        SET @HAS_PARAMETERS = CASE WHEN @PARAMETER_NAME IS NULL THEN 0 ELSE 1 END

        INSERT INTO @Results (Line) VALUES('<h2><a name="' + @ROUTINE_SCHEMA + '.' + @ROUTINE_NAME + '" ></a>'
            + @ROUTINE_SCHEMA + '.' + @ROUTINE_NAME + '</h2>')

        IF @HAS_PARAMETERS = 1
            BEGIN
            INSERT INTO @Results (Line) VALUES('<table class="fields">')
            INSERT INTO @Results (Line) VALUES('<tr><th>Parameter</th><th>DataType</th><th>Mode</th><th>Comment</th></tr>')
            END
        END

    IF @HAS_PARAMETERS = 1
        INSERT INTO @Results (Line) VALUES('<tr><td>' + @PARAMETER_NAME + '</td>'
            + '<td>' + COALESCE(@DATA_TYPE, '') + '</td>'
            + '<td>' + COALESCE(@PARAMETER_MODE, '') + '</td>'
            + '<td></td></tr>')

    FETCH NEXT FROM FieldCursor
    INTO
        @ROUTINE_SCHEMA
        , @ROUTINE_NAME
        , @PARAMETER_NAME
        , @DATA_TYPE
        , @PARAMETER_MODE
        , @TRANSLATED_DESC
        , @TRANSLATED_COMMENT
    END

CLOSE FieldCursor
DEALLOCATE FieldCursor

IF @HAS_PARAMETERS = 1
    BEGIN
    INSERT INTO @Results (Line) VALUES(+ '</table>')
    END

INSERT INTO @Results (Line) VALUES('<p>' + COALESCE(REPLACE(@PREV_COMMENT, CHAR(10), CHAR(10) + '<br/>' ), '') + '</p>')

SELECT * FROM @Results
