-- =============================================
-- Database Doc Generator for Microsoft SQL Server
-- Version 1.0, April 13, 2015
--
-- Copyright 2015 Gartle Technology Corporation
-- =============================================

SET NOCOUNT ON

DECLARE @Results TABLE (Line nvarchar(2000))

-- Cursor variables

DECLARE @ROUTINE_SCHEMA nvarchar(128)
DECLARE @ROUTINE_NAME nvarchar(128)

DECLARE @PARAMETER_NAME nvarchar(128)
DECLARE @DATA_TYPE nvarchar(128)
DECLARE @PARAMETER_MODE nvarchar(128)

DECLARE @PREV_SCHEMA nvarchar(128)
DECLARE @PREV_NAME nvarchar(128)
DECLARE @HAS_PARAMETERS tinyint

-- Object output

DECLARE ObjectCursor CURSOR FORWARD_ONLY LOCAL READ_ONLY FOR
    SELECT
        t.ROUTINE_SCHEMA
        , t.ROUTINE_NAME
    FROM
        INFORMATION_SCHEMA.ROUTINES t
    WHERE
        t.ROUTINE_TYPE = 'FUNCTION'
        AND t.ROUTINE_SCHEMA NOT IN ('etl01', 'dbo01', 'xls01')
    ORDER BY
        t.ROUTINE_SCHEMA
        , t.ROUTINE_NAME

INSERT INTO @Results (Line) VALUES('<table class="objects">')
INSERT INTO @Results (Line) VALUES('<tr><th>Function</th><th>Description</th></tr>')
    
OPEN ObjectCursor
FETCH NEXT FROM ObjectCursor
INTO 
    @ROUTINE_SCHEMA
    , @ROUTINE_NAME
WHILE @@FETCH_STATUS = 0
    BEGIN

    INSERT INTO @Results (Line) VALUES(+ '<tr><td><a href="#' + @ROUTINE_SCHEMA + '.' + @ROUTINE_NAME + '" >'
        + @ROUTINE_SCHEMA + '.' + @ROUTINE_NAME + '</a></td><td></td></tr>')

    FETCH NEXT FROM ObjectCursor
    INTO
        @ROUTINE_SCHEMA
        , @ROUTINE_NAME
    END

CLOSE ObjectCursor
DEALLOCATE ObjectCursor

INSERT INTO @Results (Line) VALUES('</table>')

-- Details output

DECLARE FieldCursor CURSOR FORWARD_ONLY LOCAL READ_ONLY FOR
    SELECT
        r.ROUTINE_SCHEMA
        , r.ROUTINE_NAME
        , p.PARAMETER_NAME
        , CASE
            WHEN RIGHT(p.DATA_TYPE, 4) = 'char' AND p.CHARACTER_MAXIMUM_LENGTH = -1 THEN p.DATA_TYPE + '(max)'
            WHEN RIGHT(p.DATA_TYPE, 4) = 'char' THEN p.DATA_TYPE + '(' + CAST(p.CHARACTER_MAXIMUM_LENGTH AS varchar) + ')'
            ELSE p.DATA_TYPE END AS DATA_TYPE
        , p.PARAMETER_MODE
    FROM
        INFORMATION_SCHEMA.ROUTINES r
        LEFT OUTER JOIN INFORMATION_SCHEMA.PARAMETERS p ON p.SPECIFIC_SCHEMA = r.SPECIFIC_SCHEMA AND p.SPECIFIC_NAME = r.SPECIFIC_NAME
    WHERE
        r.ROUTINE_SCHEMA NOT IN ('etl01', 'dbo01', 'xls01')
        AND r.ROUTINE_TYPE = 'FUNCTION'
    ORDER BY
        r.ROUTINE_SCHEMA
        , r.ROUTINE_NAME
        , p.ORDINAL_POSITION

SET @PREV_SCHEMA = ''
SET @PREV_NAME = ''
SET @HAS_PARAMETERS = 0

OPEN FieldCursor
FETCH NEXT FROM FieldCursor
INTO 
    @ROUTINE_SCHEMA
    , @ROUTINE_NAME
    , @PARAMETER_NAME
    , @DATA_TYPE
    , @PARAMETER_MODE

WHILE @@FETCH_STATUS = 0
    BEGIN

    IF @PREV_SCHEMA <> @ROUTINE_SCHEMA OR @PREV_NAME <> @ROUTINE_NAME
        BEGIN
        IF @HAS_PARAMETERS = 1
            BEGIN
            INSERT INTO @Results (Line) VALUES(+ '</table>')
            END
            
        INSERT INTO @Results (Line) VALUES('<p></p>')

        SET @PREV_SCHEMA = @ROUTINE_SCHEMA
        SET @PREV_NAME = @ROUTINE_NAME

        SET @HAS_PARAMETERS = CASE WHEN @PARAMETER_NAME IS NULL THEN 0 ELSE 1 END

        INSERT INTO @Results (Line) VALUES('<h2><a name="' + @ROUTINE_SCHEMA + '.' + @ROUTINE_NAME + '" ></a>'
            + @ROUTINE_SCHEMA + '.' + @ROUTINE_NAME + '</h2>')

        IF @HAS_PARAMETERS = 1
            BEGIN
            INSERT INTO @Results (Line) VALUES('<table class="fields">')
            INSERT INTO @Results (Line) VALUES('<tr><th>Parameter</th><th>DataType</th><th>Mode</th><th>Comment</th></tr>')
            END
        END

    IF @HAS_PARAMETERS = 1
        INSERT INTO @Results (Line) VALUES('<tr><td>' + COALESCE(@PARAMETER_NAME, 'Result') + '</td>'
            + '<td>' + COALESCE(@DATA_TYPE, '') + '</td>'
            + '<td>' + COALESCE(@PARAMETER_MODE, '') + '</td>'
            + '<td></td></tr>')

    FETCH NEXT FROM FieldCursor
    INTO
        @ROUTINE_SCHEMA
        , @ROUTINE_NAME
        , @PARAMETER_NAME
        , @DATA_TYPE
        , @PARAMETER_MODE
    END

CLOSE FieldCursor
DEALLOCATE FieldCursor

IF @HAS_PARAMETERS = 1
    BEGIN
    INSERT INTO @Results (Line) VALUES(+ '</table>')
    END

SELECT * FROM @Results
