-- =============================================
-- Database Doc Generator for Microsoft SQL Server
-- Version 1.0, April 13, 2015
--
-- Copyright 2015 Gartle Technology Corporation
-- =============================================

SET NOCOUNT ON

DECLARE @Results TABLE (Line nvarchar(2000))

-- Cursor variables

DECLARE @TABLE_SCHEMA nvarchar(128)
DECLARE @TABLE_NAME nvarchar(128)

DECLARE @COLUMN_NAME nvarchar(128)
DECLARE @DATA_TYPE nvarchar(128)
DECLARE @IS_NULLABLE nvarchar(128)
DECLARE @IS_IDENTITY nvarchar(128)
DECLARE @CONSTRAINT nvarchar(128)

DECLARE @PREV_SCHEMA nvarchar(128)
DECLARE @PREV_NAME nvarchar(128)

-- Object output

DECLARE ObjectCursor CURSOR FORWARD_ONLY LOCAL READ_ONLY FOR
    SELECT
        t.TABLE_SCHEMA
        , t.TABLE_NAME
    FROM
        INFORMATION_SCHEMA.TABLES t
    WHERE
        t.TABLE_TYPE = 'VIEW'
        AND t.TABLE_SCHEMA NOT IN ('etl01', 'dbo01', 'xls01')
    ORDER BY
        t.TABLE_SCHEMA
        , t.TABLE_NAME

INSERT INTO @Results (Line) VALUES('<table class="objects">')
INSERT INTO @Results (Line) VALUES('<tr><th>Table</th><th>Description</th></tr>')
    
OPEN ObjectCursor
FETCH NEXT FROM ObjectCursor
INTO 
    @TABLE_SCHEMA
    , @TABLE_NAME
WHILE @@FETCH_STATUS = 0
    BEGIN

    INSERT INTO @Results (Line) VALUES(+ '<tr><td><a href="#' + @TABLE_SCHEMA + '.' + @TABLE_NAME + '" >'
        + @TABLE_SCHEMA + '.' + @TABLE_NAME + '</a></td><td></td></tr>')

    FETCH NEXT FROM ObjectCursor
    INTO
        @TABLE_SCHEMA
        , @TABLE_NAME
    END

CLOSE ObjectCursor
DEALLOCATE ObjectCursor

INSERT INTO @Results (Line) VALUES('</table>')

-- Details output

DECLARE FieldCursor CURSOR FORWARD_ONLY LOCAL READ_ONLY FOR
    SELECT
        t.TABLE_SCHEMA
        , t.TABLE_NAME
        , c.COLUMN_NAME
        , CASE
            WHEN RIGHT(c.DATA_TYPE, 4) = 'char' AND c.CHARACTER_MAXIMUM_LENGTH = -1 THEN c.DATA_TYPE + '(max)'
            WHEN RIGHT(c.DATA_TYPE, 4) = 'char' THEN c.DATA_TYPE + '(' + CAST(c.CHARACTER_MAXIMUM_LENGTH AS varchar) + ')'
            ELSE c.DATA_TYPE END AS DATA_TYPE
        , CASE WHEN c.IS_NULLABLE = 'NO' THEN 'NOT NULL' ELSE NULL END AS IS_NULLABLE
        , CASE WHEN sc.is_identity = 1 THEN 'IDENTITY' ELSE NULL END AS IS_IDENTITY
        , CASE
            WHEN tc.CONSTRAINT_TYPE = 'PRIMARY KEY' THEN 'PK' 
            WHEN tc.CONSTRAINT_TYPE = 'FOREIGN KEY' THEN 'FK'
            ELSE NULL END AS 'CONSTRAINT'
    FROM 
        -- Base Table Column

        INFORMATION_SCHEMA.COLUMNS c
        INNER JOIN INFORMATION_SCHEMA.TABLES t ON t.TABLE_SCHEMA = c.TABLE_SCHEMA AND t.TABLE_NAME = c.TABLE_NAME
    
        -- SQL Server specific data for column

        INNER JOIN sys.columns sc
            ON sc.[object_id] = OBJECT_ID('[' + c.TABLE_SCHEMA + '].[' + c.TABLE_NAME + ']') AND sc.name = c.COLUMN_NAME

        -- Base Table Constraint

        LEFT OUTER JOIN INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE ccu
            ON ccu.TABLE_SCHEMA = c.TABLE_SCHEMA AND ccu.TABLE_NAME = c.TABLE_NAME
                AND ccu.COLUMN_NAME = c.COLUMN_NAME

        LEFT OUTER JOIN INFORMATION_SCHEMA.TABLE_CONSTRAINTS tc
            ON tc.TABLE_SCHEMA = c.TABLE_SCHEMA AND tc.TABLE_NAME = c.TABLE_NAME
                AND tc.CONSTRAINT_SCHEMA = ccu.CONSTRAINT_SCHEMA AND tc.CONSTRAINT_NAME = ccu.CONSTRAINT_NAME

    WHERE
        t.TABLE_TYPE = 'VIEW'
        AND t.TABLE_SCHEMA NOT IN ('etl01', 'dbo01', 'xls01')
    ORDER BY
        c.TABLE_SCHEMA
        , c.TABLE_NAME
        , c.ORDINAL_POSITION

SET @PREV_SCHEMA = ''
SET @PREV_NAME = ''

OPEN FieldCursor
FETCH NEXT FROM FieldCursor
INTO 
    @TABLE_SCHEMA
    , @TABLE_NAME
    , @COLUMN_NAME
    , @DATA_TYPE
    , @IS_NULLABLE
    , @IS_IDENTITY
    , @CONSTRAINT

WHILE @@FETCH_STATUS = 0
    BEGIN

    IF @PREV_SCHEMA <> @TABLE_SCHEMA OR @PREV_NAME <> @TABLE_NAME
        BEGIN
        IF @PREV_NAME > ''
            BEGIN
            INSERT INTO @Results (Line) VALUES(+ '</table>')
            END
            
        INSERT INTO @Results (Line) VALUES('<p></p>')

        SET @PREV_SCHEMA = @TABLE_SCHEMA
        SET @PREV_NAME = @TABLE_NAME

        INSERT INTO @Results (Line) VALUES('<h2><a name="' + @TABLE_SCHEMA + '.' + @TABLE_NAME + '" ></a>'
            + @TABLE_SCHEMA + '.' + @TABLE_NAME + '</h2>')

        INSERT INTO @Results (Line) VALUES('<table class="fields">')
        INSERT INTO @Results (Line) VALUES('<tr><th>Column</th><th>DataType</th><th>Comment</th></tr>')
        END

    INSERT INTO @Results (Line) VALUES('<tr><td>' + @COLUMN_NAME + '</td>'
        + '<td>' + COALESCE(@DATA_TYPE, '') + '</td>'
        + '<td></td></tr>')

    FETCH NEXT FROM FieldCursor
    INTO
        @TABLE_SCHEMA
        , @TABLE_NAME
        , @COLUMN_NAME
        , @DATA_TYPE
        , @IS_NULLABLE
        , @IS_IDENTITY
        , @CONSTRAINT
    END

CLOSE FieldCursor
DEALLOCATE FieldCursor

INSERT INTO @Results (Line) VALUES(+ '</table>')
INSERT INTO @Results (Line) VALUES('<p></p>')

SELECT * FROM @Results
