IF NOT EXISTS (SELECT loginname FROM master.dbo.syslogins WHERE name = 'dbo30')
EXEC master.dbo.sp_addlogin @loginame = N'dbo30', @passwd = N'Dev_2011#_Xls4168', @defdb = N'master'
GO
IF NOT EXISTS (SELECT loginname FROM master.dbo.syslogins WHERE name = 'xls30')
EXEC master.dbo.sp_addlogin @loginame = N'xls30', @passwd = N'Usr_2011#_Xls4168', @defdb = N'master'
GO
EXEC dbo.sp_grantdbaccess @loginame = N'dbo30', @name_in_db = N'dbo30'
GO
EXEC dbo.sp_grantdbaccess @loginame = N'xls30', @name_in_db = N'xls30'
GO

CREATE TABLE [dbo30].[Payments](
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [Date] [datetime] NULL,
    [Sum] [money] NULL,
    [AccountName] [nvarchar](50) NULL,
    [CompanyName] [nvarchar](50) NULL,
    [ItemName] [nvarchar](50) NULL,
    [Comment] [nvarchar](50) NULL,
 CONSTRAINT [PK_Payments] PRIMARY KEY CLUSTERED ([ID] ASC)
)
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Year CashFlow report
-- =============================================

CREATE PROCEDURE [xls30].[uspCashFlowYear]
    @Year int = NULL
    , @DataLanguage char(2) = NULL
AS
BEGIN

SET NOCOUNT ON
    
SELECT
    p.RowNumber AS N
    , MAX(p.[Level]) AS [Level]
    , p.ItemType
    , p.ItemName
    , p.CompanyName
    , COALESCE(MAX(t.TRANSLATED_NAME), MAX(p.Name)) AS Name
    , SUM(p.Total) AS Total
    , SUM(p.Jan) AS Jan
    , SUM(p.Feb) AS Feb
    , SUM(p.Mar) AS Mar
    , SUM(p.Apr) AS Apr
    , SUM(p.May) AS May
    , SUM(p.Jun) AS Jun
    , SUM(p.Jul) AS Jul
    , SUM(p.Aug) AS Aug
    , SUM(p.Sep) AS Sep
    , SUM(p.Oct) AS Oct
    , SUM(p.Nov) AS Nov
    , SUM(p.[Dec]) AS [Dec]
FROM
    (
    -- Companies
    SELECT
        p.RowNumber
        , 0 AS [Level]
        , p.ItemType
        , p.ItemName
        , p.CompanyName
        , '  ' + p.CompanyName AS Name
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            CAST(CASE WHEN p.[Sum]<0 THEN 2 ELSE 1 END AS int) AS RowNumber
            , CAST(CASE WHEN p.[Sum]<0 THEN N'Expenses' ELSE N'Income' END AS NVARCHAR(50)) AS ItemType
            , p.ItemName
            , p.CompanyName
            , DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            dbo30.Payments p
        WHERE
            p.CompanyName IS NOT NULL
            AND DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period,
        p.RowNumber,
        p.ItemType,
        p.ItemName,
        p.CompanyName

    -- Total Items
    UNION ALL
    SELECT
        p.RowNumber
        , 1 AS [Level]
        , p.ItemType
        , p.ItemName
        , NULL AS CompanyName
        , p.ItemName AS [Name]
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            CAST(CASE WHEN p.[Sum]<0 THEN 2 ELSE 1 END AS int) AS RowNumber
            , CAST(CASE WHEN p.[Sum]<0 THEN N'Expenses' ELSE N'Income' END AS NVARCHAR(50)) AS ItemType
            , p.ItemName
            , DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            dbo30.Payments p
        WHERE
            p.ItemName IS NOT NULL
            AND DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period,
        p.RowNumber,
        p.ItemType,
        p.ItemName

    -- Total Income/Expenses
    UNION ALL
    SELECT
        p.RowNumber
        , 2 AS [Level]
        , p.ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N'Total ' + p.ItemType AS Name
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            CAST(CASE WHEN p.[Sum]<0 THEN 2 ELSE 1 END AS int) AS RowNumber
            , CAST(CASE WHEN p.[Sum]<0 THEN N'Expenses' ELSE N'Income' END AS NVARCHAR(50)) AS ItemType
            , DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            dbo30.Payments p
        WHERE
            DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period,
        p.RowNumber,
        p.ItemType

    -- Net Chanhge
    UNION ALL
    SELECT
        3 AS RowNumber
        , 2 AS [Level]
        , N'Net Change' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N'Net Change' AS Name
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            dbo30.Payments p
        WHERE
            DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period

    -- Opening balance
    UNION ALL
    SELECT
        0 AS RowNumber
        , 3 AS [Level]
        , N'Opening Balance' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N'Opening Balance' AS Name
        , p.Period
        , NULL AS Total
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, d.[Date]) AS Period
            , SUM(p.[Sum]) AS [Sum]
        FROM
            dbo30.Payments p
            CROSS JOIN (
                SELECT DATEADD(YEAR, @Year - 1900, 0) AS [Date]
                UNION SELECT DATEADD(MONTH, 1, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 2, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 3, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 4, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 5, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 6, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 7, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 8, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 9, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 10, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 11, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
            ) d
        WHERE
            p.[Date] < d.[Date]
        GROUP BY
            d.[Date]
        ) p
    GROUP BY
        p.Period

    -- Closing balance
    UNION ALL
    SELECT
        4 AS RowNumber
        , 3 AS [Level]
        , N'Closing Balance' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N'Closing Balance' AS Name
        , p.Period
        , NULL AS Total
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, d.[Date]) AS Period
            , SUM(p.[Sum]) AS [Sum]
        FROM
            dbo30.Payments p
            CROSS JOIN (
                SELECT DATEADD(MONTH, 1, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 2, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 3, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 4, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 5, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 6, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 7, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 8, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 9, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 10, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 11, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 12, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
            ) d
        WHERE
            p.[Date] < d.[Date]
        GROUP BY
            d.[Date]
        ) p
    GROUP BY
        p.Period
    ) p
    LEFT OUTER JOIN dbo01.ColumnTranslation t ON t.TABLE_SCHEMA = 'xls30' AND t.TABLE_NAME = 'ItemName' AND t.COLUMN_NAME = p.Name
        AND UPPER(t.LANGUAGE_NAME) = UPPER(@DataLanguage)
GROUP BY
    p.RowNumber,
    p.ItemType,
    p.ItemName,
    p.CompanyName
ORDER BY
    p.RowNumber,
    p.ItemType,
    p.ItemName,
    p.CompanyName    

END
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Year CashFlow summary report
-- =============================================

CREATE PROCEDURE [xls30].[uspCashFlowYearSummary]
    @Year int = NULL
    , @DataLanguage char(2) = NULL
AS
BEGIN

SET NOCOUNT ON
    
SELECT
    p.RowNumber AS N
    , MAX(p.[Level]) AS [Level]
    , p.ItemType
    , p.ItemName
    , p.CompanyName
    , COALESCE(MAX(t.TRANSLATED_NAME), MAX(p.Name)) AS Name
    , SUM(p.Total) AS Total
    , SUM(p.Jan) AS Jan
    , SUM(p.Feb) AS Feb
    , SUM(p.Mar) AS Mar
    , SUM(p.Apr) AS Apr
    , SUM(p.May) AS May
    , SUM(p.Jun) AS Jun
    , SUM(p.Jul) AS Jul
    , SUM(p.Aug) AS Aug
    , SUM(p.Sep) AS Sep
    , SUM(p.Oct) AS Oct
    , SUM(p.Nov) AS Nov
    , SUM(p.[Dec]) AS [Dec]
FROM
    (
    -- Total Items
    SELECT
        p.RowNumber
        , 1 AS [Level]
        , p.ItemType
        , p.ItemName
        , NULL AS CompanyName
        , p.ItemName AS [Name]
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            CAST(CASE WHEN p.[Sum]<0 THEN 2 ELSE 1 END AS int) AS RowNumber
            , CAST(CASE WHEN p.[Sum]<0 THEN N'Expenses' ELSE N'Income' END AS NVARCHAR(50)) AS ItemType
            , p.ItemName
            , DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            dbo30.Payments p
        WHERE
            p.ItemName IS NOT NULL
            AND DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period,
        p.RowNumber,
        p.ItemType,
        p.ItemName

    -- Total Income/Expenses
    UNION ALL
    SELECT
        p.RowNumber
        , 2 AS [Level]
        , p.ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N'Total ' + p.ItemType AS Name
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            CAST(CASE WHEN p.[Sum]<0 THEN 2 ELSE 1 END AS int) AS RowNumber
            , CAST(CASE WHEN p.[Sum]<0 THEN N'Expenses' ELSE N'Income' END AS NVARCHAR(50)) AS ItemType
            , DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            dbo30.Payments p
        WHERE
            DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period,
        p.RowNumber,
        p.ItemType

    -- Net Chanhge
    UNION ALL
    SELECT
        3 AS RowNumber
        , 2 AS [Level]
        , N'Net Change' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N'Net Change' AS Name
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            dbo30.Payments p
        WHERE
            DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period

    -- Opening balance
    UNION ALL
    SELECT
        0 AS RowNumber
        , 3 AS [Level]
        , N'Opening Balance' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N'Opening Balance' AS Name
        , p.Period
        , NULL AS Total
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, d.[Date]) AS Period
            , SUM(p.[Sum]) AS [Sum]
        FROM
            dbo30.Payments p
            CROSS JOIN (
                SELECT DATEADD(YEAR, @Year - 1900, 0) AS [Date]
                UNION SELECT DATEADD(MONTH, 1, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 2, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 3, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 4, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 5, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 6, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 7, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 8, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 9, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 10, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 11, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
            ) d
        WHERE
            p.[Date] < d.[Date]
        GROUP BY
            d.[Date]
        ) p
    GROUP BY
        p.Period

    -- Closing balance
    UNION ALL
    SELECT
        4 AS RowNumber
        , 3 AS [Level]
        , N'Closing Balance' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N'Closing Balance' AS Name
        , p.Period
        , NULL AS Total
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, d.[Date]) AS Period
            , SUM(p.[Sum]) AS [Sum]
        FROM
            dbo30.Payments p
            CROSS JOIN (
                SELECT DATEADD(MONTH, 1, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 2, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 3, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 4, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 5, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 6, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 7, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 8, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 9, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 10, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 11, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 12, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
            ) d
        WHERE
            p.[Date] < d.[Date]
        GROUP BY
            d.[Date]
        ) p
    GROUP BY
        p.Period
    ) p
    LEFT OUTER JOIN dbo01.ColumnTranslation t ON t.TABLE_SCHEMA = 'xls30' AND t.TABLE_NAME = 'ItemName' AND t.COLUMN_NAME = p.Name
        AND UPPER(t.LANGUAGE_NAME) = UPPER(@DataLanguage)
GROUP BY
    p.RowNumber,
    p.ItemType,
    p.ItemName,
    p.CompanyName
ORDER BY
    p.RowNumber,
    p.ItemType,
    p.ItemName,
    p.CompanyName    

END
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Company payments
-- =============================================

CREATE PROCEDURE [xls30].[uspExcelEvent_ContextMenu_Payment_CompanyName]
    @CompanyName nvarchar(255) = NULL
AS
BEGIN

    SET NOCOUNT ON

    SELECT
        *
    FROM
        dbo30.Payments p
    WHERE
        p.CompanyName = @CompanyName

END
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Item payments
-- =============================================

CREATE PROCEDURE [xls30].[uspExcelEvent_ContextMenu_Payment_ItemName]
    @ItemName nvarchar(255) = NULL
AS
BEGIN

    SET NOCOUNT ON

    SELECT
        *
    FROM
        dbo30.Payments p
    WHERE
        p.ItemName = @ItemName

END
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Year parameter values
-- =============================================

CREATE VIEW [xls30].[viewParameterValues_Year]
AS

    SELECT NULL AS [Year] UNION
    SELECT
        DISTINCT
        YEAR([Date]) AS [Year]
    FROM
       dbo30.Payments
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Query List of user objects
-- =============================================

CREATE VIEW [xls30].[viewQueryList]
AS

    SELECT
        t.TABLE_SCHEMA
        , t.TABLE_NAME
        , t.TABLE_TYPE
        , t.TABLE_CODE
        , t.INSERT_PROCEDURE
        , t.UPDATE_PROCEDURE
        , t.DELETE_PROCEDURE
        , t.PROCEDURE_TYPE
    FROM
        [xls01].[viewQueryList] t
    WHERE
        t.TABLE_NAME IN (
            'Payments'
            , 'uspCashFlowYear'
            , 'uspCashFlowYearSummary'
        )

GO

SET NOCOUNT ON

INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20141231',10000,'My Bank',NULL,NULL,'Opening balance');
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150110',200000,'My Bank','Rose, Inc','Revenue',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150110',-50000,'My Bank','Land, Inc','Expenses',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150131',-13000,'My Bank','Income Taxes','Taxes',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150131',-29580,'My Bank','Salary Taxes','Taxes',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150131',-87000,'My Bank',NULL,'Payroll',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150210',300000,'My Bank','Rose, Inc','Revenue',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150210',100000,'My Bank','Carnation, Inc','Revenue',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150210',-50000,'My Bank','Water, Inc','Expenses',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150210',-100000,'My Bank','Land, Inc','Expenses',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150228',-13000,'My Bank','Income Taxes','Taxes',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150228',-29580,'My Bank','Salary Taxes','Taxes',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150228',-87000,'My Bank',NULL,'Payroll',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150310',300000,'My Bank','Rose, Inc','Revenue',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150310',200000,'My Bank','Carnation, Inc','Revenue',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150310',100000,'My Bank','Cornflower, Corp','Revenue',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150315',-36000,'My Bank','Corporate Tax','Taxes',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150331',-26000,'My Bank','Income Taxes','Taxes',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150331',-50000,'My Bank','Water, Inc','Expenses',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150331',-59160,'My Bank','Salary Taxes','Taxes',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150331',-100000,'My Bank','Land, Inc','Expenses',NULL);
INSERT INTO [dbo30].[Payments] ([Date],[Sum],[AccountName],[CompanyName],[ItemName],[Comment]) VALUES ('20150331',-174000,'My Bank',NULL,'Payroll',NULL);
GO

SET NOCOUNT ON

INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'dbo30', N'Payments', 'en', N'Payments', N'Payments', N'This example shows the core features of database data editing.
Add, update or delete rows and then click the Save to DB button at the SaveToDB tab.
The data will be updated is the SQL Azure database and available for
authorized users over the world.');

INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls30', N'uspCashFlowYear', 'en', N'CashFlow Year', N'CashFlow', N'This example shows the power of the SQL reports.
The reports like this cannot be implemented using the Excel pivot tables.
In addition, the report data are stored in the SQL Azure database and can be updated by
authorized users over the world.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls30', N'uspCashFlowYearSummary', 'en', N'CashFlow Year Summary', N'CashFlow Summary', N'This example shows the power of the SQL reports.
The reports like this cannot be implemented using the Excel pivot tables.
In addition, the report data are stored in the SQL Azure database and can be updated by
authorized users over the world.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls30', N'uspExcelEvent_ContextMenu_Payment_CompanyName', 'en', N'Company Payments', NULL, N'This is a drill-down query example.
The stored procedure is used as Excel event handler.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls30', N'uspExcelEvent_ContextMenu_Payment_ItemName', 'en', N'Item Payments', NULL, N'This is a drill-down query example.
The stored procedure is used as Excel event handler.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls30', N'viewQueryList', 'en', N'Payments Register', N'Payments User Objects', N'This configuration view defines database objects that are showed in the Ribbon Query List and configures
INSERT, UPDATE and DELETE procedures to save changes of Excel tables based on views and stored procedures.');

INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', N'Payments', N'AccountName', 'en', N'Account Name', NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', N'Payments', N'Comment', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', N'Payments', N'CompanyName', 'en', N'Company Name', NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', N'Payments', N'Date', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', N'Payments', N'ID', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', N'Payments', N'ItemName', 'en', N'Item Name', NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', N'Payments', N'Sum', 'en', NULL, NULL);

INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Apr', 'en', NULL, N'April');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Aug', 'en', NULL, N'August');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Dec', 'en', NULL, N'December');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Feb', 'en', NULL, N'February');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Jan', 'en', NULL, N'January');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Jul', 'en', NULL, N'July');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Jun', 'en', NULL, N'June');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Mar', 'en', NULL, N'March');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'May', 'en', NULL, N'May');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Nov', 'en', NULL, N'November');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Oct', 'en', NULL, N'October');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Sep', 'en', NULL, N'September');


INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (N'dbo30', N'Payments', NULL, 'Actions', N'xls30', N'uspExcelEvent_ContextMenu_Payment_CompanyName', NULL, NULL, 1, NULL);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (N'dbo30', N'Payments', NULL, 'Actions', N'xls30', N'uspExcelEvent_ContextMenu_Payment_ItemName', NULL, NULL, 2, NULL);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (N'dbo30', N'Payments', NULL, 'ContextMenu', N'xls30', N'uspExcelEvent_ContextMenu_Payment_CompanyName', NULL, NULL, 1, NULL);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (N'dbo30', N'Payments', NULL, 'ContextMenu', N'xls30', N'uspExcelEvent_ContextMenu_Payment_ItemName', NULL, NULL, 2, NULL);

INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (N'xls30', N'uspCashFlowYear', NULL, 'ContextMenu', N'xls30', N'uspExcelEvent_ContextMenu_Payment_CompanyName', NULL, NULL, 1, NULL);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (N'xls30', N'uspCashFlowYear', NULL, 'ContextMenu', N'xls30', N'uspExcelEvent_ContextMenu_Payment_ItemName', NULL, NULL, 2, NULL);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (N'xls30', N'uspCashFlowYearSummary', NULL, 'ContextMenu', N'xls30', N'uspExcelEvent_ContextMenu_Payment_ItemName', NULL, NULL, 2, NULL);


INSERT INTO [dbo01].[ParameterValues] ([TABLE_SCHEMA], [TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE]) VALUES (N'xls30', N'uspCashFlowYear', N'Year', N'xls30', N'viewParameterValues_Year', N'VIEW');
INSERT INTO [dbo01].[ParameterValues] ([TABLE_SCHEMA], [TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE]) VALUES (N'xls30', N'uspCashFlowYearSummary', N'Year', N'xls30', N'viewParameterValues_Year', N'VIEW');


INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES ('dbo30','Payments','<?xml version="1.0" encoding="Unicode"?>
<table name="Payments">
<columnFormats>
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$4" type="String" />
<column name="ID" property="ColumnWidth" value="0.08" type="Double" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="Address" value="$D$4" type="String" />
<column name="Date" property="ColumnWidth" value="10" type="Double" />
<column name="Date" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sum" property="Address" value="$E$4" type="String" />
<column name="Sum" property="ColumnWidth" value="11.71" type="Double" />
<column name="Sum" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="AccountName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="AccountName" property="Address" value="$F$4" type="String" />
<column name="AccountName" property="ColumnWidth" value="15.57" type="Double" />
<column name="CompanyName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="CompanyName" property="Address" value="$G$4" type="String" />
<column name="CompanyName" property="ColumnWidth" value="16.71" type="Double" />
<column name="ItemName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ItemName" property="Address" value="$H$4" type="String" />
<column name="ItemName" property="ColumnWidth" value="17.71" type="Double" />
<column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Comment" property="Address" value="$I$4" type="String" />
<column name="Comment" property="ColumnWidth" value="21.71" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="ID" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES ('xls30','uspCashFlowYear','<?xml version="1.0" encoding="Unicode"?>
<table name="CashFlow">
<columnFormats>
<column name="" property="ListObjectName" value="CashFlow_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$5" type="String" />
<column name="N" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="N" property="Address" value="$C$5" type="String" />
<column name="Level" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Level" property="Address" value="$D$5" type="String" />
<column name="ItemType" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ItemType" property="Address" value="$E$5" type="String" />
<column name="ItemName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ItemName" property="Address" value="$F$5" type="String" />
<column name="CompanyName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="CompanyName" property="Address" value="$G$5" type="String" />
<column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Name" property="Address" value="$H$5" type="String" />
<column name="Name" property="ColumnWidth" value="27.86" type="Double" />
<column name="Total" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Total" property="Address" value="$I$5" type="String" />
<column name="Total" property="ColumnWidth" value="13.14" type="Double" />
<column name="Total" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jan" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jan" property="Address" value="$J$5" type="String" />
<column name="Jan" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jan" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Feb" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Feb" property="Address" value="$K$5" type="String" />
<column name="Feb" property="ColumnWidth" value="10.71" type="Double" />
<column name="Feb" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Mar" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mar" property="Address" value="$L$5" type="String" />
<column name="Mar" property="ColumnWidth" value="10.71" type="Double" />
<column name="Mar" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Apr" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Apr" property="Address" value="$M$5" type="String" />
<column name="Apr" property="ColumnWidth" value="10.71" type="Double" />
<column name="Apr" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="May" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="May" property="Address" value="$N$5" type="String" />
<column name="May" property="ColumnWidth" value="10.71" type="Double" />
<column name="May" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jun" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jun" property="Address" value="$O$5" type="String" />
<column name="Jun" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jun" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jul" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jul" property="Address" value="$P$5" type="String" />
<column name="Jul" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jul" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Aug" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Aug" property="Address" value="$Q$5" type="String" />
<column name="Aug" property="ColumnWidth" value="10.71" type="Double" />
<column name="Aug" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Sep" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sep" property="Address" value="$R$5" type="String" />
<column name="Sep" property="ColumnWidth" value="10.71" type="Double" />
<column name="Sep" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Oct" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Oct" property="Address" value="$S$5" type="String" />
<column name="Oct" property="ColumnWidth" value="10.71" type="Double" />
<column name="Oct" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Nov" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Nov" property="Address" value="$T$5" type="String" />
<column name="Nov" property="ColumnWidth" value="10.71" type="Double" />
<column name="Nov" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Dec" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Dec" property="Address" value="$U$5" type="String" />
<column name="Dec" property="ColumnWidth" value="10.71" type="Double" />
<column name="Dec" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$5:$U$21" type="String" />
<column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="_RowNum" property="FormatConditions(1).Formula1" value="=$D5=3" type="String" />
<column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="_RowNum" property="FormatConditions(2).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(2).AppliesTo.Address" value="$B$5:$U$21" type="String" />
<column name="_RowNum" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Priority" value="5" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Formula1" value="=$D5=1" type="String" />
<column name="_RowNum" property="FormatConditions(2).Font.Bold" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(2).Interior.Color" value="15853276" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.ThemeColor" value="5" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.TintAndShade" value="0.799981688894314" type="Double" />
<column name="_RowNum" property="FormatConditions(3).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(3).AppliesTo.Address" value="$B$5:$U$21" type="String" />
<column name="_RowNum" property="FormatConditions(3).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Priority" value="6" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Formula1" value="=$D5=2" type="String" />
<column name="_RowNum" property="FormatConditions(3).Font.Color" value="16777215" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Font.ThemeColor" value="1" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Font.Bold" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(3).Interior.Color" value="6299648" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="7" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES ('xls30','uspCashFlowYearSummary','<?xml version="1.0" encoding="Unicode"?>
<table name="CashFlowSummary">
<columnFormats>
<column name="" property="ListObjectName" value="CashFlow_Table134" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$5" type="String" />
<column name="N" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="N" property="Address" value="$C$5" type="String" />
<column name="Level" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Level" property="Address" value="$D$5" type="String" />
<column name="ItemType" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ItemType" property="Address" value="$E$5" type="String" />
<column name="ItemName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ItemName" property="Address" value="$F$5" type="String" />
<column name="CompanyName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="CompanyName" property="Address" value="$G$5" type="String" />
<column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Name" property="Address" value="$H$5" type="String" />
<column name="Name" property="ColumnWidth" value="27.86" type="Double" />
<column name="Total" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Total" property="Address" value="$I$5" type="String" />
<column name="Total" property="ColumnWidth" value="13.14" type="Double" />
<column name="Total" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jan" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jan" property="Address" value="$J$5" type="String" />
<column name="Jan" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jan" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Feb" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Feb" property="Address" value="$K$5" type="String" />
<column name="Feb" property="ColumnWidth" value="11" type="Double" />
<column name="Feb" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Mar" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mar" property="Address" value="$L$5" type="String" />
<column name="Mar" property="ColumnWidth" value="10.71" type="Double" />
<column name="Mar" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Apr" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Apr" property="Address" value="$M$5" type="String" />
<column name="Apr" property="ColumnWidth" value="10.71" type="Double" />
<column name="Apr" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="May" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="May" property="Address" value="$N$5" type="String" />
<column name="May" property="ColumnWidth" value="10.71" type="Double" />
<column name="May" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jun" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jun" property="Address" value="$O$5" type="String" />
<column name="Jun" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jun" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jul" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jul" property="Address" value="$P$5" type="String" />
<column name="Jul" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jul" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Aug" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Aug" property="Address" value="$Q$5" type="String" />
<column name="Aug" property="ColumnWidth" value="10.71" type="Double" />
<column name="Aug" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Sep" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sep" property="Address" value="$R$5" type="String" />
<column name="Sep" property="ColumnWidth" value="10.71" type="Double" />
<column name="Sep" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Oct" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Oct" property="Address" value="$S$5" type="String" />
<column name="Oct" property="ColumnWidth" value="10.71" type="Double" />
<column name="Oct" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Nov" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Nov" property="Address" value="$T$5" type="String" />
<column name="Nov" property="ColumnWidth" value="10.71" type="Double" />
<column name="Nov" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Dec" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Dec" property="Address" value="$U$5" type="String" />
<column name="Dec" property="ColumnWidth" value="10.71" type="Double" />
<column name="Dec" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$5:$U$13" type="String" />
<column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="_RowNum" property="FormatConditions(1).Formula1" value="=$D5=3" type="String" />
<column name="_RowNum" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="_RowNum" property="FormatConditions(2).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(2).AppliesTo.Address" value="$B$5:$U$13" type="String" />
<column name="_RowNum" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Priority" value="5" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Formula1" value="=$D5=1" type="String" />
<column name="_RowNum" property="FormatConditions(2).Interior.Color" value="16777215" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.Pattern" value="-4142" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.PatternThemeColor" value="-4142" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.ThemeColor" value="-4142" type="Double" />
<column name="_RowNum" property="FormatConditions(3).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(3).AppliesTo.Address" value="$B$5:$U$13" type="String" />
<column name="_RowNum" property="FormatConditions(3).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Priority" value="6" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Formula1" value="=$D5=2" type="String" />
<column name="_RowNum" property="FormatConditions(3).Font.Color" value="16777215" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Font.ThemeColor" value="1" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Font.Bold" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(3).Interior.Color" value="6299648" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="7" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
</table>
');
GO

print N'The application has been installed';
GO
