CREATE SCHEMA [dbo30] AUTHORIZATION [dbo]
GO
CREATE SCHEMA [xls30] AUTHORIZATION [dbo]
GO
CREATE SCHEMA [etl30] AUTHORIZATION [dbo]
GO

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo30].[Payment](
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [Date] [datetime] NULL,
    [Sum] [money] NULL,
    [AccountName] [nvarchar](50) NULL,
    [CompanyName] [nvarchar](50) NULL,
    [ItemName] [nvarchar](50) NULL,
    [Comment] [nvarchar](50) NULL,
 CONSTRAINT [PK_Payment_dbo30] PRIMARY KEY CLUSTERED 
(
    [ID] ASC
)WITH (STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF)
)

GO

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: CashFlow report
-- =============================================

CREATE PROCEDURE [xls30].[uspCashFlow]
    WITH EXECUTE AS SELF
AS
BEGIN

    DECLARE @List varchar(MAX)

    SELECT @List = (
        SELECT ', [' + Period + ']' FROM (
            SELECT DISTINCT Period FROM dbo30.viewCashFlowData
            ) AS t ORDER BY Period
        FOR XML PATH('')
        )
    SET @List = STUFF(@List, 1, 2, '')

    -- PRINT(@List)

    DECLARE @Query varchar(MAX)

    SET @Query = '
    SELECT
        N
        , Level = CASE WHEN ItemName IS NULL THEN 0 WHEN CompanyName IS NULL THEN 1 ELSE 2 END
        , ItemType, ItemName, CompanyName
        , Name = COALESCE(''    '' + CompanyName, ''  '' + ItemName, ItemType)
        , ' + @List + '
    FROM
        (
            SELECT N, ItemType, ItemName, CompanyName, Period, [Sum]
            FROM dbo30.viewCashFlowData
        ) s
        PIVOT
        (
            SUM([Sum]) FOR [Period] IN ('+ @List + ')
        ) p
    ORDER BY
        N, ItemType, ItemName, CompanyName
    '

    -- PRINT(@Query)

    EXEC(@Query)

END


GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: CashFlow summary report
-- =============================================

CREATE PROCEDURE [xls30].[uspCashFlowSummary]
    WITH EXECUTE AS SELF
AS
BEGIN

    DECLARE @List varchar(MAX)

    SELECT @List = (
        SELECT ', [' + Period + ']' FROM (
            SELECT DISTINCT Period FROM dbo30.viewCashFlowData
            ) AS t ORDER BY Period
        FOR XML PATH('')
        )
    SET @List = STUFF(@List, 1, 2, '')

    -- PRINT(@List)

    DECLARE @Query varchar(MAX)

    SET @Query = '
    SELECT
        N
        , Level = CASE WHEN ItemName IS NULL THEN 0 WHEN CompanyName IS NULL THEN 1 ELSE 2 END
        , ItemType, ItemName, CompanyName
        , Name = COALESCE(''    '' + CompanyName, ''  '' + ItemName, ItemType)
        , ' + @List + '
    FROM
        (
            SELECT N, ItemType, ItemName, CompanyName, Period, [Sum]
            FROM dbo30.viewCashFlowData
            WHERE CompanyName IS NULL
        ) s
        PIVOT
        (
            SUM([Sum]) FOR [Period] IN ('+ @List + ')
        ) p
    ORDER BY
        N, ItemType, ItemName, CompanyName
    '

    -- PRINT(@Query)

    EXEC(@Query)

END


GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Year CashFlow report
-- =============================================

CREATE PROCEDURE [xls30].[uspCashFlowYear]
    @Year int = NULL
    WITH EXECUTE AS SELF
AS
BEGIN

    SET NOCOUNT ON
    
    IF @Year IS NULL SET @Year = YEAR((SELECT MAX([Date]) FROM dbo30.Payment))
    IF @Year IS NULL SET @Year = YEAR(GETDATE())

    SET LANGUAGE us_english
    
    SELECT
        N
        , [Level] = CASE WHEN ItemName IS NULL THEN 0 WHEN CompanyName IS NULL THEN 1 ELSE 2 END
        , ItemType, ItemName, CompanyName
        , Name = COALESCE('    ' + CompanyName, '  ' + ItemName, ItemType)
        , [Jan], [Feb], [Mar], [Apr], [May], [Jun], [Jul], [Aug], [Sep], [Oct], [Nov], [Dec]
    FROM
        (
            SELECT
                N, ItemType, ItemName, CompanyName, LEFT([Month],3) AS [Month], [Sum]
            FROM dbo30.viewCashFlowData
            WHERE
                [Year] = @Year
        ) s
        PIVOT
        (
            SUM([Sum]) FOR [Month] IN ([Jan], [Feb], [Mar], [Apr], [May], [Jun], [Jul], [Aug], [Sep], [Oct], [Nov], [Dec])
        ) p
    ORDER BY
        N, ItemType, ItemName, CompanyName
    
END



GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Year CashFlow summary report
-- =============================================

CREATE PROCEDURE [xls30].[uspCashFlowYearSummary]
    @Year int = NULL
    WITH EXECUTE AS SELF
AS
BEGIN

    SET NOCOUNT ON
    
    IF @Year IS NULL SET @Year = YEAR((SELECT MAX([Date]) FROM dbo30.Payment))
    IF @Year IS NULL SET @Year = YEAR(GETDATE())

    SET LANGUAGE us_english
    
    SELECT
        N
        , [Level] = CASE WHEN ItemName IS NULL THEN 0 WHEN CompanyName IS NULL THEN 1 ELSE 2 END
        , ItemType, ItemName, CompanyName
        , Name = COALESCE('    ' + CompanyName, '  ' + ItemName, ItemType)
        , [Jan], [Feb], [Mar], [Apr], [May], [Jun], [Jul], [Aug], [Sep], [Oct], [Nov], [Dec]
    FROM
        (
            SELECT
                N, ItemType, ItemName, CompanyName, LEFT([Month],3) AS [Month], [Sum]
            FROM dbo30.viewCashFlowData
            WHERE
                CompanyName IS NULL
                AND [Year] = @Year
        ) s
        PIVOT
        (
            SUM([Sum]) FOR [Month] IN ([Jan], [Feb], [Mar], [Apr], [May], [Jun], [Jul], [Aug], [Sep], [Oct], [Nov], [Dec])
        ) p
    ORDER BY
        N, ItemType, ItemName, CompanyName
    
END


GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Company payments
-- =============================================

CREATE PROCEDURE [xls30].[uspExcelEvent_ContextMenu_dbo30_Payment_CompanyName]
    @CompanyName nvarchar(255) = NULL
AS
BEGIN

    SET NOCOUNT ON

    SELECT
        *
    FROM
        dbo30.Payment p
    WHERE
        p.CompanyName = @CompanyName

END


GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Item payments
-- =============================================

CREATE PROCEDURE [xls30].[uspExcelEvent_ContextMenu_dbo30_Payment_ItemName]
    @ItemName nvarchar(255) = NULL
AS
BEGIN

    SET NOCOUNT ON

    SELECT
        *
    FROM
        dbo30.Payment p
    WHERE
        p.ItemName = @ItemName

END


GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: CashFlow procedure data source
-- =============================================

CREATE VIEW [dbo30].[viewCashFlowData]
AS

    WITH cte (ItemType, ItemName, CompanyName, Period, [Year], [Month], [Sum])
    AS
        (
        SELECT
            CAST(CASE WHEN p.[Sum]<0 THEN N'TOTAL DISBURSEMENTS' ELSE N'TOTAL RECEIPTS' END AS NVARCHAR(50)) AS ItemType
            , p.ItemName
            , p.CompanyName
            , CONVERT(VARCHAR(7), p.[Date], 20) AS Period
            , MAX(YEAR(p.[Date])) AS [Year]
            , MAX(DATENAME(MONTH, p.[Date])) AS [Month]
            , SUM(p.[Sum]) AS [Sum]
        FROM
            dbo30.Payment p
        GROUP BY
            ROLLUP(CONVERT(VARCHAR(7), p.[Date], 20), CASE WHEN p.[Sum]<0 THEN N'TOTAL DISBURSEMENTS' ELSE N'TOTAL RECEIPTS' END, p.ItemName, p.CompanyName)
        )

    SELECT
        1 AS N
        , N'Cash at begining of month' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , Period
        , [Year], [Month]
        , [Sum] = (
            SELECT SUM([Sum]) FROM cte t WHERE t.Period < cte.Period
                AND t.ItemType IS NULL AND t.ItemName IS NULL AND t.CompanyName IS NULL AND t.Period IS NOT NULL
            )
    FROM
        cte
    WHERE
        ItemType IS NULL AND ItemName IS NULL AND CompanyName IS NULL AND Period IS NOT NULL

    UNION
    SELECT
        5 AS N
        , N'Cash at end of month' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , Period
        , [Year], [Month]
        , [Sum] = (
            SELECT SUM([Sum]) FROM cte t WHERE t.Period <= cte.Period
                AND t.ItemType IS NULL AND t.ItemName IS NULL AND t.CompanyName IS NULL AND t.Period IS NOT NULL
            )
    FROM
        cte
    WHERE
        ItemType IS NULL AND ItemName IS NULL AND CompanyName IS NULL AND Period IS NOT NULL

    UNION
    SELECT
        CASE WHEN ItemType IS NULL THEN 4 WHEN [Sum]<0 THEN 3 ELSE 2 END AS N
        , ISNULL(ItemType, N'CASH NET CHANGE') AS ItemType
        , ItemName
        , CompanyName
        , Period
        , [Year], [Month]
        , [Sum]
    FROM
        cte
    WHERE
        Period IS NOT NULL


GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Query List of developer objects
-- =============================================

CREATE VIEW [dbo30].[viewQueryList]
AS

    SELECT
        t.TABLE_SCHEMA
        , t.TABLE_NAME
        , t.TABLE_TYPE
        , t.TABLE_CODE
        , t.INSERT_PROCEDURE
        , t.UPDATE_PROCEDURE
        , t.DELETE_PROCEDURE
        , t.PROCEDURE_TYPE
    FROM
        xls01.viewQueryList t
    WHERE
        t.TABLE_SCHEMA IN ('dbo30', 'xls30', 'xls01')


GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Year parameter values
-- =============================================

CREATE VIEW [xls30].[viewParameterValues_Year]
AS

    SELECT NULL AS [Year] UNION
    SELECT
        DISTINCT
        YEAR([Date]) AS [Year]
    FROM
        dbo30.Payment


GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Query List of user objects
-- =============================================

CREATE VIEW [xls30].[viewQueryList]
AS

    SELECT
        t.TABLE_SCHEMA
        , t.TABLE_NAME
        , t.TABLE_TYPE
        , t.TABLE_CODE
        , t.INSERT_PROCEDURE
        , t.UPDATE_PROCEDURE
        , t.DELETE_PROCEDURE
        , t.PROCEDURE_TYPE
    FROM
        xls01.viewQueryList t
    WHERE
        t.TABLE_SCHEMA IN ('dbo30', 'xls30', 'xls01')
        AND NOT t.TABLE_NAME = 'viewCashFlowData'


GO

SET NOCOUNT ON

SET IDENTITY_INSERT [dbo30].[Payment] ON 
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (1, CAST(N'2015-01-10 00:00:00.000' AS DateTime), 200000.0000, N'My Bank', N'Rose, Inc', N'Revenue', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (2, CAST(N'2015-01-10 00:00:00.000' AS DateTime), -50000.0000, N'My Bank', N'Land, Inc', N'Expenses', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (3, CAST(N'2015-01-31 00:00:00.000' AS DateTime), -87000.0000, N'My Bank', NULL, N'Payroll', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (4, CAST(N'2015-01-31 00:00:00.000' AS DateTime), -13000.0000, N'My Bank', N'Income Taxes', N'Taxes', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (5, CAST(N'2015-01-31 00:00:00.000' AS DateTime), -29580.0000, N'My Bank', N'Salary Taxes', N'Taxes', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (6, CAST(N'2015-02-10 00:00:00.000' AS DateTime), 300000.0000, N'My Bank', N'Rose, Inc', N'Revenue', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (7, CAST(N'2015-02-10 00:00:00.000' AS DateTime), 100000.0000, N'My Bank', N'Carnation, Inc', N'Revenue', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (8, CAST(N'2015-02-10 00:00:00.000' AS DateTime), -50000.0000, N'My Bank', N'Water, Inc', N'Expenses', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (9, CAST(N'2015-02-10 00:00:00.000' AS DateTime), -100000.0000, N'My Bank', N'Land, Inc', N'Expenses', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (10, CAST(N'2015-02-28 00:00:00.000' AS DateTime), -87000.0000, N'My Bank', NULL, N'Payroll', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (11, CAST(N'2015-02-28 00:00:00.000' AS DateTime), -13000.0000, N'My Bank', N'Income Taxes', N'Taxes', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (12, CAST(N'2015-02-28 00:00:00.000' AS DateTime), -29580.0000, N'My Bank', N'Salary Taxes', N'Taxes', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (13, CAST(N'2015-03-10 00:00:00.000' AS DateTime), 300000.0000, N'My Bank', N'Rose, Inc', N'Revenue', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (14, CAST(N'2015-03-10 00:00:00.000' AS DateTime), 200000.0000, N'My Bank', N'Carnation, Inc', N'Revenue', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (15, CAST(N'2015-03-10 00:00:00.000' AS DateTime), 100000.0000, N'My Bank', N'Cornflower, Corp', N'Revenue', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (16, CAST(N'2015-03-15 00:00:00.000' AS DateTime), -36000.0000, N'My Bank', N'Corporate Tax', N'Taxes', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (17, CAST(N'2015-03-31 00:00:00.000' AS DateTime), -174000.0000, N'My Bank', NULL, N'Payroll', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (18, CAST(N'2015-03-31 00:00:00.000' AS DateTime), -26000.0000, N'My Bank', N'Income Taxes', N'Taxes', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (19, CAST(N'2015-03-31 00:00:00.000' AS DateTime), -59160.0000, N'My Bank', N'Salary Taxes', N'Taxes', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (20, CAST(N'2015-03-31 00:00:00.000' AS DateTime), -50000.0000, N'My Bank', N'Water, Inc', N'Expenses', NULL)
INSERT [dbo30].[Payment] ([ID], [Date], [Sum], [AccountName], [CompanyName], [ItemName], [Comment]) VALUES (21, CAST(N'2015-03-31 00:00:00.000' AS DateTime), -100000.0000, N'My Bank', N'Land, Inc', N'Expenses', NULL)
SET IDENTITY_INSERT [dbo30].[Payment] OFF

SET NOCOUNT ON

INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'dbo30', N'Payment', 'en', N'Payments', N'Payments', N'This example shows the core features of database data editing.
Add, update or delete rows and then click the Save to DB button at the SaveToDB tab.
The data will be updated is the SQL Azure database and available for
authorized users over the world.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'dbo30', N'viewCashFlowData', 'en', NULL, N'Data Source for CashFlow', N'Data source view for CashFlow stored procedures');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'dbo30', N'viewQueryList', 'en', N'Payments Register Development', N'Payments Developer Objects', N'This configuration view defines database objects that are showed in the Ribbon Query List and configures
INSERT, UPDATE and DELETE procedures to save changes of Excel tables based on views and stored procedures.');

INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls30', N'uspCashFlow', 'en', N'CashFlow', N'CashFlow', N'This example shows the power of the SQL reports.
The reports like this cannot be implemented using the Excel pivot tables.
In addition, the report data are stored in the SQL Azure database and can be updated by
authorized users over the world.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls30', N'uspCashFlowSummary', 'en', N'CashFlow Summary', N'CashFlow Summary', N'This example shows the power of the SQL reports.
The reports like this cannot be implemented using the Excel pivot tables.
In addition, the report data are stored in the SQL Azure database and can be updated by
authorized users over the world.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls30', N'uspCashFlowYear', 'en', N'CashFlow Year', N'CashFlow', N'This example shows the power of the SQL reports.
The reports like this cannot be implemented using the Excel pivot tables.
In addition, the report data are stored in the SQL Azure database and can be updated by
authorized users over the world.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls30', N'uspCashFlowYearSummary', 'en', N'CashFlow Year Summary', N'CashFlow Summary', N'This example shows the power of the SQL reports.
The reports like this cannot be implemented using the Excel pivot tables.
In addition, the report data are stored in the SQL Azure database and can be updated by
authorized users over the world.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls30', N'uspExcelEvent_ContextMenu_dbo30_Payment_CompanyName', 'en', N'Company Payments', NULL, N'This is a drill-down query example.
The stored procedure is used as Excel event handler.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls30', N'uspExcelEvent_ContextMenu_dbo30_Payment_ItemName', 'en', N'Item Payments', NULL, N'This is a drill-down query example.
The stored procedure is used as Excel event handler.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls30', N'viewQueryList', 'en', N'Payments Register', N'Payments User Objects', N'This configuration view defines database objects that are showed in the Ribbon Query List and configures
INSERT, UPDATE and DELETE procedures to save changes of Excel tables based on views and stored procedures.');

INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', N'Payment', N'AccountName', 'en', N'Account Name', NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', N'Payment', N'Comment', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', N'Payment', N'CompanyName', 'en', N'Company Name', NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', N'Payment', N'Date', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', N'Payment', N'ID', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', N'Payment', N'ItemName', 'en', N'Item Name', NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', N'Payment', N'Sum', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo30', NULL, N'Name', 'en', NULL, NULL);

INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Apr', 'en', NULL, N'April');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Aug', 'en', NULL, N'August');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Dec', 'en', NULL, N'December');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Feb', 'en', NULL, N'February');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Jan', 'en', NULL, N'January');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Jul', 'en', NULL, N'July');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Jun', 'en', NULL, N'June');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Mar', 'en', NULL, N'March');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'May', 'en', NULL, N'May');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Nov', 'en', NULL, N'November');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Oct', 'en', NULL, N'October');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls30', NULL, N'Sep', 'en', NULL, N'September');


INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo30', N'Payment', NULL, N'Actions', N'xls30', N'uspExcelEvent_ContextMenu_dbo30_Payment_CompanyName', N'PROCEDURE', NULL, NULL, 1, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo30', N'Payment', NULL, N'Actions', N'xls30', N'uspExcelEvent_ContextMenu_dbo30_Payment_ItemName', N'PROCEDURE', NULL, NULL, 2, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo30', N'Payment', NULL, N'ContextMenu', N'xls30', N'uspExcelEvent_ContextMenu_dbo30_Payment_CompanyName', N'PROCEDURE', NULL, NULL, 1, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo30', N'Payment', NULL, N'ContextMenu', N'xls30', N'uspExcelEvent_ContextMenu_dbo30_Payment_ItemName', N'PROCEDURE', NULL, NULL, 2, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls30', N'uspCashFlow', NULL, N'ContextMenu', N'xls30', N'uspExcelEvent_ContextMenu_dbo30_Payment_CompanyName', N'PROCEDURE', NULL, NULL, 1, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls30', N'uspCashFlow', NULL, N'ContextMenu', N'xls30', N'uspExcelEvent_ContextMenu_dbo30_Payment_ItemName', N'PROCEDURE', NULL, NULL, 2, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls30', N'uspCashFlowSummary', NULL, N'ContextMenu', N'xls30', N'uspExcelEvent_ContextMenu_dbo30_Payment_ItemName', N'PROCEDURE', NULL, NULL, 2, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls30', N'uspCashFlowYearSummary', NULL, N'ContextMenu', N'xls30', N'uspExcelEvent_ContextMenu_dbo30_Payment_ItemName', N'PROCEDURE', NULL, NULL, 2, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls30', N'uspCashFlowYear', NULL, N'ContextMenu', N'xls30', N'uspExcelEvent_ContextMenu_dbo30_Payment_CompanyName', N'PROCEDURE', NULL, NULL, 1, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls30', N'uspCashFlowYear', NULL, N'ContextMenu', N'xls30', N'uspExcelEvent_ContextMenu_dbo30_Payment_ItemName', N'PROCEDURE', NULL, NULL, 2, NULL, 1);

INSERT INTO [dbo01].[ParameterValues] ([TABLE_SCHEMA], [TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE]) VALUES (N'xls30', N'uspCashFlowYear', N'Year', N'xls30', N'viewParameterValues_Year', N'VIEW');
INSERT INTO [dbo01].[ParameterValues] ([TABLE_SCHEMA], [TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE]) VALUES (N'xls30', N'uspCashFlowYearSummary', N'Year', N'xls30', N'viewParameterValues_Year', N'VIEW');


INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo30', N'Payment', '<table name="dbo30.Payment"><columnFormats><column name="" property="ListObjectName" value="Payments_Table" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$8" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$8" type="String"/><column name="ID" property="ColumnWidth" value="0.08" type="Double"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="Address" value="$D$8" type="String"/><column name="Date" property="ColumnWidth" value="9.29" type="Double"/><column name="Date" property="NumberFormat" value="m/d/yyyy" type="String"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="Address" value="$E$8" type="String"/><column name="Sum" property="ColumnWidth" value="11.71" type="Double"/><column name="Sum" property="NumberFormat" value="#,##0.00_);[Red](#,##0.00)" type="String"/><column name="AccountName" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="AccountName" property="Address" value="$F$8" type="String"/><column name="AccountName" property="ColumnWidth" value="15.57" type="Double"/><column name="CompanyName" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="CompanyName" property="Address" value="$G$8" type="String"/><column name="CompanyName" property="ColumnWidth" value="16.71" type="Double"/><column name="ItemName" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemName" property="Address" value="$H$8" type="String"/><column name="ItemName" property="ColumnWidth" value="12.43" type="Double"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="Address" value="$I$8" type="String"/><column name="Comment" property="ColumnWidth" value="11.29" type="Double"/><column name="SortFields(1)" property="KeyfieldName" value="Date" type="String"/><column name="SortFields(1)" property="SortOn" value="0" type="Double"/><column name="SortFields(1)" property="Order" value="1" type="Double"/><column name="SortFields(1)" property="DataOption" value="0" type="Double"/><column name="SortFields(2)" property="KeyfieldName" value="Sum" type="String"/><column name="SortFields(2)" property="SortOn" value="0" type="Double"/><column name="SortFields(2)" property="Order" value="2" type="Double"/><column name="SortFields(2)" property="DataOption" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'xls30', N'uspCashFlow', '<table name="xls30.uspCashFlow"><columnFormats><column name="" property="ListObjectName" value="CashFlow_Table" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$8" type="String"/><column name="N" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="N" property="Address" value="$C$8" type="String"/><column name="N" property="ColumnWidth" value="0.08" type="Double"/><column name="Level" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="Level" property="Address" value="$D$8" type="String"/><column name="ItemType" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ItemType" property="Address" value="$E$8" type="String"/><column name="ItemName" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ItemName" property="Address" value="$F$8" type="String"/><column name="CompanyName" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="CompanyName" property="Address" value="$G$8" type="String"/><column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Name" property="Address" value="$H$8" type="String"/><column name="Name" property="ColumnWidth" value="23.71" type="Double"/><column name="2015-01" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="2015-01" property="Address" value="$I$8" type="String"/><column name="2015-01" property="ColumnWidth" value="9.29" type="Double"/><column name="2015-01" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="2015-02" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="2015-02" property="Address" value="$J$8" type="String"/><column name="2015-02" property="ColumnWidth" value="9.29" type="Double"/><column name="2015-02" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="2015-03" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="2015-03" property="Address" value="$K$8" type="String"/><column name="2015-03" property="ColumnWidth" value="9.29" type="Double"/><column name="2015-03" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'xls30', N'uspCashFlowSummary', '<table name="xls30.uspCashFlowSummary"><columnFormats><column name="" property="ListObjectName" value="CashFlowSummary_Table" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$8" type="String"/><column name="N" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="N" property="Address" value="$C$8" type="String"/><column name="N" property="ColumnWidth" value="0.08" type="Double"/><column name="Level" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="Level" property="Address" value="$D$8" type="String"/><column name="ItemType" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ItemType" property="Address" value="$E$8" type="String"/><column name="ItemName" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ItemName" property="Address" value="$F$8" type="String"/><column name="CompanyName" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="CompanyName" property="Address" value="$G$8" type="String"/><column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Name" property="Address" value="$H$8" type="String"/><column name="Name" property="ColumnWidth" value="23.71" type="Double"/><column name="2015-01" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="2015-01" property="Address" value="$I$8" type="String"/><column name="2015-01" property="ColumnWidth" value="9.29" type="Double"/><column name="2015-01" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="2015-02" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="2015-02" property="Address" value="$J$8" type="String"/><column name="2015-02" property="ColumnWidth" value="9.29" type="Double"/><column name="2015-02" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="2015-03" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="2015-03" property="Address" value="$K$8" type="String"/><column name="2015-03" property="ColumnWidth" value="9.29" type="Double"/><column name="2015-03" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'xls30', N'uspCashFlowYear', '<table name="xls30.uspCashFlowYear"><columnFormats><column name="" property="ListObjectName" value="Reports_Table" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$8" type="String"/><column name="N" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="N" property="Address" value="$C$8" type="String"/><column name="N" property="ColumnWidth" value="0.08" type="Double"/><column name="Level" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="Level" property="Address" value="$D$8" type="String"/><column name="ItemType" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ItemType" property="Address" value="$E$8" type="String"/><column name="ItemName" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ItemName" property="Address" value="$F$8" type="String"/><column name="CompanyName" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="CompanyName" property="Address" value="$G$8" type="String"/><column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Name" property="Address" value="$H$8" type="String"/><column name="Name" property="ColumnWidth" value="23.71" type="Double"/><column name="Jan" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Jan" property="Address" value="$I$8" type="String"/><column name="Jan" property="ColumnWidth" value="8.29" type="Double"/><column name="Jan" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Feb" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Feb" property="Address" value="$J$8" type="String"/><column name="Feb" property="ColumnWidth" value="8.29" type="Double"/><column name="Feb" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Mar" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Mar" property="Address" value="$K$8" type="String"/><column name="Mar" property="ColumnWidth" value="8.29" type="Double"/><column name="Mar" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Apr" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Apr" property="Address" value="$L$8" type="String"/><column name="Apr" property="ColumnWidth" value="5.71" type="Double"/><column name="Apr" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="May" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="May" property="Address" value="$M$8" type="String"/><column name="May" property="ColumnWidth" value="6.43" type="Double"/><column name="May" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Jun" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Jun" property="Address" value="$N$8" type="String"/><column name="Jun" property="ColumnWidth" value="5.57" type="Double"/><column name="Jun" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Jul" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Jul" property="Address" value="$O$8" type="String"/><column name="Jul" property="ColumnWidth" value="5" type="Double"/><column name="Jul" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Aug" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Aug" property="Address" value="$P$8" type="String"/><column name="Aug" property="ColumnWidth" value="6" type="Double"/><column name="Aug" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Sep" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sep" property="Address" value="$Q$8" type="String"/><column name="Sep" property="ColumnWidth" value="5.86" type="Double"/><column name="Sep" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Oct" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Oct" property="Address" value="$R$8" type="String"/><column name="Oct" property="ColumnWidth" value="5.57" type="Double"/><column name="Oct" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Nov" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Nov" property="Address" value="$S$8" type="String"/><column name="Nov" property="ColumnWidth" value="6.14" type="Double"/><column name="Nov" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Dec" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Dec" property="Address" value="$T$8" type="String"/><column name="Dec" property="ColumnWidth" value="5.86" type="Double"/><column name="Dec" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'xls30', N'uspCashFlowYearSummary', '<table name="xls30.uspCashFlowYearSummary"><columnFormats><column name="" property="ListObjectName" value="Reports_Table" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$8" type="String"/><column name="N" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="N" property="Address" value="$C$8" type="String"/><column name="N" property="ColumnWidth" value="0.08" type="Double"/><column name="Level" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="Level" property="Address" value="$D$8" type="String"/><column name="ItemType" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ItemType" property="Address" value="$E$8" type="String"/><column name="ItemName" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ItemName" property="Address" value="$F$8" type="String"/><column name="CompanyName" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="CompanyName" property="Address" value="$G$8" type="String"/><column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Name" property="Address" value="$H$8" type="String"/><column name="Name" property="ColumnWidth" value="23.71" type="Double"/><column name="Jan" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Jan" property="Address" value="$I$8" type="String"/><column name="Jan" property="ColumnWidth" value="8.29" type="Double"/><column name="Jan" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Feb" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Feb" property="Address" value="$J$8" type="String"/><column name="Feb" property="ColumnWidth" value="8.29" type="Double"/><column name="Feb" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Mar" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Mar" property="Address" value="$K$8" type="String"/><column name="Mar" property="ColumnWidth" value="8.29" type="Double"/><column name="Mar" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Apr" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Apr" property="Address" value="$L$8" type="String"/><column name="Apr" property="ColumnWidth" value="5.71" type="Double"/><column name="Apr" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="May" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="May" property="Address" value="$M$8" type="String"/><column name="May" property="ColumnWidth" value="6.43" type="Double"/><column name="May" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Jun" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Jun" property="Address" value="$N$8" type="String"/><column name="Jun" property="ColumnWidth" value="5.57" type="Double"/><column name="Jun" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Jul" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Jul" property="Address" value="$O$8" type="String"/><column name="Jul" property="ColumnWidth" value="5" type="Double"/><column name="Jul" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Aug" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Aug" property="Address" value="$P$8" type="String"/><column name="Aug" property="ColumnWidth" value="6" type="Double"/><column name="Aug" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Sep" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sep" property="Address" value="$Q$8" type="String"/><column name="Sep" property="ColumnWidth" value="5.86" type="Double"/><column name="Sep" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Oct" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Oct" property="Address" value="$R$8" type="String"/><column name="Oct" property="ColumnWidth" value="5.57" type="Double"/><column name="Oct" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Nov" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Nov" property="Address" value="$S$8" type="String"/><column name="Nov" property="ColumnWidth" value="6.14" type="Double"/><column name="Nov" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="Dec" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Dec" property="Address" value="$T$8" type="String"/><column name="Dec" property="ColumnWidth" value="5.86" type="Double"/><column name="Dec" property="NumberFormat" value="#,##0_);[Red](#,##0)" type="String"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
GO

print N'The application has been installed';
GO
