CREATE TABLE Budget(
    ID int IDENTITY(1,1) NOT NULL,
    DepartmentCode nvarchar(50) NOT NULL,
    ItemCode nvarchar(50) NOT NULL,
    [Date] datetime NOT NULL,
    Amount float NULL,
    [Sum] money NULL,
 CONSTRAINT PK_Budget PRIMARY KEY (ID)
);
GO

CREATE TABLE Department(
    Code nvarchar(50) NOT NULL,
    Name nvarchar(255) NOT NULL,
 CONSTRAINT PK_Department PRIMARY KEY (Code),
 CONSTRAINT IX_Department_Name UNIQUE (Name)
);
GO

CREATE TABLE Item(
    Code nvarchar(50) NOT NULL,
    Name nvarchar(255) NOT NULL,
 CONSTRAINT PK_Item PRIMARY KEY (Code),
 CONSTRAINT IX_Item_Name UNIQUE (Name)
);
GO

CREATE TABLE Period(
    [Date] datetime NOT NULL,
    Name nvarchar(50) NOT NULL,
 CONSTRAINT PK_Period PRIMARY KEY (Date),
 CONSTRAINT IX_Period_Name UNIQUE (Name)
);
GO

ALTER TABLE Budget ADD CONSTRAINT FK_Budget_Department
FOREIGN KEY(DepartmentCode) REFERENCES Department (Code)
ON UPDATE CASCADE;
GO

ALTER TABLE Budget ADD CONSTRAINT FK_Budget_Item
FOREIGN KEY(ItemCode) REFERENCES Item (Code)
ON UPDATE CASCADE;
GO

ALTER TABLE Budget ADD CONSTRAINT FK_Budget_Period
FOREIGN KEY([Date]) REFERENCES Period ([Date])
ON UPDATE CASCADE;
GO

CREATE TABLE [QueryListBudget] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [TABLE_TYPE] [nvarchar](128) NOT NULL,
    [TABLE_CODE] [ntext],
    [INSERT_PROCEDURE] [ntext],
    [UPDATE_PROCEDURE] [ntext],
    [DELETE_PROCEDURE] [ntext],
    [PROCEDURE_TYPE] [nvarchar](128),
  CONSTRAINT [PK_QueryList] PRIMARY KEY ([ID])
);
GO
CREATE UNIQUE INDEX [QueryListBudget_TableName]
    ON [QueryListBudget] (
    [TABLE_NAME]
);
GO

INSERT INTO [QueryListBudget] ([TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'Budget', N'TABLE', NULL, NULL, NULL, NULL, NULL);
GO
INSERT INTO [QueryListBudget] ([TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'Department', N'TABLE', NULL, NULL, NULL, NULL, NULL);
GO
INSERT INTO [QueryListBudget] ([TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'Item', N'TABLE', NULL, NULL, NULL, NULL, NULL);
GO
INSERT INTO [QueryListBudget] ([TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'Period', N'TABLE', NULL, NULL, NULL, NULL, NULL);
GO

INSERT INTO [QueryList] ([TABLE_NAME], [TABLE_TYPE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [TABLE_CODE]) VALUES (N'BudgetFormBase',N'CODE',N'Budget', N'Budget', N'Budget', N'SELECT
    b.ID
    , d.Code AS DepartmentCode
    , i.Code AS ItemCode
    , CASE WHEN LEN(i.Code) > 2 THEN ''    '' + i.Name WHEN SUBSTRING(i.Code, LEN(i.Code), 1) = ''0'' THEN i.Name ELSE ''  '' + i.Name END AS ItemName
    , CAST(p.[Date] AS datetime) AS [Date]
    , b.Amount
    , b.[Sum]
FROM
    Department d
    CROSS JOIN Period p
    CROSS JOIN Item i
    LEFT OUTER JOIN Budget b ON p.[Date] = b.[Date] AND d.Code = b.DepartmentCode AND i.Code = b.ItemCode
WHERE
    d.Code = COALESCE(@DepartmentCode, d.Code)
    AND i.Code = COALESCE(@ItemCode, i.Code)
    AND p.[Date] = COALESCE(@Date, p.[Date])
ORDER BY
    DepartmentCode
    , [Date]
    , ItemCode
');
GO

INSERT INTO [QueryList] ([TABLE_NAME], [TABLE_TYPE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [TABLE_CODE]) VALUES (N'BudgetFormBase',N'CODE',N'Budget', N'Budget', N'Budget', N'SELECT
    ID
    , DepartmentCode
    , ItemCode
    , ItemName
    , [Date]
    , Amount
    , [Sum]
FROM
    (
SELECT
    NULL AS ID
    , d.Code AS DepartmentCode
    , NULL AS ItemCode
    , NULL AS ItemName
    , NULL AS [Date]
    , CAST(NULL AS float) AS Amount
    , NULL AS [Sum]
    , 1 AS IsAxis
FROM
    Department d
WHERE
    d.Code = COALESCE(@DepartmentCode, d.Code)

UNION ALL
SELECT
    NULL AS ID
    , NULL AS DepartmentCode
    , i.Code AS ItemCode
    , CASE WHEN LEN(i.Code) > 2 THEN ''    '' + i.Name WHEN SUBSTRING(i.Code, LEN(i.Code), 1) = ''0'' THEN i.Name ELSE ''  '' + i.Name END AS ItemName
    , NULL AS [Date]
    , CAST(NULL AS float) AS Amount
    , NULL AS [Sum]
    , 1 AS IsAxis
FROM
    Item i
WHERE
    i.Code = COALESCE(@ItemCode, i.Code)

UNION ALL
SELECT
    NULL AS ID
    , NULL AS DepartmentCode
    , NULL AS ItemCode
    , NULL AS ItemName
    , CAST(p.[Date] AS datetime) AS [Date]
    , CAST(NULL AS float) AS Amount
    , NULL AS [Sum]
    , 1 AS IsAxis
FROM
    Period p
WHERE
    p.[Date] = COALESCE(@Date, p.[Date])

UNION ALL
SELECT
    b.ID
    , d.Code AS DepartmentCode
    , i.Code AS ItemCode
    , CASE WHEN LEN(i.Code) > 2 THEN ''    '' + i.Name WHEN SUBSTRING(i.Code, LEN(i.Code), 1) = ''0'' THEN i.Name ELSE ''  '' + i.Name END AS ItemName
    , CAST(p.[Date] AS datetime) AS [Date]
    , b.Amount
    , b.[Sum]
    , NULL AS IsAxis
FROM
    Budget b
    LEFT OUTER JOIN Department d ON d.Code = b.DepartmentCode
    LEFT OUTER JOIN Period p ON p.[Date] = b.[Date]
    LEFT OUTER JOIN Item i ON i.Code = b.ItemCode
WHERE
    d.Code = COALESCE(@DepartmentCode, d.Code)
    AND p.[Date] = COALESCE(@Date, p.[Date])
    AND i.Code = COALESCE(@ItemCode, i.Code)
) t
ORDER BY
    IsAxis DESC
    , [Date]
    , ItemCode
    , DepartmentCode
');
GO

INSERT INTO [ParameterValues] ([TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE], [SELECT_CODE]) VALUES (N'BudgetFormBase', N'DepartmentCode', N'code47', N'Department', N'CODE', N'SELECT NULL AS [Code], NULL AS [Name] UNION ALL SELECT [Code], [Name] FROM Department ORDER BY [Code]');
GO
INSERT INTO [ParameterValues] ([TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE], [SELECT_CODE]) VALUES (N'BudgetFormBase', N'ItemCode', N'code47', N'Item', N'CODE', N'SELECT NULL AS [Code], NULL AS [Name] UNION ALL SELECT [Code], [Name] FROM Item ORDER BY [Code]');
GO
INSERT INTO [ParameterValues] ([TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE], [SELECT_CODE]) VALUES (N'BudgetFormBase', N'Date', N'code47', N'Period', N'CODE', N'SELECT NULL AS [Date] UNION ALL SELECT [Date] FROM Period ORDER BY [Date]');
GO

INSERT INTO [ParameterValues] ([TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE], [SELECT_CODE]) VALUES (N'BudgetFormBase2', N'DepartmentCode', N'code47', N'Department', N'CODE', N'SELECT NULL AS [Code], NULL AS [Name] UNION ALL SELECT [Code], [Name] FROM Department ORDER BY [Code]');
GO
INSERT INTO [ParameterValues] ([TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE], [SELECT_CODE]) VALUES (N'BudgetFormBase2', N'ItemCode', N'code47', N'Item', N'CODE', N'SELECT NULL AS [Code], NULL AS [Name] UNION ALL SELECT [Code], [Name] FROM Item ORDER BY [Code]');
GO
INSERT INTO [ParameterValues] ([TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE], [SELECT_CODE]) VALUES (N'BudgetFormBase2', N'Date', N'code47', N'Period', N'CODE', N'SELECT NULL AS [Date] UNION ALL SELECT [Date] FROM Period ORDER BY [Date]');
GO

INSERT INTO [TableFormats] ([TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'BudgetFormBase', '<table name="BudgetFormBase"><columnFormats><column name="" property="ListObjectName" value="BaseForm" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$4" type="String"/><column name="_RowNum" property="NumberFormat" value="General" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$4" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="NumberFormat" value="General" type="String"/><column name="DepartmentCode" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="DepartmentCode" property="Address" value="$D$4" type="String"/><column name="DepartmentCode" property="ColumnWidth" value="18" type="Double"/><column name="DepartmentCode" property="NumberFormat" value="General" type="String"/><column name="ItemCode" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemCode" property="Address" value="$E$4" type="String"/><column name="ItemCode" property="ColumnWidth" value="18.86" type="Double"/><column name="ItemCode" property="NumberFormat" value="@" type="String"/><column name="ItemName" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemName" property="Address" value="$F$4" type="String"/><column name="ItemName" property="ColumnWidth" value="27.29" type="Double"/><column name="ItemName" property="NumberFormat" value="General" type="String"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="Address" value="$G$4" type="String"/><column name="Date" property="ColumnWidth" value="11.29" type="Double"/><column name="Date" property="NumberFormat" value="m/d/yyyy" type="String"/><column name="Amount" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Amount" property="Address" value="$H$4" type="String"/><column name="Amount" property="ColumnWidth" value="11.14" type="Double"/><column name="Amount" property="NumberFormat" value="General" type="String"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="Address" value="$I$4" type="String"/><column name="Sum" property="ColumnWidth" value="10.86" type="Double"/><column name="Sum" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats><pivotviews><view name="Items * Departments"><column name="" property="TableStyle2.Name" value="PivotStyleMedium18" type="String"/><column name="" property="LayoutRowDefault" value="1" type="Double"/><column name="" property="GrandTotalName" value="Grand Total" type="String"/><column name="" property="ColumnGrand" value="True" type="Boolean"/><column name="" property="DisplayFieldCaptions" value="True" type="Boolean"/><column name="" property="DisplayImmediateItems" value="True" type="Boolean"/><column name="" property="DisplayNullString" value="True" type="Boolean"/><column name="" property="EnableDataValueEditing" value="True" type="Boolean"/><column name="" property="EnableDrilldown" value="True" type="Boolean"/><column name="" property="EnableFieldDialog" value="True" type="Boolean"/><column name="" property="EnableFieldList" value="True" type="Boolean"/><column name="" property="EnableWizard" value="True" type="Boolean"/><column name="" property="ShowTableStyleColumnHeaders" value="True" type="Boolean"/><column name="" property="ShowTableStyleLastColumn" value="True" type="Boolean"/><column name="" property="SortUsingCustomLists" value="True" type="Boolean"/><column name="" property="VisualTotals" value="True" type="Boolean"/><column name="DepartmentCode" property="Name" value="DepartmentCode" type="String"/><column name="DepartmentCode" property="Orientation" value="2" type="Double"/><column name="DepartmentCode" property="Position" value="1" type="Double"/><column name="DepartmentCode" property="Subtotals" value="False" type="Boolean"/><column name="DepartmentCode" property="AutoSortOrder" value="-4135" type="Double"/><column name="DepartmentCode" property="AutoSortField" value="DepartmentCode" type="String"/><column name="DepartmentCode" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="DepartmentCode" property="HorizontalAlignment" value="1" type="Double"/><column name="ItemCode" property="Name" value="ItemCode" type="String"/><column name="ItemCode" property="Orientation" value="1" type="Double"/><column name="ItemCode" property="Position" value="1" type="Double"/><column name="ItemCode" property="Subtotals" value="False" type="Boolean"/><column name="ItemCode" property="AutoSortOrder" value="1" type="Double"/><column name="ItemCode" property="AutoSortField" value="ItemCode" type="String"/><column name="ItemCode" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="ItemCode" property="ColumnWidth" value="11.29" type="Double"/><column name="ItemName" property="Name" value="ItemName" type="String"/><column name="ItemName" property="Orientation" value="1" type="Double"/><column name="ItemName" property="Position" value="2" type="Double"/><column name="ItemName" property="Subtotals" value="False" type="Boolean"/><column name="ItemName" property="AutoSortOrder" value="-4135" type="Double"/><column name="ItemName" property="AutoSortField" value="ItemName" type="String"/><column name="ItemName" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="ItemName" property="ColumnWidth" value="26.86" type="Double"/><column name="Sum of Sum" property="Name" value="Sum of Sum" type="String"/><column name="Sum of Sum" property="SourceName" value="Sum" type="String"/><column name="Sum of Sum" property="Orientation" value="4" type="Double"/><column name="Sum of Sum" property="Position" value="1" type="Double"/><column name="Sum of Sum" property="NumberFormat" value="#,##0" type="String"/><column name="Sum of Sum" property="Function" value="-4157" type="Double"/><column name="Sum of Sum" property="ColumnWidth" value="9.29" type="Double"/></view><view name="Items * Periods"><column name="" property="TableStyle2.Name" value="PivotStyleMedium18" type="String"/><column name="" property="LayoutRowDefault" value="1" type="Double"/><column name="" property="GrandTotalName" value="Grand Total" type="String"/><column name="" property="ColumnGrand" value="True" type="Boolean"/><column name="" property="DisplayFieldCaptions" value="True" type="Boolean"/><column name="" property="DisplayImmediateItems" value="True" type="Boolean"/><column name="" property="DisplayNullString" value="True" type="Boolean"/><column name="" property="EnableDataValueEditing" value="True" type="Boolean"/><column name="" property="EnableDrilldown" value="True" type="Boolean"/><column name="" property="EnableFieldDialog" value="True" type="Boolean"/><column name="" property="EnableFieldList" value="True" type="Boolean"/><column name="" property="EnableWizard" value="True" type="Boolean"/><column name="" property="ShowTableStyleColumnHeaders" value="True" type="Boolean"/><column name="" property="ShowTableStyleLastColumn" value="True" type="Boolean"/><column name="" property="SortUsingCustomLists" value="True" type="Boolean"/><column name="" property="VisualTotals" value="True" type="Boolean"/><column name="ItemCode" property="Name" value="ItemCode" type="String"/><column name="ItemCode" property="Orientation" value="1" type="Double"/><column name="ItemCode" property="Position" value="1" type="Double"/><column name="ItemCode" property="Subtotals" value="False" type="Boolean"/><column name="ItemCode" property="AutoSortOrder" value="-4135" type="Double"/><column name="ItemCode" property="AutoSortField" value="ItemCode" type="String"/><column name="ItemCode" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="ItemCode" property="ColumnWidth" value="11.29" type="Double"/><column name="ItemName" property="Name" value="ItemName" type="String"/><column name="ItemName" property="Orientation" value="1" type="Double"/><column name="ItemName" property="Position" value="2" type="Double"/><column name="ItemName" property="Subtotals" value="False" type="Boolean"/><column name="ItemName" property="AutoSortOrder" value="-4135" type="Double"/><column name="ItemName" property="AutoSortField" value="ItemName" type="String"/><column name="ItemName" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="ItemName" property="ColumnWidth" value="26.86" type="Double"/><column name="Date" property="Name" value="Date" type="String"/><column name="Date" property="Orientation" value="2" type="Double"/><column name="Date" property="Position" value="1" type="Double"/><column name="Date" property="Subtotals" value="True" type="Boolean"/><column name="Date" property="AutoSortOrder" value="-4135" type="Double"/><column name="Date" property="AutoSortField" value="Date" type="String"/><column name="Date" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="Date" property="HorizontalAlignment" value="1" type="Double"/><column name="Sum of Sum" property="Name" value="Sum of Sum" type="String"/><column name="Sum of Sum" property="SourceName" value="Sum" type="String"/><column name="Sum of Sum" property="Orientation" value="4" type="Double"/><column name="Sum of Sum" property="Position" value="1" type="Double"/><column name="Sum of Sum" property="NumberFormat" value="#,##0" type="String"/><column name="Sum of Sum" property="Function" value="-4157" type="Double"/><column name="Sum of Sum" property="ColumnWidth" value="9.43" type="Double"/></view><view name="Departments * Periods"><column name="" property="TableStyle2.Name" value="PivotStyleMedium18" type="String"/><column name="" property="LayoutRowDefault" value="1" type="Double"/><column name="" property="GrandTotalName" value="Grand Total" type="String"/><column name="" property="ColumnGrand" value="True" type="Boolean"/><column name="" property="DisplayFieldCaptions" value="True" type="Boolean"/><column name="" property="DisplayImmediateItems" value="True" type="Boolean"/><column name="" property="DisplayNullString" value="True" type="Boolean"/><column name="" property="EnableDataValueEditing" value="True" type="Boolean"/><column name="" property="EnableDrilldown" value="True" type="Boolean"/><column name="" property="EnableFieldDialog" value="True" type="Boolean"/><column name="" property="EnableFieldList" value="True" type="Boolean"/><column name="" property="EnableWizard" value="True" type="Boolean"/><column name="" property="ShowTableStyleColumnHeaders" value="True" type="Boolean"/><column name="" property="ShowTableStyleLastColumn" value="True" type="Boolean"/><column name="" property="SortUsingCustomLists" value="True" type="Boolean"/><column name="" property="VisualTotals" value="True" type="Boolean"/><column name="DepartmentCode" property="Name" value="DepartmentCode" type="String"/><column name="DepartmentCode" property="Orientation" value="1" type="Double"/><column name="DepartmentCode" property="Position" value="1" type="Double"/><column name="DepartmentCode" property="Subtotals" value="False" type="Boolean"/><column name="DepartmentCode" property="AutoSortOrder" value="-4135" type="Double"/><column name="DepartmentCode" property="AutoSortField" value="DepartmentCode" type="String"/><column name="DepartmentCode" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="DepartmentCode" property="ColumnWidth" value="18" type="Double"/><column name="Date" property="Name" value="Date" type="String"/><column name="Date" property="Orientation" value="2" type="Double"/><column name="Date" property="Position" value="1" type="Double"/><column name="Date" property="Subtotals" value="True" type="Boolean"/><column name="Date" property="AutoSortOrder" value="-4135" type="Double"/><column name="Date" property="AutoSortField" value="Date" type="String"/><column name="Date" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="Date" property="HorizontalAlignment" value="1" type="Double"/><column name="Sum of Sum" property="Name" value="Sum of Sum" type="String"/><column name="Sum of Sum" property="SourceName" value="Sum" type="String"/><column name="Sum of Sum" property="Orientation" value="4" type="Double"/><column name="Sum of Sum" property="Position" value="1" type="Double"/><column name="Sum of Sum" property="NumberFormat" value="#,##0" type="String"/><column name="Sum of Sum" property="Function" value="-4157" type="Double"/><column name="Sum of Sum" property="ColumnWidth" value="11.29" type="Double"/></view></pivotviews></table>');
GO
INSERT INTO [TableFormats] ([TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'BudgetFormBase2', '<table name="BudgetFormBase2"><columnFormats><column name="" property="ListObjectName" value="BaseForm" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$4" type="String"/><column name="_RowNum" property="NumberFormat" value="General" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$4" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="NumberFormat" value="General" type="String"/><column name="DepartmentCode" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="DepartmentCode" property="Address" value="$D$4" type="String"/><column name="DepartmentCode" property="ColumnWidth" value="18" type="Double"/><column name="DepartmentCode" property="NumberFormat" value="General" type="String"/><column name="ItemCode" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemCode" property="Address" value="$E$4" type="String"/><column name="ItemCode" property="ColumnWidth" value="18.86" type="Double"/><column name="ItemCode" property="NumberFormat" value="@" type="String"/><column name="ItemName" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemName" property="Address" value="$F$4" type="String"/><column name="ItemName" property="ColumnWidth" value="27.29" type="Double"/><column name="ItemName" property="NumberFormat" value="General" type="String"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="Address" value="$G$4" type="String"/><column name="Date" property="ColumnWidth" value="11.29" type="Double"/><column name="Date" property="NumberFormat" value="m/d/yyyy" type="String"/><column name="Amount" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Amount" property="Address" value="$H$4" type="String"/><column name="Amount" property="ColumnWidth" value="11.14" type="Double"/><column name="Amount" property="NumberFormat" value="General" type="String"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="Address" value="$I$4" type="String"/><column name="Sum" property="ColumnWidth" value="10.86" type="Double"/><column name="Sum" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats><pivotviews><view name="Items * Departments"><column name="" property="TableStyle2.Name" value="PivotStyleMedium18" type="String"/><column name="" property="LayoutRowDefault" value="1" type="Double"/><column name="" property="GrandTotalName" value="Grand Total" type="String"/><column name="" property="ColumnGrand" value="True" type="Boolean"/><column name="" property="DisplayFieldCaptions" value="True" type="Boolean"/><column name="" property="DisplayImmediateItems" value="True" type="Boolean"/><column name="" property="DisplayNullString" value="True" type="Boolean"/><column name="" property="EnableDataValueEditing" value="True" type="Boolean"/><column name="" property="EnableDrilldown" value="True" type="Boolean"/><column name="" property="EnableFieldDialog" value="True" type="Boolean"/><column name="" property="EnableFieldList" value="True" type="Boolean"/><column name="" property="EnableWizard" value="True" type="Boolean"/><column name="" property="ShowTableStyleColumnHeaders" value="True" type="Boolean"/><column name="" property="ShowTableStyleLastColumn" value="True" type="Boolean"/><column name="" property="SortUsingCustomLists" value="True" type="Boolean"/><column name="" property="VisualTotals" value="True" type="Boolean"/><column name="DepartmentCode" property="Name" value="DepartmentCode" type="String"/><column name="DepartmentCode" property="Orientation" value="2" type="Double"/><column name="DepartmentCode" property="Position" value="1" type="Double"/><column name="DepartmentCode" property="Subtotals" value="False" type="Boolean"/><column name="DepartmentCode" property="AutoSortOrder" value="-4135" type="Double"/><column name="DepartmentCode" property="AutoSortField" value="DepartmentCode" type="String"/><column name="DepartmentCode" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="DepartmentCode" property="HorizontalAlignment" value="1" type="Double"/><column name="ItemCode" property="Name" value="ItemCode" type="String"/><column name="ItemCode" property="Orientation" value="1" type="Double"/><column name="ItemCode" property="Position" value="1" type="Double"/><column name="ItemCode" property="Subtotals" value="False" type="Boolean"/><column name="ItemCode" property="AutoSortOrder" value="1" type="Double"/><column name="ItemCode" property="AutoSortField" value="ItemCode" type="String"/><column name="ItemCode" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="ItemCode" property="ColumnWidth" value="11.29" type="Double"/><column name="ItemName" property="Name" value="ItemName" type="String"/><column name="ItemName" property="Orientation" value="1" type="Double"/><column name="ItemName" property="Position" value="2" type="Double"/><column name="ItemName" property="Subtotals" value="False" type="Boolean"/><column name="ItemName" property="AutoSortOrder" value="-4135" type="Double"/><column name="ItemName" property="AutoSortField" value="ItemName" type="String"/><column name="ItemName" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="ItemName" property="ColumnWidth" value="26.86" type="Double"/><column name="Sum of Sum" property="Name" value="Sum of Sum" type="String"/><column name="Sum of Sum" property="SourceName" value="Sum" type="String"/><column name="Sum of Sum" property="Orientation" value="4" type="Double"/><column name="Sum of Sum" property="Position" value="1" type="Double"/><column name="Sum of Sum" property="NumberFormat" value="#,##0" type="String"/><column name="Sum of Sum" property="Function" value="-4157" type="Double"/><column name="Sum of Sum" property="ColumnWidth" value="9.29" type="Double"/></view><view name="Items * Periods"><column name="" property="TableStyle2.Name" value="PivotStyleMedium18" type="String"/><column name="" property="LayoutRowDefault" value="1" type="Double"/><column name="" property="GrandTotalName" value="Grand Total" type="String"/><column name="" property="ColumnGrand" value="True" type="Boolean"/><column name="" property="DisplayFieldCaptions" value="True" type="Boolean"/><column name="" property="DisplayImmediateItems" value="True" type="Boolean"/><column name="" property="DisplayNullString" value="True" type="Boolean"/><column name="" property="EnableDataValueEditing" value="True" type="Boolean"/><column name="" property="EnableDrilldown" value="True" type="Boolean"/><column name="" property="EnableFieldDialog" value="True" type="Boolean"/><column name="" property="EnableFieldList" value="True" type="Boolean"/><column name="" property="EnableWizard" value="True" type="Boolean"/><column name="" property="ShowTableStyleColumnHeaders" value="True" type="Boolean"/><column name="" property="ShowTableStyleLastColumn" value="True" type="Boolean"/><column name="" property="SortUsingCustomLists" value="True" type="Boolean"/><column name="" property="VisualTotals" value="True" type="Boolean"/><column name="ItemCode" property="Name" value="ItemCode" type="String"/><column name="ItemCode" property="Orientation" value="1" type="Double"/><column name="ItemCode" property="Position" value="1" type="Double"/><column name="ItemCode" property="Subtotals" value="False" type="Boolean"/><column name="ItemCode" property="AutoSortOrder" value="-4135" type="Double"/><column name="ItemCode" property="AutoSortField" value="ItemCode" type="String"/><column name="ItemCode" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="ItemCode" property="ColumnWidth" value="11.29" type="Double"/><column name="ItemName" property="Name" value="ItemName" type="String"/><column name="ItemName" property="Orientation" value="1" type="Double"/><column name="ItemName" property="Position" value="2" type="Double"/><column name="ItemName" property="Subtotals" value="False" type="Boolean"/><column name="ItemName" property="AutoSortOrder" value="-4135" type="Double"/><column name="ItemName" property="AutoSortField" value="ItemName" type="String"/><column name="ItemName" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="ItemName" property="ColumnWidth" value="26.86" type="Double"/><column name="Date" property="Name" value="Date" type="String"/><column name="Date" property="Orientation" value="2" type="Double"/><column name="Date" property="Position" value="1" type="Double"/><column name="Date" property="Subtotals" value="True" type="Boolean"/><column name="Date" property="AutoSortOrder" value="-4135" type="Double"/><column name="Date" property="AutoSortField" value="Date" type="String"/><column name="Date" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="Date" property="HorizontalAlignment" value="1" type="Double"/><column name="Sum of Sum" property="Name" value="Sum of Sum" type="String"/><column name="Sum of Sum" property="SourceName" value="Sum" type="String"/><column name="Sum of Sum" property="Orientation" value="4" type="Double"/><column name="Sum of Sum" property="Position" value="1" type="Double"/><column name="Sum of Sum" property="NumberFormat" value="#,##0" type="String"/><column name="Sum of Sum" property="Function" value="-4157" type="Double"/><column name="Sum of Sum" property="ColumnWidth" value="9.43" type="Double"/></view><view name="Departments * Periods"><column name="" property="TableStyle2.Name" value="PivotStyleMedium18" type="String"/><column name="" property="LayoutRowDefault" value="1" type="Double"/><column name="" property="GrandTotalName" value="Grand Total" type="String"/><column name="" property="ColumnGrand" value="True" type="Boolean"/><column name="" property="DisplayFieldCaptions" value="True" type="Boolean"/><column name="" property="DisplayImmediateItems" value="True" type="Boolean"/><column name="" property="DisplayNullString" value="True" type="Boolean"/><column name="" property="EnableDataValueEditing" value="True" type="Boolean"/><column name="" property="EnableDrilldown" value="True" type="Boolean"/><column name="" property="EnableFieldDialog" value="True" type="Boolean"/><column name="" property="EnableFieldList" value="True" type="Boolean"/><column name="" property="EnableWizard" value="True" type="Boolean"/><column name="" property="ShowTableStyleColumnHeaders" value="True" type="Boolean"/><column name="" property="ShowTableStyleLastColumn" value="True" type="Boolean"/><column name="" property="SortUsingCustomLists" value="True" type="Boolean"/><column name="" property="VisualTotals" value="True" type="Boolean"/><column name="DepartmentCode" property="Name" value="DepartmentCode" type="String"/><column name="DepartmentCode" property="Orientation" value="1" type="Double"/><column name="DepartmentCode" property="Position" value="1" type="Double"/><column name="DepartmentCode" property="Subtotals" value="False" type="Boolean"/><column name="DepartmentCode" property="AutoSortOrder" value="-4135" type="Double"/><column name="DepartmentCode" property="AutoSortField" value="DepartmentCode" type="String"/><column name="DepartmentCode" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="DepartmentCode" property="ColumnWidth" value="18" type="Double"/><column name="Date" property="Name" value="Date" type="String"/><column name="Date" property="Orientation" value="2" type="Double"/><column name="Date" property="Position" value="1" type="Double"/><column name="Date" property="Subtotals" value="True" type="Boolean"/><column name="Date" property="AutoSortOrder" value="-4135" type="Double"/><column name="Date" property="AutoSortField" value="Date" type="String"/><column name="Date" property="AutoSortCustomSubtotal" value="1" type="Double"/><column name="Date" property="HorizontalAlignment" value="1" type="Double"/><column name="Sum of Sum" property="Name" value="Sum of Sum" type="String"/><column name="Sum of Sum" property="SourceName" value="Sum" type="String"/><column name="Sum of Sum" property="Orientation" value="4" type="Double"/><column name="Sum of Sum" property="Position" value="1" type="Double"/><column name="Sum of Sum" property="NumberFormat" value="#,##0" type="String"/><column name="Sum of Sum" property="Function" value="-4157" type="Double"/><column name="Sum of Sum" property="ColumnWidth" value="11.29" type="Double"/></view></pivotviews></table>');
GO

INSERT INTO [Item] ([Code], [Name]) VALUES (N'10', N'Revenew');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'11', N'Direct Sales');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'12', N'Online Sales');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'20', N'Cost Of Revenue');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'21', N'Cost Of Direct Sales');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'22', N'Cost Of Online Sales');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'30', N'Operating Expenses');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'31', N'Research Development');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'31.70', N'Payroll R&D');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'31.71', N'Salary Taxes R&D');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'32', N'Distribution costs');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'32.70', N'Payroll Sales');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'32.71', N'Salary Taxes Sales');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'33', N'Administrative Expenses');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'33.70', N'Payroll Administrative');
GO
INSERT INTO [Item] ([Code], [Name]) VALUES (N'33.71', N'Salary Taxes Administrative');
GO

INSERT INTO [Department] ([Code], [Name]) VALUES (N'ADM', N'Administration');
GO
-- INSERT INTO [Department] ([Code], [Name]) VALUES (N'FIN', N'Finance');
-- GO
-- INSERT INTO [Department] ([Code], [Name]) VALUES (N'HR', N'HR');
-- GO
-- INSERT INTO [Department] ([Code], [Name]) VALUES (N'IT', N'IT');
-- GO
INSERT INTO [Department] ([Code], [Name]) VALUES (N'MKT', N'Marketing');
GO
-- INSERT INTO [Department] ([Code], [Name]) VALUES (N'PROD', N'Production');
-- GO
INSERT INTO [Department] ([Code], [Name]) VALUES (N'R&D', N'R&D');
GO
INSERT INTO [Department] ([Code], [Name]) VALUES (N'SALES', N'Sales');
GO

INSERT INTO [Period] ([Date], [Name]) VALUES ('20150101', N'Jan 15');
GO
INSERT INTO [Period] ([Date], [Name]) VALUES ('20150201', N'Feb 15');
GO
INSERT INTO [Period] ([Date], [Name]) VALUES ('20150301', N'Mar 15');
GO
INSERT INTO [Period] ([Date], [Name]) VALUES ('20150401', N'Apr 15');
GO
INSERT INTO [Period] ([Date], [Name]) VALUES ('20150501', N'May 15');
GO
INSERT INTO [Period] ([Date], [Name]) VALUES ('20150601', N'Jun 15');
GO
INSERT INTO [Period] ([Date], [Name]) VALUES ('20150701', N'Jul 15');
GO
INSERT INTO [Period] ([Date], [Name]) VALUES ('20150801', N'Aug 15');
GO
INSERT INTO [Period] ([Date], [Name]) VALUES ('20150901', N'Sep 15');
GO
INSERT INTO [Period] ([Date], [Name]) VALUES ('20151001', N'Oct 15');
GO
INSERT INTO [Period] ([Date], [Name]) VALUES ('20151101', N'Nov 15');
GO
INSERT INTO [Period] ([Date], [Name]) VALUES ('20151201', N'Dec 15');
GO

INSERT INTO [Budget] ([DepartmentCode], [ItemCode], [Date], [Amount], [Sum]) VALUES (N'ADM', N'33.70', '2015-01-01 00:00:00.000', NULL, -50000);
GO
INSERT INTO [Budget] ([DepartmentCode], [ItemCode], [Date], [Amount], [Sum]) VALUES (N'ADM', N'33.71', '2015-01-01 00:00:00.000', NULL, -15000);
GO
INSERT INTO [Budget] ([DepartmentCode], [ItemCode], [Date], [Amount], [Sum]) VALUES (N'MKT', N'12', '2015-01-01 00:00:00.000', NULL, 500000);
GO
INSERT INTO [Budget] ([DepartmentCode], [ItemCode], [Date], [Amount], [Sum]) VALUES (N'MKT', N'22', '2015-01-01 00:00:00.000', NULL, -200000);
GO
INSERT INTO [Budget] ([DepartmentCode], [ItemCode], [Date], [Amount], [Sum]) VALUES (N'MKT', N'32.70', '2015-01-01 00:00:00.000', NULL, -100000);
GO
INSERT INTO [Budget] ([DepartmentCode], [ItemCode], [Date], [Amount], [Sum]) VALUES (N'MKT', N'32.71', '2015-01-01 00:00:00.000', NULL, -30000);
GO
INSERT INTO [Budget] ([DepartmentCode], [ItemCode], [Date], [Amount], [Sum]) VALUES (N'R&D', N'31.70', '2015-01-01 00:00:00.000', NULL, -100000);
GO
INSERT INTO [Budget] ([DepartmentCode], [ItemCode], [Date], [Amount], [Sum]) VALUES (N'R&D', N'31.71', '2015-01-01 00:00:00.000', NULL, -30000);
GO
INSERT INTO [Budget] ([DepartmentCode], [ItemCode], [Date], [Amount], [Sum]) VALUES (N'SALES', N'11', '2015-01-01 00:00:00.000', NULL, 1000000);
GO
INSERT INTO [Budget] ([DepartmentCode], [ItemCode], [Date], [Amount], [Sum]) VALUES (N'SALES', N'21', '2015-01-01 00:00:00.000', NULL, -500000);
GO
INSERT INTO [Budget] ([DepartmentCode], [ItemCode], [Date], [Amount], [Sum]) VALUES (N'SALES', N'32.70', '2015-01-01 00:00:00.000', NULL, -200000);
GO
INSERT INTO [Budget] ([DepartmentCode], [ItemCode], [Date], [Amount], [Sum]) VALUES (N'SALES', N'32.71', '2015-01-01 00:00:00.000', NULL, -60000);
GO

INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, N'BudgetFormBase', N'<?xml version="1.0" encoding="Unicode"?>
<table name=".BudgetFormBase">
<columnFormats>
<column name="" property="ListObjectName" value="BaseForm" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$4" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="NumberFormat" value="General" type="String" />
<column name="DepartmentCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="DepartmentCode" property="Address" value="$D$4" type="String" />
<column name="DepartmentCode" property="ColumnWidth" value="18" type="Double" />
<column name="DepartmentCode" property="NumberFormat" value="General" type="String" />
<column name="ItemCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ItemCode" property="Address" value="$E$4" type="String" />
<column name="ItemCode" property="ColumnWidth" value="18.86" type="Double" />
<column name="ItemCode" property="NumberFormat" value="@" type="String" />
<column name="ItemName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ItemName" property="Address" value="$F$4" type="String" />
<column name="ItemName" property="ColumnWidth" value="27.29" type="Double" />
<column name="ItemName" property="NumberFormat" value="General" type="String" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="Address" value="$G$4" type="String" />
<column name="Date" property="ColumnWidth" value="11.29" type="Double" />
<column name="Date" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="Amount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Amount" property="Address" value="$H$4" type="String" />
<column name="Amount" property="ColumnWidth" value="11.14" type="Double" />
<column name="Amount" property="NumberFormat" value="General" type="String" />
<column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sum" property="Address" value="$I$4" type="String" />
<column name="Sum" property="ColumnWidth" value="10.86" type="Double" />
<column name="Sum" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
<pivotviews>
<view name="Items * Departments">
<column name="" property="TableStyle2.Name" value="PivotStyleMedium18" type="String" />
<column name="" property="LayoutRowDefault" value="1" type="Double" />
<column name="" property="GrandTotalName" value="Grand Total" type="String" />
<column name="" property="ColumnGrand" value="True" type="Boolean" />
<column name="" property="DisplayFieldCaptions" value="False" type="Boolean" />
<column name="" property="DisplayImmediateItems" value="True" type="Boolean" />
<column name="" property="DisplayNullString" value="True" type="Boolean" />
<column name="" property="EnableDataValueEditing" value="True" type="Boolean" />
<column name="" property="EnableDrilldown" value="True" type="Boolean" />
<column name="" property="EnableFieldDialog" value="True" type="Boolean" />
<column name="" property="EnableFieldList" value="True" type="Boolean" />
<column name="" property="EnableWizard" value="True" type="Boolean" />
<column name="" property="EnableWriteback" value="False" type="Boolean" />
<column name="" property="HasAutoFormat" value="False" type="Boolean" />
<column name="" property="ShowTableStyleColumnHeaders" value="True" type="Boolean" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleLastColumn" value="True" type="Boolean" />
<column name="" property="ShowTableStyleRowHeaders" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="" property="ShowValuesRow" value="False" type="Boolean" />
<column name="" property="SmallGrid" value="False" type="Boolean" />
<column name="" property="SortUsingCustomLists" value="True" type="Boolean" />
<column name="" property="SubtotalHiddenPageItems" value="False" type="Boolean" />
<column name="" property="TotalsAnnotation" value="False" type="Boolean" />
<column name="" property="VisualTotals" value="True" type="Boolean" />
<column name="" property="VisualTotalsForSets" value="False" type="Boolean" />
<column name="" property="FieldListSortAscending" value="False" type="Boolean" />
<column name="ItemCode" property="SourceName" value="ItemCode" type="String" />
<column name="ItemCode" property="Name" value="ItemCode" type="String" />
<column name="ItemCode" property="Caption" value="ItemCode" type="String" />
<column name="ItemCode" property="DataType" value="-4158" type="Double" />
<column name="ItemCode" property="Orientation" value="1" type="Double" />
<column name="ItemCode" property="Position" value="1" type="Double" />
<column name="ItemCode" property="EnableItemSelection" value="True" type="Boolean" />
<column name="ItemCode" property="RepeatLabels" value="False" type="Boolean" />
<column name="ItemCode" property="AllItemsVisible" value="True" type="Boolean" />
<column name="ItemCode" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutBlankLine" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutCompactRow" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutPageBreak" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutSubtotalLocation" value="1" type="Double" />
<column name="ItemCode" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="ItemCode" property="AutoSortField" value="ItemCode" type="String" />
<column name="ItemCode" property="AutoSortOrder" value="1" type="Double" />
<column name="ItemCode" property="AutoShowCount" value="10" type="Double" />
<column name="ItemCode" property="AutoShowType" value="-4135" type="Double" />
<column name="ItemCode" property="DragToColumn" value="True" type="Boolean" />
<column name="ItemCode" property="DragToRow" value="True" type="Boolean" />
<column name="ItemCode" property="DragToPage" value="True" type="Boolean" />
<column name="ItemCode" property="DragToData" value="True" type="Boolean" />
<column name="ItemCode" property="ColumnWidth" value="10.71" type="Double" />
<column name="ItemName" property="SourceName" value="ItemName" type="String" />
<column name="ItemName" property="Name" value="ItemName" type="String" />
<column name="ItemName" property="Caption" value="ItemName" type="String" />
<column name="ItemName" property="DataType" value="-4158" type="Double" />
<column name="ItemName" property="Orientation" value="1" type="Double" />
<column name="ItemName" property="Position" value="2" type="Double" />
<column name="ItemName" property="EnableItemSelection" value="True" type="Boolean" />
<column name="ItemName" property="RepeatLabels" value="False" type="Boolean" />
<column name="ItemName" property="AllItemsVisible" value="True" type="Boolean" />
<column name="ItemName" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="ItemName" property="LayoutBlankLine" value="False" type="Boolean" />
<column name="ItemName" property="LayoutCompactRow" value="False" type="Boolean" />
<column name="ItemName" property="LayoutPageBreak" value="False" type="Boolean" />
<column name="ItemName" property="LayoutSubtotalLocation" value="1" type="Double" />
<column name="ItemName" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="ItemName" property="AutoSortField" value="ItemName" type="String" />
<column name="ItemName" property="AutoSortOrder" value="-4135" type="Double" />
<column name="ItemName" property="AutoShowCount" value="10" type="Double" />
<column name="ItemName" property="AutoShowType" value="-4135" type="Double" />
<column name="ItemName" property="DragToColumn" value="True" type="Boolean" />
<column name="ItemName" property="DragToRow" value="True" type="Boolean" />
<column name="ItemName" property="DragToPage" value="True" type="Boolean" />
<column name="ItemName" property="DragToData" value="True" type="Boolean" />
<column name="ItemName" property="ColumnWidth" value="26.86" type="Double" />
<column name="DepartmentCode" property="SourceName" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="Name" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="Caption" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="DataType" value="-4158" type="Double" />
<column name="DepartmentCode" property="Orientation" value="2" type="Double" />
<column name="DepartmentCode" property="Position" value="1" type="Double" />
<column name="DepartmentCode" property="EnableItemSelection" value="True" type="Boolean" />
<column name="DepartmentCode" property="RepeatLabels" value="False" type="Boolean" />
<column name="DepartmentCode" property="AllItemsVisible" value="True" type="Boolean" />
<column name="DepartmentCode" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="DepartmentCode" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="DepartmentCode" property="AutoSortField" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="AutoSortOrder" value="-4135" type="Double" />
<column name="DepartmentCode" property="AutoShowCount" value="10" type="Double" />
<column name="DepartmentCode" property="AutoShowType" value="-4135" type="Double" />
<column name="DepartmentCode" property="DragToColumn" value="True" type="Boolean" />
<column name="DepartmentCode" property="DragToRow" value="True" type="Boolean" />
<column name="DepartmentCode" property="DragToPage" value="True" type="Boolean" />
<column name="DepartmentCode" property="DragToData" value="True" type="Boolean" />
<column name="DepartmentCode" property="HorizontalAlignment" value="1" type="Double" />
<column name="Sum of Sum" property="SourceName" value="Sum" type="String" />
<column name="Sum of Sum" property="Name" value="Sum of Sum" type="String" />
<column name="Sum of Sum" property="Caption" value="Sum of Sum" type="String" />
<column name="Sum of Sum" property="Orientation" value="4" type="Double" />
<column name="Sum of Sum" property="Position" value="1" type="Double" />
<column name="Sum of Sum" property="DataType" value="-4158" type="Double" />
<column name="Sum of Sum" property="NumberFormat" value="#,##0" type="String" />
<column name="Sum of Sum" property="Function" value="-4157" type="Double" />
<column name="Sum of Sum" property="Calculation" value="-4143" type="Double" />
<column name="Sum of Sum" property="ColumnWidth" value="10.71" type="Double" />
<column name="" property="GrandTotal.Range.ColumnWidth" value="11.29" type="Double" />
</view>
<view name="Items * Periods">
<column name="" property="TableStyle2.Name" value="PivotStyleMedium18" type="String" />
<column name="" property="LayoutRowDefault" value="1" type="Double" />
<column name="" property="GrandTotalName" value="Grand Total" type="String" />
<column name="" property="ColumnGrand" value="True" type="Boolean" />
<column name="" property="DisplayFieldCaptions" value="False" type="Boolean" />
<column name="" property="DisplayImmediateItems" value="True" type="Boolean" />
<column name="" property="DisplayNullString" value="True" type="Boolean" />
<column name="" property="EnableDataValueEditing" value="True" type="Boolean" />
<column name="" property="EnableDrilldown" value="True" type="Boolean" />
<column name="" property="EnableFieldDialog" value="True" type="Boolean" />
<column name="" property="EnableFieldList" value="True" type="Boolean" />
<column name="" property="EnableWizard" value="True" type="Boolean" />
<column name="" property="EnableWriteback" value="False" type="Boolean" />
<column name="" property="HasAutoFormat" value="False" type="Boolean" />
<column name="" property="ShowTableStyleColumnHeaders" value="True" type="Boolean" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleLastColumn" value="True" type="Boolean" />
<column name="" property="ShowTableStyleRowHeaders" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="" property="ShowValuesRow" value="False" type="Boolean" />
<column name="" property="SmallGrid" value="False" type="Boolean" />
<column name="" property="SortUsingCustomLists" value="True" type="Boolean" />
<column name="" property="SubtotalHiddenPageItems" value="False" type="Boolean" />
<column name="" property="TotalsAnnotation" value="False" type="Boolean" />
<column name="" property="VisualTotals" value="True" type="Boolean" />
<column name="" property="VisualTotalsForSets" value="False" type="Boolean" />
<column name="" property="FieldListSortAscending" value="False" type="Boolean" />
<column name="ItemCode" property="SourceName" value="ItemCode" type="String" />
<column name="ItemCode" property="Name" value="ItemCode" type="String" />
<column name="ItemCode" property="Caption" value="ItemCode" type="String" />
<column name="ItemCode" property="DataType" value="-4158" type="Double" />
<column name="ItemCode" property="Orientation" value="1" type="Double" />
<column name="ItemCode" property="Position" value="1" type="Double" />
<column name="ItemCode" property="EnableItemSelection" value="True" type="Boolean" />
<column name="ItemCode" property="RepeatLabels" value="False" type="Boolean" />
<column name="ItemCode" property="AllItemsVisible" value="True" type="Boolean" />
<column name="ItemCode" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutBlankLine" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutCompactRow" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutPageBreak" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutSubtotalLocation" value="1" type="Double" />
<column name="ItemCode" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="ItemCode" property="AutoSortField" value="ItemCode" type="String" />
<column name="ItemCode" property="AutoSortOrder" value="1" type="Double" />
<column name="ItemCode" property="AutoShowCount" value="10" type="Double" />
<column name="ItemCode" property="AutoShowType" value="-4135" type="Double" />
<column name="ItemCode" property="DragToColumn" value="True" type="Boolean" />
<column name="ItemCode" property="DragToRow" value="True" type="Boolean" />
<column name="ItemCode" property="DragToPage" value="True" type="Boolean" />
<column name="ItemCode" property="DragToData" value="True" type="Boolean" />
<column name="ItemCode" property="ColumnWidth" value="10.71" type="Double" />
<column name="ItemName" property="SourceName" value="ItemName" type="String" />
<column name="ItemName" property="Name" value="ItemName" type="String" />
<column name="ItemName" property="Caption" value="ItemName" type="String" />
<column name="ItemName" property="DataType" value="-4158" type="Double" />
<column name="ItemName" property="Orientation" value="1" type="Double" />
<column name="ItemName" property="Position" value="2" type="Double" />
<column name="ItemName" property="EnableItemSelection" value="True" type="Boolean" />
<column name="ItemName" property="RepeatLabels" value="False" type="Boolean" />
<column name="ItemName" property="AllItemsVisible" value="True" type="Boolean" />
<column name="ItemName" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="ItemName" property="LayoutBlankLine" value="False" type="Boolean" />
<column name="ItemName" property="LayoutCompactRow" value="False" type="Boolean" />
<column name="ItemName" property="LayoutPageBreak" value="False" type="Boolean" />
<column name="ItemName" property="LayoutSubtotalLocation" value="1" type="Double" />
<column name="ItemName" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="ItemName" property="AutoSortField" value="ItemName" type="String" />
<column name="ItemName" property="AutoSortOrder" value="-4135" type="Double" />
<column name="ItemName" property="AutoShowCount" value="10" type="Double" />
<column name="ItemName" property="AutoShowType" value="-4135" type="Double" />
<column name="ItemName" property="DragToColumn" value="True" type="Boolean" />
<column name="ItemName" property="DragToRow" value="True" type="Boolean" />
<column name="ItemName" property="DragToPage" value="True" type="Boolean" />
<column name="ItemName" property="DragToData" value="True" type="Boolean" />
<column name="ItemName" property="ColumnWidth" value="26.86" type="Double" />
<column name="Date" property="SourceName" value="Date" type="String" />
<column name="Date" property="Name" value="Date" type="String" />
<column name="Date" property="Caption" value="Date" type="String" />
<column name="Date" property="DataType" value="2" type="Double" />
<column name="Date" property="Orientation" value="2" type="Double" />
<column name="Date" property="Position" value="1" type="Double" />
<column name="Date" property="EnableItemSelection" value="True" type="Boolean" />
<column name="Date" property="RepeatLabels" value="False" type="Boolean" />
<column name="Date" property="AllItemsVisible" value="True" type="Boolean" />
<column name="Date" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="Date" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="Date" property="AutoSortField" value="Date" type="String" />
<column name="Date" property="AutoSortOrder" value="-4135" type="Double" />
<column name="Date" property="AutoShowCount" value="10" type="Double" />
<column name="Date" property="AutoShowType" value="-4135" type="Double" />
<column name="Date" property="DragToColumn" value="True" type="Boolean" />
<column name="Date" property="DragToRow" value="True" type="Boolean" />
<column name="Date" property="DragToPage" value="True" type="Boolean" />
<column name="Date" property="DragToData" value="True" type="Boolean" />
<column name="Date" property="HorizontalAlignment" value="1" type="Double" />
<column name="Sum of Sum" property="SourceName" value="Sum" type="String" />
<column name="Sum of Sum" property="Name" value="Sum of Sum" type="String" />
<column name="Sum of Sum" property="Caption" value="Sum of Sum" type="String" />
<column name="Sum of Sum" property="Orientation" value="4" type="Double" />
<column name="Sum of Sum" property="Position" value="1" type="Double" />
<column name="Sum of Sum" property="DataType" value="-4158" type="Double" />
<column name="Sum of Sum" property="NumberFormat" value="#,##0" type="String" />
<column name="Sum of Sum" property="Function" value="-4157" type="Double" />
<column name="Sum of Sum" property="Calculation" value="-4143" type="Double" />
<column name="Sum of Sum" property="ColumnWidth" value="10.71" type="Double" />
<column name="" property="GrandTotal.Range.ColumnWidth" value="10.57" type="Double" />
</view>
<view name="Departments * Periods">
<column name="" property="TableStyle2.Name" value="PivotStyleMedium18" type="String" />
<column name="" property="LayoutRowDefault" value="1" type="Double" />
<column name="" property="GrandTotalName" value="Grand Total" type="String" />
<column name="" property="ColumnGrand" value="True" type="Boolean" />
<column name="" property="DisplayFieldCaptions" value="False" type="Boolean" />
<column name="" property="DisplayImmediateItems" value="True" type="Boolean" />
<column name="" property="DisplayNullString" value="True" type="Boolean" />
<column name="" property="EnableDataValueEditing" value="True" type="Boolean" />
<column name="" property="EnableDrilldown" value="True" type="Boolean" />
<column name="" property="EnableFieldDialog" value="True" type="Boolean" />
<column name="" property="EnableFieldList" value="True" type="Boolean" />
<column name="" property="EnableWizard" value="True" type="Boolean" />
<column name="" property="EnableWriteback" value="False" type="Boolean" />
<column name="" property="HasAutoFormat" value="False" type="Boolean" />
<column name="" property="ShowTableStyleColumnHeaders" value="True" type="Boolean" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleLastColumn" value="True" type="Boolean" />
<column name="" property="ShowTableStyleRowHeaders" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="" property="ShowValuesRow" value="False" type="Boolean" />
<column name="" property="SmallGrid" value="False" type="Boolean" />
<column name="" property="SortUsingCustomLists" value="True" type="Boolean" />
<column name="" property="SubtotalHiddenPageItems" value="False" type="Boolean" />
<column name="" property="TotalsAnnotation" value="False" type="Boolean" />
<column name="" property="VisualTotals" value="True" type="Boolean" />
<column name="" property="VisualTotalsForSets" value="False" type="Boolean" />
<column name="" property="FieldListSortAscending" value="False" type="Boolean" />
<column name="DepartmentCode" property="SourceName" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="Name" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="Caption" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="DataType" value="-4158" type="Double" />
<column name="DepartmentCode" property="Orientation" value="1" type="Double" />
<column name="DepartmentCode" property="Position" value="1" type="Double" />
<column name="DepartmentCode" property="EnableItemSelection" value="True" type="Boolean" />
<column name="DepartmentCode" property="RepeatLabels" value="False" type="Boolean" />
<column name="DepartmentCode" property="AllItemsVisible" value="True" type="Boolean" />
<column name="DepartmentCode" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="DepartmentCode" property="LayoutBlankLine" value="False" type="Boolean" />
<column name="DepartmentCode" property="LayoutCompactRow" value="False" type="Boolean" />
<column name="DepartmentCode" property="LayoutPageBreak" value="False" type="Boolean" />
<column name="DepartmentCode" property="LayoutSubtotalLocation" value="1" type="Double" />
<column name="DepartmentCode" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="DepartmentCode" property="AutoSortField" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="AutoSortOrder" value="-4135" type="Double" />
<column name="DepartmentCode" property="AutoShowCount" value="10" type="Double" />
<column name="DepartmentCode" property="AutoShowType" value="-4135" type="Double" />
<column name="DepartmentCode" property="DragToColumn" value="True" type="Boolean" />
<column name="DepartmentCode" property="DragToRow" value="True" type="Boolean" />
<column name="DepartmentCode" property="DragToPage" value="True" type="Boolean" />
<column name="DepartmentCode" property="DragToData" value="True" type="Boolean" />
<column name="DepartmentCode" property="ColumnWidth" value="10.71" type="Double" />
<column name="Date" property="SourceName" value="Date" type="String" />
<column name="Date" property="Name" value="Date" type="String" />
<column name="Date" property="Caption" value="Date" type="String" />
<column name="Date" property="DataType" value="2" type="Double" />
<column name="Date" property="Orientation" value="2" type="Double" />
<column name="Date" property="Position" value="1" type="Double" />
<column name="Date" property="EnableItemSelection" value="True" type="Boolean" />
<column name="Date" property="RepeatLabels" value="False" type="Boolean" />
<column name="Date" property="AllItemsVisible" value="True" type="Boolean" />
<column name="Date" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="Date" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="Date" property="AutoSortField" value="Date" type="String" />
<column name="Date" property="AutoSortOrder" value="-4135" type="Double" />
<column name="Date" property="AutoShowCount" value="10" type="Double" />
<column name="Date" property="AutoShowType" value="-4135" type="Double" />
<column name="Date" property="DragToColumn" value="True" type="Boolean" />
<column name="Date" property="DragToRow" value="True" type="Boolean" />
<column name="Date" property="DragToPage" value="True" type="Boolean" />
<column name="Date" property="DragToData" value="True" type="Boolean" />
<column name="Date" property="HorizontalAlignment" value="1" type="Double" />
<column name="Sum of Sum" property="SourceName" value="Sum" type="String" />
<column name="Sum of Sum" property="Name" value="Sum of Sum" type="String" />
<column name="Sum of Sum" property="Caption" value="Sum of Sum" type="String" />
<column name="Sum of Sum" property="Orientation" value="4" type="Double" />
<column name="Sum of Sum" property="Position" value="1" type="Double" />
<column name="Sum of Sum" property="DataType" value="-4158" type="Double" />
<column name="Sum of Sum" property="NumberFormat" value="#,##0" type="String" />
<column name="Sum of Sum" property="Function" value="-4157" type="Double" />
<column name="Sum of Sum" property="Calculation" value="-4143" type="Double" />
<column name="Sum of Sum" property="ColumnWidth" value="12" type="Double" />
<column name="" property="GrandTotal.Range.ColumnWidth" value="9.43" type="Double" />
</view>
</pivotviews>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, N'Budget', N'<?xml version="1.0" encoding="Unicode"?>
<table name=".Budget">
<columnFormats>
<column name="" property="ListObjectName" value="Objects" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$4" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="NumberFormat" value="General" type="String" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="DepartmentCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="DepartmentCode" property="Address" value="$D$4" type="String" />
<column name="DepartmentCode" property="ColumnWidth" value="18" type="Double" />
<column name="DepartmentCode" property="NumberFormat" value="General" type="String" />
<column name="DepartmentCode" property="Validation.Type" value="6" type="Double" />
<column name="DepartmentCode" property="Validation.AlertStyle" value="1" type="Double" />
<column name="DepartmentCode" property="Validation.Operator" value="8" type="Double" />
<column name="DepartmentCode" property="Validation.Formula1" value="50" type="String" />
<column name="DepartmentCode" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="DepartmentCode" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="DepartmentCode" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="DepartmentCode" property="Validation.ShowError" value="True" type="Boolean" />
<column name="ItemCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ItemCode" property="Address" value="$E$4" type="String" />
<column name="ItemCode" property="ColumnWidth" value="11.29" type="Double" />
<column name="ItemCode" property="NumberFormat" value="General" type="String" />
<column name="ItemCode" property="Validation.Type" value="6" type="Double" />
<column name="ItemCode" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ItemCode" property="Validation.Operator" value="8" type="Double" />
<column name="ItemCode" property="Validation.Formula1" value="50" type="String" />
<column name="ItemCode" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ItemCode" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ItemCode" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ItemCode" property="Validation.ShowError" value="True" type="Boolean" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="Address" value="$F$4" type="String" />
<column name="Date" property="ColumnWidth" value="10.14" type="Double" />
<column name="Date" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="Date" property="Validation.Type" value="4" type="Double" />
<column name="Date" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Date" property="Validation.Operator" value="5" type="Double" />
<column name="Date" property="Validation.Formula1" value="01.01.1900" type="String" />
<column name="Date" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Date" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Date" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Date" property="Validation.ShowError" value="True" type="Boolean" />
<column name="Amount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Amount" property="Address" value="$G$4" type="String" />
<column name="Amount" property="ColumnWidth" value="9.71" type="Double" />
<column name="Amount" property="NumberFormat" value="General" type="String" />
<column name="Amount" property="Validation.Type" value="2" type="Double" />
<column name="Amount" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Amount" property="Validation.Operator" value="4" type="Double" />
<column name="Amount" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" />
<column name="Amount" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Amount" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Amount" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Amount" property="Validation.ShowError" value="True" type="Boolean" />
<column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sum" property="Address" value="$H$4" type="String" />
<column name="Sum" property="ColumnWidth" value="12.57" type="Double" />
<column name="Sum" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Sum" property="Validation.Type" value="2" type="Double" />
<column name="Sum" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Sum" property="Validation.Operator" value="4" type="Double" />
<column name="Sum" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" />
<column name="Sum" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Sum" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Sum" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Sum" property="Validation.ShowError" value="True" type="Boolean" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, N'BudgetFormBase2', N'<?xml version="1.0" encoding="Unicode"?>
<table name=".BudgetFormBase2">
<columnFormats>
<column name="" property="ListObjectName" value="BaseForm2" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$4" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="NumberFormat" value="General" type="String" />
<column name="DepartmentCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="DepartmentCode" property="Address" value="$D$4" type="String" />
<column name="DepartmentCode" property="ColumnWidth" value="18" type="Double" />
<column name="DepartmentCode" property="NumberFormat" value="General" type="String" />
<column name="ItemCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ItemCode" property="Address" value="$E$4" type="String" />
<column name="ItemCode" property="ColumnWidth" value="11.29" type="Double" />
<column name="ItemCode" property="NumberFormat" value="General" type="String" />
<column name="ItemName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ItemName" property="Address" value="$F$4" type="String" />
<column name="ItemName" property="ColumnWidth" value="26.86" type="Double" />
<column name="ItemName" property="NumberFormat" value="General" type="String" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="Address" value="$G$4" type="String" />
<column name="Date" property="ColumnWidth" value="10.86" type="Double" />
<column name="Date" property="NumberFormat" value="General" type="String" />
<column name="Amount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Amount" property="Address" value="$H$4" type="String" />
<column name="Amount" property="ColumnWidth" value="9.71" type="Double" />
<column name="Amount" property="NumberFormat" value="General" type="String" />
<column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sum" property="Address" value="$I$4" type="String" />
<column name="Sum" property="ColumnWidth" value="11.71" type="Double" />
<column name="Sum" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
<pivotviews>
<view name="Items * Departments">
<column name="" property="TableStyle2.Name" value="PivotStyleMedium18" type="String" />
<column name="" property="LayoutRowDefault" value="1" type="Double" />
<column name="" property="GrandTotalName" value="Grand Total" type="String" />
<column name="" property="ColumnGrand" value="True" type="Boolean" />
<column name="" property="DisplayFieldCaptions" value="False" type="Boolean" />
<column name="" property="DisplayImmediateItems" value="True" type="Boolean" />
<column name="" property="DisplayNullString" value="True" type="Boolean" />
<column name="" property="EnableDataValueEditing" value="True" type="Boolean" />
<column name="" property="EnableDrilldown" value="True" type="Boolean" />
<column name="" property="EnableFieldDialog" value="True" type="Boolean" />
<column name="" property="EnableFieldList" value="True" type="Boolean" />
<column name="" property="EnableWizard" value="True" type="Boolean" />
<column name="" property="EnableWriteback" value="False" type="Boolean" />
<column name="" property="HasAutoFormat" value="False" type="Boolean" />
<column name="" property="ShowTableStyleColumnHeaders" value="True" type="Boolean" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleLastColumn" value="True" type="Boolean" />
<column name="" property="ShowTableStyleRowHeaders" value="True" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="" property="ShowValuesRow" value="False" type="Boolean" />
<column name="" property="SmallGrid" value="False" type="Boolean" />
<column name="" property="SortUsingCustomLists" value="True" type="Boolean" />
<column name="" property="SubtotalHiddenPageItems" value="False" type="Boolean" />
<column name="" property="TotalsAnnotation" value="False" type="Boolean" />
<column name="" property="VisualTotals" value="True" type="Boolean" />
<column name="" property="VisualTotalsForSets" value="False" type="Boolean" />
<column name="" property="FieldListSortAscending" value="False" type="Boolean" />
<column name="ItemCode" property="SourceName" value="ItemCode" type="String" />
<column name="ItemCode" property="Name" value="ItemCode" type="String" />
<column name="ItemCode" property="Caption" value="ItemCode" type="String" />
<column name="ItemCode" property="DataType" value="-4158" type="Double" />
<column name="ItemCode" property="Orientation" value="1" type="Double" />
<column name="ItemCode" property="Position" value="1" type="Double" />
<column name="ItemCode" property="EnableItemSelection" value="True" type="Boolean" />
<column name="ItemCode" property="RepeatLabels" value="False" type="Boolean" />
<column name="ItemCode" property="AllItemsVisible" value="True" type="Boolean" />
<column name="ItemCode" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutBlankLine" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutCompactRow" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutPageBreak" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutSubtotalLocation" value="1" type="Double" />
<column name="ItemCode" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="ItemCode" property="AutoSortField" value="ItemCode" type="String" />
<column name="ItemCode" property="AutoSortOrder" value="-4135" type="Double" />
<column name="ItemCode" property="AutoShowCount" value="10" type="Double" />
<column name="ItemCode" property="AutoShowType" value="-4135" type="Double" />
<column name="ItemCode" property="DragToColumn" value="True" type="Boolean" />
<column name="ItemCode" property="DragToRow" value="True" type="Boolean" />
<column name="ItemCode" property="DragToPage" value="True" type="Boolean" />
<column name="ItemCode" property="DragToData" value="True" type="Boolean" />
<column name="ItemCode" property="ColumnWidth" value="10.71" type="Double" />
<column name="ItemName" property="SourceName" value="ItemName" type="String" />
<column name="ItemName" property="Name" value="ItemName" type="String" />
<column name="ItemName" property="Caption" value="ItemName" type="String" />
<column name="ItemName" property="DataType" value="-4158" type="Double" />
<column name="ItemName" property="Orientation" value="1" type="Double" />
<column name="ItemName" property="Position" value="2" type="Double" />
<column name="ItemName" property="EnableItemSelection" value="True" type="Boolean" />
<column name="ItemName" property="RepeatLabels" value="False" type="Boolean" />
<column name="ItemName" property="AllItemsVisible" value="True" type="Boolean" />
<column name="ItemName" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="ItemName" property="LayoutBlankLine" value="False" type="Boolean" />
<column name="ItemName" property="LayoutCompactRow" value="False" type="Boolean" />
<column name="ItemName" property="LayoutPageBreak" value="False" type="Boolean" />
<column name="ItemName" property="LayoutSubtotalLocation" value="1" type="Double" />
<column name="ItemName" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="ItemName" property="AutoSortField" value="ItemName" type="String" />
<column name="ItemName" property="AutoSortOrder" value="-4135" type="Double" />
<column name="ItemName" property="AutoShowCount" value="10" type="Double" />
<column name="ItemName" property="AutoShowType" value="-4135" type="Double" />
<column name="ItemName" property="DragToColumn" value="True" type="Boolean" />
<column name="ItemName" property="DragToRow" value="True" type="Boolean" />
<column name="ItemName" property="DragToPage" value="True" type="Boolean" />
<column name="ItemName" property="DragToData" value="True" type="Boolean" />
<column name="ItemName" property="ColumnWidth" value="26.86" type="Double" />
<column name="DepartmentCode" property="SourceName" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="Name" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="Caption" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="DataType" value="-4158" type="Double" />
<column name="DepartmentCode" property="Orientation" value="2" type="Double" />
<column name="DepartmentCode" property="Position" value="1" type="Double" />
<column name="DepartmentCode" property="EnableItemSelection" value="True" type="Boolean" />
<column name="DepartmentCode" property="RepeatLabels" value="False" type="Boolean" />
<column name="DepartmentCode" property="AllItemsVisible" value="True" type="Boolean" />
<column name="DepartmentCode" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="DepartmentCode" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="DepartmentCode" property="AutoSortField" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="AutoSortOrder" value="-4135" type="Double" />
<column name="DepartmentCode" property="AutoShowCount" value="10" type="Double" />
<column name="DepartmentCode" property="AutoShowType" value="-4135" type="Double" />
<column name="DepartmentCode" property="DragToColumn" value="True" type="Boolean" />
<column name="DepartmentCode" property="DragToRow" value="True" type="Boolean" />
<column name="DepartmentCode" property="DragToPage" value="True" type="Boolean" />
<column name="DepartmentCode" property="DragToData" value="True" type="Boolean" />
<column name="DepartmentCode" property="HorizontalAlignment" value="1" type="Double" />
<column name="Sum of Sum" property="SourceName" value="Sum" type="String" />
<column name="Sum of Sum" property="Name" value="Sum of Sum" type="String" />
<column name="Sum of Sum" property="Caption" value="Sum of Sum" type="String" />
<column name="Sum of Sum" property="Orientation" value="4" type="Double" />
<column name="Sum of Sum" property="Position" value="1" type="Double" />
<column name="Sum of Sum" property="DataType" value="-4158" type="Double" />
<column name="Sum of Sum" property="NumberFormat" value="#,##0" type="String" />
<column name="Sum of Sum" property="Function" value="-4157" type="Double" />
<column name="Sum of Sum" property="Calculation" value="-4143" type="Double" />
<column name="Sum of Sum" property="ColumnWidth" value="10.71" type="Double" />
<column name="" property="GrandTotal.Range.ColumnWidth" value="9.43" type="Double" />
</view>
<view name="Items * Dates">
<column name="" property="TableStyle2.Name" value="PivotStyleMedium18" type="String" />
<column name="" property="LayoutRowDefault" value="1" type="Double" />
<column name="" property="GrandTotalName" value="Grand Total" type="String" />
<column name="" property="ColumnGrand" value="True" type="Boolean" />
<column name="" property="DisplayFieldCaptions" value="False" type="Boolean" />
<column name="" property="DisplayImmediateItems" value="True" type="Boolean" />
<column name="" property="DisplayNullString" value="True" type="Boolean" />
<column name="" property="EnableDataValueEditing" value="True" type="Boolean" />
<column name="" property="EnableDrilldown" value="True" type="Boolean" />
<column name="" property="EnableFieldDialog" value="True" type="Boolean" />
<column name="" property="EnableFieldList" value="True" type="Boolean" />
<column name="" property="EnableWizard" value="True" type="Boolean" />
<column name="" property="EnableWriteback" value="False" type="Boolean" />
<column name="" property="HasAutoFormat" value="False" type="Boolean" />
<column name="" property="ShowTableStyleColumnHeaders" value="True" type="Boolean" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleLastColumn" value="True" type="Boolean" />
<column name="" property="ShowTableStyleRowHeaders" value="True" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="" property="ShowValuesRow" value="False" type="Boolean" />
<column name="" property="SmallGrid" value="False" type="Boolean" />
<column name="" property="SortUsingCustomLists" value="True" type="Boolean" />
<column name="" property="SubtotalHiddenPageItems" value="False" type="Boolean" />
<column name="" property="TotalsAnnotation" value="False" type="Boolean" />
<column name="" property="VisualTotals" value="True" type="Boolean" />
<column name="" property="VisualTotalsForSets" value="False" type="Boolean" />
<column name="" property="FieldListSortAscending" value="False" type="Boolean" />
<column name="ItemCode" property="SourceName" value="ItemCode" type="String" />
<column name="ItemCode" property="Name" value="ItemCode" type="String" />
<column name="ItemCode" property="Caption" value="ItemCode" type="String" />
<column name="ItemCode" property="DataType" value="-4158" type="Double" />
<column name="ItemCode" property="Orientation" value="1" type="Double" />
<column name="ItemCode" property="Position" value="1" type="Double" />
<column name="ItemCode" property="EnableItemSelection" value="True" type="Boolean" />
<column name="ItemCode" property="RepeatLabels" value="False" type="Boolean" />
<column name="ItemCode" property="AllItemsVisible" value="True" type="Boolean" />
<column name="ItemCode" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutBlankLine" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutCompactRow" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutPageBreak" value="False" type="Boolean" />
<column name="ItemCode" property="LayoutSubtotalLocation" value="1" type="Double" />
<column name="ItemCode" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="ItemCode" property="AutoSortField" value="ItemCode" type="String" />
<column name="ItemCode" property="AutoSortOrder" value="-4135" type="Double" />
<column name="ItemCode" property="AutoShowCount" value="10" type="Double" />
<column name="ItemCode" property="AutoShowType" value="-4135" type="Double" />
<column name="ItemCode" property="DragToColumn" value="True" type="Boolean" />
<column name="ItemCode" property="DragToRow" value="True" type="Boolean" />
<column name="ItemCode" property="DragToPage" value="True" type="Boolean" />
<column name="ItemCode" property="DragToData" value="True" type="Boolean" />
<column name="ItemCode" property="ColumnWidth" value="10.71" type="Double" />
<column name="ItemName" property="SourceName" value="ItemName" type="String" />
<column name="ItemName" property="Name" value="ItemName" type="String" />
<column name="ItemName" property="Caption" value="ItemName" type="String" />
<column name="ItemName" property="DataType" value="-4158" type="Double" />
<column name="ItemName" property="Orientation" value="1" type="Double" />
<column name="ItemName" property="Position" value="2" type="Double" />
<column name="ItemName" property="EnableItemSelection" value="True" type="Boolean" />
<column name="ItemName" property="RepeatLabels" value="False" type="Boolean" />
<column name="ItemName" property="AllItemsVisible" value="True" type="Boolean" />
<column name="ItemName" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="ItemName" property="LayoutBlankLine" value="False" type="Boolean" />
<column name="ItemName" property="LayoutCompactRow" value="False" type="Boolean" />
<column name="ItemName" property="LayoutPageBreak" value="False" type="Boolean" />
<column name="ItemName" property="LayoutSubtotalLocation" value="1" type="Double" />
<column name="ItemName" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="ItemName" property="AutoSortField" value="ItemName" type="String" />
<column name="ItemName" property="AutoSortOrder" value="-4135" type="Double" />
<column name="ItemName" property="AutoShowCount" value="10" type="Double" />
<column name="ItemName" property="AutoShowType" value="-4135" type="Double" />
<column name="ItemName" property="DragToColumn" value="True" type="Boolean" />
<column name="ItemName" property="DragToRow" value="True" type="Boolean" />
<column name="ItemName" property="DragToPage" value="True" type="Boolean" />
<column name="ItemName" property="DragToData" value="True" type="Boolean" />
<column name="ItemName" property="ColumnWidth" value="26.86" type="Double" />
<column name="Date" property="SourceName" value="Date" type="String" />
<column name="Date" property="Name" value="Date" type="String" />
<column name="Date" property="Caption" value="Date" type="String" />
<column name="Date" property="DataType" value="2" type="Double" />
<column name="Date" property="Orientation" value="2" type="Double" />
<column name="Date" property="Position" value="1" type="Double" />
<column name="Date" property="EnableItemSelection" value="True" type="Boolean" />
<column name="Date" property="RepeatLabels" value="False" type="Boolean" />
<column name="Date" property="AllItemsVisible" value="True" type="Boolean" />
<column name="Date" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="Date" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="Date" property="AutoSortField" value="Date" type="String" />
<column name="Date" property="AutoSortOrder" value="1" type="Double" />
<column name="Date" property="AutoShowCount" value="10" type="Double" />
<column name="Date" property="AutoShowType" value="-4135" type="Double" />
<column name="Date" property="DragToColumn" value="True" type="Boolean" />
<column name="Date" property="DragToRow" value="True" type="Boolean" />
<column name="Date" property="DragToPage" value="True" type="Boolean" />
<column name="Date" property="DragToData" value="True" type="Boolean" />
<column name="Date" property="HorizontalAlignment" value="1" type="Double" />
<column name="Sum of Sum" property="SourceName" value="Sum" type="String" />
<column name="Sum of Sum" property="Name" value="Sum of Sum" type="String" />
<column name="Sum of Sum" property="Caption" value="Sum of Sum" type="String" />
<column name="Sum of Sum" property="Orientation" value="4" type="Double" />
<column name="Sum of Sum" property="Position" value="1" type="Double" />
<column name="Sum of Sum" property="DataType" value="-4158" type="Double" />
<column name="Sum of Sum" property="NumberFormat" value="#,##0" type="String" />
<column name="Sum of Sum" property="Function" value="-4157" type="Double" />
<column name="Sum of Sum" property="Calculation" value="-4143" type="Double" />
<column name="Sum of Sum" property="ColumnWidth" value="10.71" type="Double" />
<column name="" property="GrandTotal.Range.ColumnWidth" value="10.57" type="Double" />
</view>
<view name="Departments * Dates">
<column name="" property="TableStyle2.Name" value="PivotStyleMedium18" type="String" />
<column name="" property="LayoutRowDefault" value="1" type="Double" />
<column name="" property="GrandTotalName" value="Grand Total" type="String" />
<column name="" property="ColumnGrand" value="True" type="Boolean" />
<column name="" property="DisplayFieldCaptions" value="False" type="Boolean" />
<column name="" property="DisplayImmediateItems" value="True" type="Boolean" />
<column name="" property="DisplayNullString" value="True" type="Boolean" />
<column name="" property="EnableDataValueEditing" value="True" type="Boolean" />
<column name="" property="EnableDrilldown" value="True" type="Boolean" />
<column name="" property="EnableFieldDialog" value="True" type="Boolean" />
<column name="" property="EnableFieldList" value="True" type="Boolean" />
<column name="" property="EnableWizard" value="True" type="Boolean" />
<column name="" property="EnableWriteback" value="False" type="Boolean" />
<column name="" property="HasAutoFormat" value="False" type="Boolean" />
<column name="" property="ShowTableStyleColumnHeaders" value="True" type="Boolean" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleLastColumn" value="True" type="Boolean" />
<column name="" property="ShowTableStyleRowHeaders" value="True" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="" property="ShowValuesRow" value="False" type="Boolean" />
<column name="" property="SmallGrid" value="False" type="Boolean" />
<column name="" property="SortUsingCustomLists" value="True" type="Boolean" />
<column name="" property="SubtotalHiddenPageItems" value="False" type="Boolean" />
<column name="" property="TotalsAnnotation" value="False" type="Boolean" />
<column name="" property="VisualTotals" value="True" type="Boolean" />
<column name="" property="VisualTotalsForSets" value="False" type="Boolean" />
<column name="" property="FieldListSortAscending" value="False" type="Boolean" />
<column name="DepartmentCode" property="SourceName" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="Name" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="Caption" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="DataType" value="-4158" type="Double" />
<column name="DepartmentCode" property="Orientation" value="1" type="Double" />
<column name="DepartmentCode" property="Position" value="1" type="Double" />
<column name="DepartmentCode" property="EnableItemSelection" value="True" type="Boolean" />
<column name="DepartmentCode" property="RepeatLabels" value="False" type="Boolean" />
<column name="DepartmentCode" property="AllItemsVisible" value="True" type="Boolean" />
<column name="DepartmentCode" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="DepartmentCode" property="LayoutBlankLine" value="False" type="Boolean" />
<column name="DepartmentCode" property="LayoutCompactRow" value="False" type="Boolean" />
<column name="DepartmentCode" property="LayoutPageBreak" value="False" type="Boolean" />
<column name="DepartmentCode" property="LayoutSubtotalLocation" value="1" type="Double" />
<column name="DepartmentCode" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="DepartmentCode" property="AutoSortField" value="DepartmentCode" type="String" />
<column name="DepartmentCode" property="AutoSortOrder" value="-4135" type="Double" />
<column name="DepartmentCode" property="AutoShowCount" value="10" type="Double" />
<column name="DepartmentCode" property="AutoShowType" value="-4135" type="Double" />
<column name="DepartmentCode" property="DragToColumn" value="True" type="Boolean" />
<column name="DepartmentCode" property="DragToRow" value="True" type="Boolean" />
<column name="DepartmentCode" property="DragToPage" value="True" type="Boolean" />
<column name="DepartmentCode" property="DragToData" value="True" type="Boolean" />
<column name="DepartmentCode" property="ColumnWidth" value="10.71" type="Double" />
<column name="Date" property="SourceName" value="Date" type="String" />
<column name="Date" property="Name" value="Date" type="String" />
<column name="Date" property="Caption" value="Date" type="String" />
<column name="Date" property="DataType" value="2" type="Double" />
<column name="Date" property="Orientation" value="2" type="Double" />
<column name="Date" property="Position" value="1" type="Double" />
<column name="Date" property="EnableItemSelection" value="True" type="Boolean" />
<column name="Date" property="RepeatLabels" value="False" type="Boolean" />
<column name="Date" property="AllItemsVisible" value="True" type="Boolean" />
<column name="Date" property="IncludeNewItemsInFilter" value="False" type="Boolean" />
<column name="Date" property="AutoSortCustomSubtotal" value="1" type="Double" />
<column name="Date" property="AutoSortField" value="Date" type="String" />
<column name="Date" property="AutoSortOrder" value="1" type="Double" />
<column name="Date" property="AutoShowCount" value="10" type="Double" />
<column name="Date" property="AutoShowType" value="-4135" type="Double" />
<column name="Date" property="DragToColumn" value="True" type="Boolean" />
<column name="Date" property="DragToRow" value="True" type="Boolean" />
<column name="Date" property="DragToPage" value="True" type="Boolean" />
<column name="Date" property="DragToData" value="True" type="Boolean" />
<column name="Date" property="HorizontalAlignment" value="1" type="Double" />
<column name="Sum of Sum" property="SourceName" value="Sum" type="String" />
<column name="Sum of Sum" property="Name" value="Sum of Sum" type="String" />
<column name="Sum of Sum" property="Caption" value="Sum of Sum" type="String" />
<column name="Sum of Sum" property="Orientation" value="4" type="Double" />
<column name="Sum of Sum" property="Position" value="1" type="Double" />
<column name="Sum of Sum" property="DataType" value="-4158" type="Double" />
<column name="Sum of Sum" property="NumberFormat" value="#,##0" type="String" />
<column name="Sum of Sum" property="Function" value="-4157" type="Double" />
<column name="Sum of Sum" property="Calculation" value="-4143" type="Double" />
<column name="Sum of Sum" property="ColumnWidth" value="10.71" type="Double" />
<column name="" property="GrandTotal.Range.ColumnWidth" value="9.43" type="Double" />
</view>
</pivotviews>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, N'QueryListBudget', N'<?xml version="1.0" encoding="Unicode"?>
<table name=".QueryListBudget">
<columnFormats>
<column name="" property="ListObjectName" value="Objects13" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$4" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="NumberFormat" value="General" type="String" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$4" type="String" />
<column name="TABLE_SCHEMA" property="NumberFormat" value="General" type="String" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$4" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="14.43" type="Double" />
<column name="TABLE_NAME" property="NumberFormat" value="General" type="String" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_TYPE" property="Address" value="$F$4" type="String" />
<column name="TABLE_TYPE" property="ColumnWidth" value="13.14" type="Double" />
<column name="TABLE_TYPE" property="NumberFormat" value="General" type="String" />
<column name="TABLE_TYPE" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_TYPE" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_CODE" property="Address" value="$G$4" type="String" />
<column name="TABLE_CODE" property="ColumnWidth" value="14.71" type="Double" />
<column name="TABLE_CODE" property="NumberFormat" value="General" type="String" />
<column name="INSERT_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="INSERT_PROCEDURE" property="Address" value="$H$4" type="String" />
<column name="INSERT_PROCEDURE" property="ColumnWidth" value="20.71" type="Double" />
<column name="INSERT_PROCEDURE" property="NumberFormat" value="General" type="String" />
<column name="UPDATE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="UPDATE_PROCEDURE" property="Address" value="$I$4" type="String" />
<column name="UPDATE_PROCEDURE" property="ColumnWidth" value="21.71" type="Double" />
<column name="UPDATE_PROCEDURE" property="NumberFormat" value="General" type="String" />
<column name="DELETE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="DELETE_PROCEDURE" property="Address" value="$J$4" type="String" />
<column name="DELETE_PROCEDURE" property="ColumnWidth" value="20.71" type="Double" />
<column name="DELETE_PROCEDURE" property="NumberFormat" value="General" type="String" />
<column name="PROCEDURE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Address" value="$K$4" type="String" />
<column name="PROCEDURE_TYPE" property="ColumnWidth" value="18.86" type="Double" />
<column name="PROCEDURE_TYPE" property="NumberFormat" value="General" type="String" />
<column name="PROCEDURE_TYPE" property="Validation.Type" value="6" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.Formula1" value="128" type="String" />
<column name="PROCEDURE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="PROCEDURE_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="PROCEDURE_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$4:$E$7" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E4)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_TYPE" property="FormatConditions(1).AppliesTo.Address" value="$F$4:$F$7" type="String" />
<column name="TABLE_TYPE" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_TYPE" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="TABLE_TYPE" property="FormatConditions(1).Formula1" value="=ISBLANK(F4)" type="String" />
<column name="TABLE_TYPE" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_TYPE" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, N'Period', N'<?xml version="1.0" encoding="Unicode"?>
<table name=".Period">
<columnFormats>
<column name="" property="ListObjectName" value="Objects" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="Address" value="$C$4" type="String" />
<column name="Date" property="ColumnWidth" value="10.71" type="Double" />
<column name="Date" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="Date" property="HorizontalAlignment" value="-4131" type="Double" />
<column name="Date" property="Validation.Type" value="4" type="Double" />
<column name="Date" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Date" property="Validation.Operator" value="5" type="Double" />
<column name="Date" property="Validation.Formula1" value="01.01.1900" type="String" />
<column name="Date" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Date" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Date" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Date" property="Validation.ShowError" value="True" type="Boolean" />
<column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Name" property="Address" value="$D$4" type="String" />
<column name="Name" property="ColumnWidth" value="27.86" type="Double" />
<column name="Name" property="NumberFormat" value="d-mmm" type="String" />
<column name="Name" property="Validation.Type" value="6" type="Double" />
<column name="Name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Name" property="Validation.Operator" value="8" type="Double" />
<column name="Name" property="Validation.Formula1" value="50" type="String" />
<column name="Name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, N'Item', N'<?xml version="1.0" encoding="Unicode"?>
<table name=".Item">
<columnFormats>
<column name="" property="ListObjectName" value="Objects" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="Code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Code" property="Address" value="$C$4" type="String" />
<column name="Code" property="ColumnWidth" value="10.71" type="Double" />
<column name="Code" property="NumberFormat" value="@" type="String" />
<column name="Code" property="Validation.Type" value="6" type="Double" />
<column name="Code" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Code" property="Validation.Operator" value="8" type="Double" />
<column name="Code" property="Validation.Formula1" value="50" type="String" />
<column name="Code" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Code" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Code" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Code" property="Validation.ShowError" value="True" type="Boolean" />
<column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Name" property="Address" value="$D$4" type="String" />
<column name="Name" property="ColumnWidth" value="27.86" type="Double" />
<column name="Name" property="NumberFormat" value="General" type="String" />
<column name="Name" property="Validation.Type" value="6" type="Double" />
<column name="Name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Name" property="Validation.Operator" value="8" type="Double" />
<column name="Name" property="Validation.Formula1" value="255" type="String" />
<column name="Name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, N'Department', N'<?xml version="1.0" encoding="Unicode"?>
<table name=".Department">
<columnFormats>
<column name="" property="ListObjectName" value="Objects" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="NumberFormat" value="General" type="String" />
<column name="Code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Code" property="Address" value="$C$4" type="String" />
<column name="Code" property="ColumnWidth" value="9.29" type="Double" />
<column name="Code" property="NumberFormat" value="General" type="String" />
<column name="Code" property="Validation.Type" value="6" type="Double" />
<column name="Code" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Code" property="Validation.Operator" value="8" type="Double" />
<column name="Code" property="Validation.Formula1" value="50" type="String" />
<column name="Code" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Code" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Code" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Code" property="Validation.ShowError" value="True" type="Boolean" />
<column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Name" property="Address" value="$D$4" type="String" />
<column name="Name" property="ColumnWidth" value="27.86" type="Double" />
<column name="Name" property="NumberFormat" value="General" type="String" />
<column name="Name" property="Validation.Type" value="6" type="Double" />
<column name="Name" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Name" property="Validation.Operator" value="8" type="Double" />
<column name="Name" property="Validation.Formula1" value="255" type="String" />
<column name="Name" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Name" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Name" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Name" property="Validation.ShowError" value="True" type="Boolean" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');
GO
