SELECT
    ID
    , DepartmentCode
    , ItemCode
    , ItemName
    , [Date]
    , Amount
    , [Sum]
FROM
    (
SELECT
    NULL AS ID
    , d.Code AS DepartmentCode
    , NULL AS ItemCode
    , NULL AS ItemName
    , NULL AS [Date]
    , CAST(NULL AS float) AS Amount
    , NULL AS [Sum]
    , 1 AS IsAxis
FROM
    Department d
WHERE
    d.Code = COALESCE(@DepartmentCode, d.Code)

UNION ALL
SELECT
    NULL AS ID
    , NULL AS DepartmentCode
    , i.Code AS ItemCode
    , CASE WHEN LEN(i.Code) > 2 THEN '    ' + i.Name WHEN SUBSTRING(i.Code, LEN(i.Code), 1) = '0' THEN i.Name ELSE '  ' + i.Name END AS ItemName
    , NULL AS [Date]
    , CAST(NULL AS float) AS Amount
    , NULL AS [Sum]
    , 1 AS IsAxis
FROM
    Item i
WHERE
    i.Code = COALESCE(@ItemCode, i.Code)

UNION ALL
SELECT
    NULL AS ID
    , NULL AS DepartmentCode
    , NULL AS ItemCode
    , NULL AS ItemName
    , CAST(p.[Date] AS datetime) AS [Date]
    , CAST(NULL AS float) AS Amount
    , NULL AS [Sum]
    , 1 AS IsAxis
FROM
    Period p
WHERE
    p.[Date] = COALESCE(@Date, p.[Date])

UNION ALL
SELECT
    b.ID
    , d.Code AS DepartmentCode
    , i.Code AS ItemCode
    , CASE WHEN LEN(i.Code) > 2 THEN '    ' + i.Name WHEN SUBSTRING(i.Code, LEN(i.Code), 1) = '0' THEN i.Name ELSE '  ' + i.Name END AS ItemName
    , CAST(p.[Date] AS datetime) AS [Date]
    , b.Amount
    , b.[Sum]
    , NULL AS IsAxis
FROM
    Budget b
    LEFT OUTER JOIN Department d ON d.Code = b.DepartmentCode
    LEFT OUTER JOIN Period p ON p.[Date] = b.[Date]
    LEFT OUTER JOIN Item i ON i.Code = b.ItemCode
WHERE
    d.Code = COALESCE(@DepartmentCode, d.Code)
    AND p.[Date] = COALESCE(@Date, p.[Date])
    AND i.Code = COALESCE(@ItemCode, i.Code)
) t
ORDER BY
    IsAxis DESC
    , [Date]
    , ItemCode
    , DepartmentCode
