-- =============================================
-- SaveToDB Framework for Microsoft SQL Server
-- Version 5.2, May 12, 2015
--
-- Copyright 2011-2015 Gartle Technology Corporation
-- =============================================
GO

CREATE SCHEMA [xls01] AUTHORIZATION [dbo]
GO
CREATE SCHEMA [dbo01] AUTHORIZATION [dbo]
GO
CREATE SCHEMA [etl01] AUTHORIZATION [dbo]
GO

print N'Schemas have been created';
GO

CREATE TABLE [dbo01].[QueryList] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128) NOT NULL,
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [TABLE_TYPE] [nvarchar](128) NOT NULL,
    [TABLE_CODE] [nvarchar](max),
    [INSERT_PROCEDURE] [nvarchar](max),
    [UPDATE_PROCEDURE] [nvarchar](max),
    [DELETE_PROCEDURE] [nvarchar](max),
    [PROCEDURE_TYPE] [nvarchar](128),
  CONSTRAINT [PK_QueryList_dbo01] PRIMARY KEY ([ID])
)
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-05-12
-- Description: SaveToDB Query List view
-- =============================================

CREATE VIEW [dbo01].[viewQueryList]
AS

SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_TYPE
    , NULL AS TABLE_CODE
    , COALESCE(q.INSERT_PROCEDURE, i.ROUTINE_SCHEMA + '.' + i.ROUTINE_NAME) AS INSERT_PROCEDURE
    , COALESCE(q.UPDATE_PROCEDURE, u.ROUTINE_SCHEMA + '.' + u.ROUTINE_NAME) AS UPDATE_PROCEDURE
    , COALESCE(q.DELETE_PROCEDURE, d.ROUTINE_SCHEMA + '.' + d.ROUTINE_NAME) AS DELETE_PROCEDURE
    , COALESCE(q.PROCEDURE_TYPE, i.ROUTINE_TYPE) AS PROCEDURE_TYPE
FROM
    (
        SELECT
            t.TABLE_CATALOG
            , t.TABLE_SCHEMA
            , t.TABLE_NAME
            , t.TABLE_TYPE
        FROM
            INFORMATION_SCHEMA.TABLES t
        WHERE
            NOT LEFT(t.TABLE_NAME,3) = 'sys'
            AND HAS_PERMS_BY_NAME(QUOTENAME(t.TABLE_CATALOG)+'.'+QUOTENAME(t.TABLE_SCHEMA)+'.'+QUOTENAME(t.TABLE_NAME), 'OBJECT', 'SELECT') = 1

        UNION ALL
        SELECT
            r.ROUTINE_CATALOG   AS TABLE_CATALOG
            , r.ROUTINE_SCHEMA  AS TABLE_SCHEMA
            , r.ROUTINE_NAME    AS TABLE_NAME
            , r.ROUTINE_TYPE    AS TABLE_TYPE
        FROM 
            INFORMATION_SCHEMA.ROUTINES r
        WHERE
            NOT LEFT(r.ROUTINE_NAME, 3) = 'sp_'
            AND ((r.ROUTINE_TYPE = 'PROCEDURE'
                AND HAS_PERMS_BY_NAME(QUOTENAME(r.ROUTINE_CATALOG)+'.'+QUOTENAME(r.ROUTINE_SCHEMA)+'.'+QUOTENAME(r.ROUTINE_NAME), 'OBJECT', 'EXECUTE') = 1)
                OR (ROUTINE_TYPE = 'FUNCTION' AND DATA_TYPE = 'TABLE'
                AND HAS_PERMS_BY_NAME(QUOTENAME(r.ROUTINE_CATALOG)+'.'+QUOTENAME(r.ROUTINE_SCHEMA)+'.'+QUOTENAME(r.ROUTINE_NAME), 'OBJECT', 'SELECT') = 1)
            )
            AND NOT r.ROUTINE_SCHEMA IN ('etl01')
            AND NOT r.ROUTINE_NAME LIKE '%_insert'
            AND NOT r.ROUTINE_NAME LIKE '%_update'
            AND NOT r.ROUTINE_NAME LIKE '%_delete'
            AND NOT r.ROUTINE_NAME LIKE '%_merge'
    ) t

    LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES i ON i.ROUTINE_SCHEMA = t.TABLE_SCHEMA AND i.ROUTINE_NAME = REPLACE(t.TABLE_NAME, '_select', '') + '_insert'
        AND HAS_PERMS_BY_NAME(QUOTENAME(i.ROUTINE_CATALOG)+'.'+QUOTENAME(i.ROUTINE_SCHEMA)+'.'+QUOTENAME(i.ROUTINE_NAME), 'OBJECT', 'EXECUTE') = 1
    LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES u ON u.ROUTINE_SCHEMA = t.TABLE_SCHEMA AND u.ROUTINE_NAME = REPLACE(t.TABLE_NAME, '_select', '') + '_update'
        AND HAS_PERMS_BY_NAME(QUOTENAME(u.ROUTINE_CATALOG)+'.'+QUOTENAME(u.ROUTINE_SCHEMA)+'.'+QUOTENAME(u.ROUTINE_NAME), 'OBJECT', 'EXECUTE') = 1
    LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES d ON d.ROUTINE_SCHEMA = t.TABLE_SCHEMA AND d.ROUTINE_NAME = REPLACE(t.TABLE_NAME, '_select', '') + '_delete'
        AND HAS_PERMS_BY_NAME(QUOTENAME(d.ROUTINE_CATALOG)+'.'+QUOTENAME(d.ROUTINE_SCHEMA)+'.'+QUOTENAME(d.ROUTINE_NAME), 'OBJECT', 'EXECUTE') = 1
    LEFT OUTER JOIN [dbo01].[QueryList] q ON q.TABLE_SCHEMA = t.TABLE_SCHEMA AND q.TABLE_NAME = t.TABLE_NAME

UNION ALL
SELECT
    q.TABLE_SCHEMA
    , q.TABLE_NAME
    , q.TABLE_TYPE
    , q.TABLE_CODE
    , q.INSERT_PROCEDURE
    , q.UPDATE_PROCEDURE
    , q.DELETE_PROCEDURE
    , q.PROCEDURE_TYPE
FROM
    [dbo01].[QueryList] q
    LEFT OUTER JOIN INFORMATION_SCHEMA.TABLES t ON q.TABLE_SCHEMA = t.TABLE_SCHEMA AND q.TABLE_NAME = t.TABLE_NAME
    LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES r ON q.TABLE_SCHEMA = r.ROUTINE_SCHEMA AND q.TABLE_NAME = r.ROUTINE_NAME
WHERE
    q.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
    AND t.TABLE_NAME IS NULL
    AND r.ROUTINE_NAME IS NULL

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: SaveToDB Query List view
--
-- This view can be used as a data source of other Query List views
-- which can filter different logic areas of a database.
-- =============================================

CREATE VIEW [xls01].[viewQueryList]
AS

SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_TYPE
    , t.TABLE_CODE
    , t.INSERT_PROCEDURE
    , t.UPDATE_PROCEDURE
    , t.DELETE_PROCEDURE
    , t.PROCEDURE_TYPE
FROM
    [dbo01].[viewQueryList] t
WHERE
    NOT t.TABLE_SCHEMA IN ('etl01', 'dbo01')
    AND NOT t.TABLE_NAME IN (                           -- SDK objects are not showed
        'ObjectTranslation'                             -- SDK 3.0
        , 'ColumnTranslation'
        , 'ParameterValues'
        , 'EventHandlers'
        , 'TableFormats'
        , 'QueryList'

        , 'viewQueryList'                               -- SDK 3.0
        , 'viewEventHandlers'
        , 'viewColumnTranslation'
        , 'viewObjectTranslation'
        , 'viewParameterValues'
        , 'viewTableFormats'
        , 'viewObjectTranslationSuggest'
        , 'viewEventHandlersSuggest'

        , 'Translation_Objects'                         -- SDK 2.x
        , 'Translation_Columns'
        , 'ExcelEventHandlers'
        , 'ExcelTableFormats'

        , 'viewTranslation_Columns'
        , 'viewTranslation_Objects'
        , 'viewExcelEventHandlers'
        , 'viewExcelTableFormats'
        , 'viewParameterValuesQueries'

        , 'uspUpdateTableFormat'                        -- SDK 3.0
        , 'uspGenerateEditProcedures'
        , 'uspGenerateChangeHandler'
        , 'uspGenerateGenegicHandler'
        , 'uspUpdateColumnTranslation'
        , 'uspUpdateColumnTranslation_Group'
        , 'uspUpdateObjectTranslation'
        , 'uspUpdateObjectTranslationAbsent'
        , 'uspUpdateTranslation_Columns'
        , 'uspUpdateTranslation_Columns_Group'
        , 'uspUpdateTranslation_Objects'
        , 'uspUpdateEventHandlers'

        , 'uspUpdateExcelTableFormat'                   -- SDK 2.0
        , 'uspUpdateExcelEventHandlers'
        )
    AND NOT t.TABLE_NAME LIKE 'viewParameterValues_%'   -- Parameter values
    AND NOT t.TABLE_NAME LIKE 'uspExcelEvent_%'         -- Event handlers
    AND NOT t.TABLE_NAME LIKE 'uspParameterValues_%'    -- Parameter values
    AND NOT t.TABLE_NAME LIKE 'ufnExcelEvent_%'         -- Event handlers
    AND NOT t.TABLE_NAME LIKE 'ufnParameterValues_%'    -- Parameter values

GO

print N'QueryList objects have been created';
GO

CREATE TABLE [dbo01].[ColumnTranslation] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128),
    [COLUMN_NAME] [nvarchar](128) NOT NULL,
    [LANGUAGE_NAME] [char](2) NOT NULL,
    [TRANSLATED_NAME] [nvarchar](128),
    [TRANSLATED_DESC] [nvarchar](1024),
  CONSTRAINT [PK_ColumnTranslation_dbo01] PRIMARY KEY ([ID])
)

GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ColumnTranslation_Schema_Name_Column_Language_dbo01] ON [dbo01].[ColumnTranslation]
(
    [TABLE_SCHEMA],
    [TABLE_NAME],
    [COLUMN_NAME],
    [LANGUAGE_NAME]
)
GO

CREATE TABLE [dbo01].[ObjectTranslation] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128) NOT NULL,
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [LANGUAGE_NAME] [char](2) NOT NULL,
    [TRANSLATED_NAME] [nvarchar](128),
    [TRANSLATED_DESC] [nvarchar](255),
    [TRANSLATED_COMMENT] [nvarchar](4000),
  CONSTRAINT [PK_ObjectTranslation_dbo01] PRIMARY KEY ([ID])
)

GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ObjectTranslation_Schema_Name_Language_dbo01] ON [dbo01].[ObjectTranslation]
(
    [TABLE_SCHEMA],
    [TABLE_NAME],
    [LANGUAGE_NAME]
)
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Configuration view of column and parameter translation
-- =============================================

CREATE VIEW [xls01].[viewColumnTranslation]
AS

SELECT
    t.ID
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.COLUMN_NAME
    , t.LANGUAGE_NAME
    , t.TRANSLATED_NAME
    , t.TRANSLATED_DESC
FROM
    [dbo01].[ColumnTranslation] t

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.2, 2015-05-12
-- Description: Configuration view of object translation
-- =============================================

CREATE VIEW [xls01].[viewObjectTranslation]
AS

SELECT
    t.ID
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.LANGUAGE_NAME
    , t.TRANSLATED_NAME
    , t.TRANSLATED_DESC
    , t.TRANSLATED_COMMENT
FROM
    [dbo01].[ObjectTranslation] t

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Object descriptions for users
-- =============================================

CREATE VIEW [xls01].[viewObjectDescription]
AS

SELECT
    t.ID
    , t.LANGUAGE_NAME
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TRANSLATED_NAME
    , t.TRANSLATED_COMMENT
FROM
    [dbo01].[ObjectTranslation] t
WHERE
    t.TRANSLATED_NAME IS NOT NULL                       -- This name is used in QueryList
    AND t.TRANSLATED_COMMENT IS NOT NULL                -- This comment for users
    AND NOT LEFT(t.TABLE_NAME,3) = 'sys'
    AND (
        HAS_PERMS_BY_NAME(QUOTENAME(DB_NAME())+'.'+QUOTENAME(t.TABLE_SCHEMA)+'.'+QUOTENAME(t.TABLE_NAME), 'OBJECT', 'SELECT') = 1
        OR HAS_PERMS_BY_NAME(QUOTENAME(DB_NAME())+'.'+QUOTENAME(t.TABLE_SCHEMA)+'.'+QUOTENAME(t.TABLE_NAME), 'OBJECT', 'EXECUTE') = 1
        )
    AND NOT TABLE_SCHEMA IN ('etl01')
    AND NOT TABLE_NAME IN (                             -- SDK objects are not showed
        'ObjectTranslation'                             -- SDK 3.0
        , 'ColumnTranslation'
        , 'ParameterValues'
        , 'EventHandlers'
        , 'TableFormats'
        , 'QueryList'

        , 'viewQueryList'
        , 'viewEventHandlers'
        , 'viewColumnTranslation'
        , 'viewObjectTranslation'
        , 'viewParameterValues'
        , 'viewTableFormats'
        , 'viewObjectTranslationSuggest'
        , 'viewEventHandlersSuggest'
        , 'viewObjectDescription'

        , 'uspUpdateTableFormat'
        , 'uspGenerateEditProcedures'
        , 'uspUpdateColumnTranslation'
        , 'uspUpdateColumnTranslation_Group'
        , 'uspUpdateObjectTranslation'
        , 'uspUpdateObjectTranslationAbsent'
        , 'uspUpdateTranslation_Columns'
        , 'uspUpdateTranslation_Columns_Group'
        , 'uspUpdateTranslation_Objects'
        , 'uspUpdateEventHandlers'

        , 'Translation_Objects'                         -- SDK 2.x
        , 'Translation_Columns'
        , 'ExcelEventHandlers'
        , 'ExcelTableFormats'

        , 'viewTranslation_Columns'
        , 'viewTranslation_Objects'
        , 'viewExcelEventHandlers'
        , 'viewExcelTableFormats'
        , 'viewParameterValuesQueries'

        , 'uspUpdateExcelTableFormat'
        , 'uspUpdateExcelEventHandlers'
        )
    AND NOT t.TABLE_NAME LIKE '%_insert'                -- Edit procedures
    AND NOT t.TABLE_NAME LIKE '%_update'
    AND NOT t.TABLE_NAME LIKE '%_delete'
    AND NOT t.TABLE_NAME LIKE '%_merge'
    AND NOT t.TABLE_NAME LIKE 'uspExcelEvent_%'         -- Event handlers
    AND NOT t.TABLE_NAME LIKE 'uspParameterValues_%'    -- Parameter values
    AND NOT t.TABLE_NAME LIKE 'viewParameterValues_%'

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: The procedure inserts column translation for new objects
-- =============================================

CREATE PROCEDURE [etl01].[uspUpdateColumnTranslation]
    @Schema nvarchar(128) = NULL
    , @LanguageName char(2) = NULL
AS
BEGIN

IF @LanguageName IS NULL
    BEGIN
    SELECT 'Specify @LanguageName parameter' AS [Message]
    RETURN
    END

SET NOCOUNT ON

INSERT INTO [dbo01].[ColumnTranslation]
    (
    TABLE_SCHEMA
    , TABLE_NAME
    , COLUMN_NAME
    , LANGUAGE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_DESC
    )
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.COLUMN_NAME
    , @LanguageName AS LANGUAGE_NAME
    , t.COLUMN_NAME AS TRANSLATED_NAME
    , NULL AS TRANSLATED_DESC
FROM
    (   
    SELECT
        t.TABLE_SCHEMA
        , t.TABLE_NAME
        , t.TABLE_TYPE
        , c.COLUMN_NAME
        , c.ORDINAL_POSITION
    FROM
        INFORMATION_SCHEMA.COLUMNS c
        INNER JOIN INFORMATION_SCHEMA.TABLES t
            ON t.TABLE_SCHEMA = c.TABLE_SCHEMA AND t.TABLE_NAME = c.TABLE_NAME
    WHERE
        (t.TABLE_TYPE = 'BASE TABLE' OR t.TABLE_TYPE = 'VIEW')  -- User tables and views only
        AND t.TABLE_SCHEMA = COALESCE(@Schema, t.TABLE_SCHEMA)
        AND NOT t.TABLE_NAME = 'ColumnTranslation'              -- Service tables
        AND NOT t.TABLE_NAME = 'ObjectTranslation'              -- Service tables
        AND NOT t.TABLE_NAME = 'TableFormat'                    -- Service tables
        AND NOT t.TABLE_NAME = 'ParameterValues'                -- Service tables
        AND NOT t.TABLE_NAME = 'EventHandlers'                  -- Service tables
        AND NOT t.TABLE_NAME = 'ExcelTableFormat'               -- Service tables
        AND NOT t.TABLE_NAME = 'ExcelEventHandlers'             -- Service tables
        AND NOT t.TABLE_NAME LIKE 'Translation_%'               -- Service tables
        AND NOT t.TABLE_NAME = 'viewColumnTranslation'          -- Service view
        AND NOT t.TABLE_NAME = 'viewObjectTranslation'          -- Service view
        AND NOT t.TABLE_NAME LIKE 'viewTranslation_%'           -- Service views
        AND NOT t.TABLE_NAME LIKE 'viewQueryList%'              -- Service queries for QueryList
        AND NOT t.TABLE_NAME = 'viewExcelEventHandlers'         -- Service query for Handlers
        AND NOT t.TABLE_NAME LIKE 'viewParameterValues%'        -- Service queries for parameter values
        AND NOT t.TABLE_SCHEMA LIKE 'etl%'                      -- Service schema

    UNION ALL
        
    SELECT
        p.ROUTINE_SCHEMA AS TABLE_SCHEMA
        , p.ROUTINE_NAME AS TABLE_NAME
        , p.ROUTINE_TYPE AS TABLE_TYPE
        , REPLACE(c.PARAMETER_NAME, '@', '') AS COLUMN_NAME
        , c.ORDINAL_POSITION
    FROM
        INFORMATION_SCHEMA.PARAMETERS c
        INNER JOIN INFORMATION_SCHEMA.ROUTINES p
            ON p.SPECIFIC_SCHEMA = c.SPECIFIC_SCHEMA AND p.SPECIFIC_NAME = c.SPECIFIC_NAME
    WHERE
        p.ROUTINE_TYPE = 'PROCEDURE'
        AND p.ROUTINE_SCHEMA = COALESCE(@Schema, p.ROUTINE_SCHEMA)
        AND NOT p.ROUTINE_NAME LIKE 'sp_%'                      -- System procedures 
        AND c.PARAMETER_MODE LIKE 'IN%'                         -- Input parameters only
        AND NOT p.ROUTINE_SCHEMA LIKE 'etl%'                    -- Service schema
        AND NOT p.ROUTINE_NAME LIKE 'usp%_insert'               -- Hidden procedures for INSERT
        AND NOT p.ROUTINE_NAME LIKE 'usp%_update'               -- Hidden procedures for UPDATE
        AND NOT p.ROUTINE_NAME LIKE 'usp%_delete'               -- Hidden procedures for DELETE
        AND NOT p.ROUTINE_NAME LIKE 'uspExcelEvent_%'           -- Hidden procedures for Excel Event Handling
        AND NOT p.ROUTINE_NAME = 'uspGenerateEditProcedures'    -- Service procedure for edit procedure generation
        AND NOT p.ROUTINE_NAME LIKE 'uspUpdateTranslation_%'    -- Service procedures for translation
    ) t

    LEFT OUTER JOIN [dbo01].[ColumnTranslation] o
        ON o.TABLE_SCHEMA = t.TABLE_SCHEMA AND o.TABLE_NAME = t.TABLE_NAME
            AND o.COLUMN_NAME = t.COLUMN_NAME
            AND o.LANGUAGE_NAME = @LanguageName
WHERE
    o.TABLE_SCHEMA IS NULL

SELECT LTRIM(STR(@@ROWCOUNT)) + ' rows inserted' AS [Message]

END
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: The procedure inserts column translation for new columns and parameters
-- =============================================

CREATE PROCEDURE [etl01].[uspUpdateColumnTranslation_Group]
    @Schema nvarchar(128) = NULL
    , @LanguageName char(2) = NULL
AS
BEGIN

IF @LanguageName IS NULL
    BEGIN
    SELECT 'Specify @LanguageName parameter' AS [Message]
    RETURN
    END

SET NOCOUNT ON

INSERT INTO [dbo01].[ColumnTranslation]
    (
    TABLE_SCHEMA
    , TABLE_NAME
    , COLUMN_NAME
    , LANGUAGE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_DESC
    )
SELECT
    t.TABLE_SCHEMA
    , NULL AS TABLE_NAME
    , t.COLUMN_NAME
    , @LanguageName AS LANGUAGE_NAME
    , t.COLUMN_NAME AS TRANSLATED_NAME
    , NULL AS TRANSLATED_DESC
FROM
    (
        SELECT
            t.TABLE_SCHEMA
            , t.COLUMN_NAME
        FROM
            (   
                SELECT
                    t.TABLE_SCHEMA
                    , t.TABLE_NAME
                    , t.TABLE_TYPE
                    , c.COLUMN_NAME
                    , c.ORDINAL_POSITION
                FROM
                    INFORMATION_SCHEMA.COLUMNS c
                    INNER JOIN INFORMATION_SCHEMA.TABLES t
                        ON t.TABLE_SCHEMA = c.TABLE_SCHEMA AND t.TABLE_NAME = c.TABLE_NAME
                WHERE
                    (t.TABLE_TYPE = 'BASE TABLE' OR t.TABLE_TYPE = 'VIEW')  -- User tables and views only
                    AND t.TABLE_SCHEMA = COALESCE(@Schema, t.TABLE_SCHEMA)
                    AND NOT t.TABLE_NAME = 'ColumnTranslation'              -- Service tables
                    AND NOT t.TABLE_NAME = 'ObjectTranslation'              -- Service tables
                    AND NOT t.TABLE_NAME = 'TableFormat'                    -- Service tables
                    AND NOT t.TABLE_NAME = 'ParameterValues'                -- Service tables
                    AND NOT t.TABLE_NAME = 'EventHandlers'                  -- Service tables
                    AND NOT t.TABLE_NAME = 'ExcelTableFormat'               -- Service tables
                    AND NOT t.TABLE_NAME = 'ExcelEventHandlers'             -- Service tables
                    AND NOT t.TABLE_NAME LIKE 'Translation_%'               -- Service tables
                    AND NOT t.TABLE_NAME LIKE 'viewTranslation_%'           -- Service views
                    AND NOT t.TABLE_NAME LIKE 'viewQueryList%'              -- Service queries for QueryList
                    AND NOT t.TABLE_NAME = 'viewExcelEventHandlers'         -- Service query for Handlers
                    AND NOT t.TABLE_NAME LIKE 'viewParameterValues%'        -- Service queries for parameter values
                    AND NOT t.TABLE_SCHEMA LIKE 'etl%'                      -- Service schema

                UNION ALL
            
                SELECT
                    p.ROUTINE_SCHEMA AS TABLE_SCHEMA
                    , p.ROUTINE_NAME AS TABLE_NAME
                    , p.ROUTINE_TYPE AS TABLE_TYPE
                    , REPLACE(c.PARAMETER_NAME, '@', '') AS COLUMN_NAME
                    , c.ORDINAL_POSITION
                FROM
                    INFORMATION_SCHEMA.PARAMETERS c
                    INNER JOIN INFORMATION_SCHEMA.ROUTINES p
                        ON p.SPECIFIC_SCHEMA = c.SPECIFIC_SCHEMA AND p.SPECIFIC_NAME = c.SPECIFIC_NAME
                WHERE
                    p.ROUTINE_TYPE = 'PROCEDURE'
                    AND p.ROUTINE_SCHEMA = COALESCE(@Schema, p.ROUTINE_SCHEMA)
                    AND NOT p.ROUTINE_NAME LIKE 'sp_%'                      -- System procedures 
                    AND c.PARAMETER_MODE LIKE 'IN%'                         -- Input parameters only
                    AND NOT p.ROUTINE_SCHEMA LIKE 'etl%'                    -- Service schema
                    AND NOT p.ROUTINE_NAME LIKE 'usp%_insert'               -- Hidden procedures for INSERT
                    AND NOT p.ROUTINE_NAME LIKE 'usp%_update'               -- Hidden procedures for UPDATE
                    AND NOT p.ROUTINE_NAME LIKE 'usp%_delete'               -- Hidden procedures for DELETE
                    AND NOT p.ROUTINE_NAME LIKE 'uspExcelEvent_%'           -- Hidden procedures for Excel Event Handling
                    AND NOT p.ROUTINE_NAME = 'uspGenerateEditProcedures'    -- Service procedure for edit procedure generation
                    AND NOT p.ROUTINE_NAME LIKE 'uspUpdateTranslation_%'    -- Service procedures for translation
            ) t
        GROUP BY
            t.TABLE_SCHEMA
            , t.COLUMN_NAME
    ) t
    LEFT OUTER JOIN [dbo01].[ColumnTranslation] o
        ON UPPER(o.TABLE_SCHEMA) = UPPER(t.TABLE_SCHEMA) AND o.TABLE_NAME IS NULL
            AND UPPER(o.COLUMN_NAME) = UPPER(t.COLUMN_NAME)
            AND UPPER(o.LANGUAGE_NAME) = UPPER(@LanguageName)
WHERE
    o.COLUMN_NAME IS NULL

SELECT LTRIM(STR(@@ROWCOUNT)) + ' rows inserted' AS [Message]

END
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: The procedure inserts translation for new objects
-- =============================================

CREATE PROCEDURE [etl01].[uspUpdateObjectTranslation]
    @Schema nvarchar(128) = NULL
    , @LanguageName char(2) = NULL
AS
BEGIN

IF @LanguageName IS NULL
    BEGIN
    SELECT 'Specify @LanguageName parameter' AS [Message]
    RETURN
    END

SET NOCOUNT ON

INSERT INTO [dbo01].[ObjectTranslation]
    (
    TABLE_SCHEMA
    , TABLE_NAME
    , LANGUAGE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_DESC
    )
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , @LanguageName AS LANGUAGE_NAME
    , t.TABLE_SCHEMA + '.' + t.TABLE_NAME AS TRANSLATED_NAME
    , NULL AS TRANSLATED_DESC
FROM
    (   
        SELECT
            t.TABLE_SCHEMA
            , t.TABLE_NAME
            , t.TABLE_TYPE
        FROM
            INFORMATION_SCHEMA.TABLES t
        WHERE
            (t.TABLE_TYPE = 'BASE TABLE' OR t.TABLE_TYPE = 'VIEW')
            AND t.TABLE_SCHEMA = COALESCE(@Schema, t.TABLE_SCHEMA)
            AND NOT (
                t.TABLE_NAME LIKE 'viewParameterValues_%'
            )

        UNION ALL
        
        SELECT
            p.ROUTINE_SCHEMA AS TABLE_SCHEMA
            , p.ROUTINE_NAME AS TABLE_NAME
            , p.ROUTINE_TYPE AS TABLE_TYPE
        FROM
            INFORMATION_SCHEMA.ROUTINES p
        WHERE
            p.ROUTINE_TYPE = 'PROCEDURE'
            AND p.ROUTINE_SCHEMA = COALESCE(@Schema, p.ROUTINE_SCHEMA)
            AND NOT (
                p.ROUTINE_NAME LIKE 'uspParameterValues_%'
                OR p.ROUTINE_NAME LIKE 'uspExcelEvent_Change_%'
                OR p.ROUTINE_NAME LIKE 'uspExcelEvent_DoubleClick_%'
                OR p.ROUTINE_NAME LIKE 'uspExcelEvent_SelectionChange_%'
            )
    ) t
    LEFT OUTER JOIN [dbo01].[ObjectTranslation] o
        ON UPPER(o.TABLE_SCHEMA) = UPPER(t.TABLE_SCHEMA) AND UPPER(o.TABLE_NAME) = UPPER(t.TABLE_NAME)
            AND UPPER(o.LANGUAGE_NAME) = UPPER(@LanguageName)
WHERE
    o.TABLE_SCHEMA IS NULL

SELECT LTRIM(STR(@@ROWCOUNT)) + ' rows inserted' AS [Message]

END
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: The procedure inserts translation of existing languages for absent objects
-- =============================================

CREATE PROCEDURE [etl01].[uspUpdateObjectTranslationAbsent]
AS
BEGIN

SET NOCOUNT ON

INSERT INTO [dbo01].[ObjectTranslation]
    (
    TABLE_SCHEMA
    , TABLE_NAME
    , LANGUAGE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_DESC
    )
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , l.LANGUAGE_NAME
    , t.TABLE_SCHEMA + '.' + t.TABLE_NAME AS TRANSLATED_NAME
    , NULL AS TRANSLATED_DESC
FROM
    (   
        SELECT
            t.TABLE_SCHEMA
            , t.TABLE_NAME
            , t.TABLE_TYPE
        FROM
            INFORMATION_SCHEMA.TABLES t
        WHERE
            (t.TABLE_TYPE = 'BASE TABLE'
            OR t.TABLE_TYPE = 'VIEW')
            AND NOT (
                t.TABLE_NAME LIKE 'viewParameterValues_%'
            )

        UNION ALL
        
        SELECT
            p.ROUTINE_SCHEMA AS TABLE_SCHEMA
            , p.ROUTINE_NAME AS TABLE_NAME
            , p.ROUTINE_TYPE AS TABLE_TYPE
        FROM
            INFORMATION_SCHEMA.ROUTINES p
        WHERE
            p.ROUTINE_TYPE = 'PROCEDURE'
            AND NOT (
                p.ROUTINE_NAME LIKE 'uspParameterValues_%'
                OR p.ROUTINE_NAME LIKE 'uspExcelEvent_Change_%'
                OR p.ROUTINE_NAME LIKE 'uspExcelEvent_DoubleClick_%'
                OR p.ROUTINE_NAME LIKE 'uspExcelEvent_SelectionChange_%'
            )
    ) t
    INNER JOIN (
        SELECT
            DISTINCT
            TABLE_SCHEMA
            , LANGUAGE_NAME
        FROM
            [dbo01].[ObjectTranslation]
    ) l ON l.TABLE_SCHEMA = t.TABLE_SCHEMA
    LEFT OUTER JOIN [dbo01].[ObjectTranslation] o
        ON o.TABLE_SCHEMA = t.TABLE_SCHEMA AND o.TABLE_NAME = t.TABLE_NAME
            AND o.LANGUAGE_NAME = l.LANGUAGE_NAME
WHERE
    o.TABLE_SCHEMA IS NULL

SELECT LTRIM(STR(@@ROWCOUNT)) + ' rows inserted' AS [Message]

END
GO

print N'Translation objects have been created';
GO

CREATE TABLE [dbo01].[EventHandlers] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128) NOT NULL,
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [COLUMN_NAME] [nvarchar](128),
    [EVENT_NAME] [varchar](50) NOT NULL,
    [HANDLER_SCHEMA] [nvarchar](128),
    [HANDLER_NAME] [nvarchar](128) NOT NULL,
    [HANDLER_TYPE] [nvarchar](128),
    [HANDLER_CODE] [nvarchar](max),
    [TARGET_WORKSHEET] [nvarchar](128),
    [MENU_ORDER] [int],
    [EDIT_PARAMETERS] [bit],
    [IS_ACTIVE] [bit],
  CONSTRAINT [PK_EventHandlers_dbo01] PRIMARY KEY ([ID])
)

GO
ALTER TABLE [dbo01].[EventHandlers] ADD  CONSTRAINT [DF_EventHandlers_IS_ACTIVE]  DEFAULT ((1)) FOR [IS_ACTIVE]
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Configuration view of event handlers
-- =============================================

CREATE VIEW [xls01].[viewEventHandlers]
AS

SELECT
    t.ID
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.COLUMN_NAME
    , t.EVENT_NAME
    , t.HANDLER_SCHEMA
    , t.HANDLER_NAME
    , t.HANDLER_TYPE
    , t.HANDLER_CODE
    , t.TARGET_WORKSHEET
    , t.MENU_ORDER
    , t.EDIT_PARAMETERS
FROM
    [dbo01].[EventHandlers] t
WHERE
    t.IS_ACTIVE = 1

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: The procedure generates change event handlers
-- =============================================

CREATE PROCEDURE [etl01].[uspGenerateChangeHandler]
    @TableSchema nvarchar(128) = NULL
    , @TableName nvarchar(128) = NULL
    , @TargetSchema nvarchar(128) = NULL
    , @ExecuteScript bit = 0
AS
BEGIN
    
DECLARE @Tab varchar(4)

SET @Tab = REPLICATE(' ', 4)

DECLARE @CrLf char(2)

SET @CrLf = CHAR(13) + CHAR(10)

IF @TableSchema IS NULL OR @TableName IS NULL OR @TargetSchema IS NULL
    BEGIN
    SELECT 'Use SQL Server Management Studio to execute this procedure' AS [Message]
    UNION ALL
    SELECT 'Specify all parameters of the procedure' AS [Message]
    RETURN
    END

SET NOCOUNT ON

IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(@TableSchema + '.' + @TableName) AND [type] in (N'U'))
    BEGIN
    SELECT 'Table ' + @TableSchema + '.' + @TableName + ' does not exist' AS [Message]
    RETURN
    END

IF (
        SELECT
            COUNT(*)
        FROM 
            INFORMATION_SCHEMA.KEY_COLUMN_USAGE c
        WHERE
            TABLE_SCHEMA = @TableSchema
            AND TABLE_NAME = @TableName
    ) = 0
    BEGIN
    SELECT @TableSchema + '.' + @TableName + ' has no key fields' AS [Message]
    RETURN
    END

DECLARE @ProcedureName nvarchar(128)

SET @ProcedureName = '[' + @TargetSchema + '].[uspExcelEvent_Change_' + @TableSchema + '_' + @TableName + ']'

DECLARE @Where VARCHAR(MAX)

SELECT @Where = (
        SELECT
            ' AND ' + c.COLUMN_NAME + ' = @' + c.COLUMN_NAME
        FROM
            INFORMATION_SCHEMA.KEY_COLUMN_USAGE c
        WHERE
            TABLE_SCHEMA = @TableSchema
            AND TABLE_NAME = @TableName
        ORDER BY
            c.ORDINAL_POSITION
        FOR XML PATH('')
    )

SET @Where = STUFF(@Where, 1, 5, '')

--PRINT @Where

DECLARE @Header VARCHAR(MAX)

SELECT @Header = (
        SELECT
            ', @' + c.COLUMN_NAME
                + ' ' + c.DATA_TYPE
                + CASE WHEN c.CHARACTER_MAXIMUM_LENGTH IS NULL THEN '' ELSE '(' + CAST(c.CHARACTER_MAXIMUM_LENGTH AS varchar(5)) + ')' END
        FROM
            INFORMATION_SCHEMA.COLUMNS c
        WHERE
            c.TABLE_SCHEMA = @TableSchema
            AND c.TABLE_NAME = @TableName
        ORDER BY
            c.ORDINAL_POSITION
        FOR XML PATH('')
    )

SET @Header = REPLACE(@Header, ',', @CrLf + '    ,')

--PRINT @Header

DECLARE @Body VARCHAR(MAX)

SELECT @Body = (
        SELECT
            ' IF @ColumnName = ''' + c.COLUMN_NAME + ''''
            + ' UPDATE [' + @TableSchema + '].[' + @TableName + '] SET ' + c.COLUMN_NAME + ' = @' + c.COLUMN_NAME + ' WHERE ' + @Where
        FROM
            INFORMATION_SCHEMA.COLUMNS c
        WHERE
            c.TABLE_SCHEMA = @TableSchema
            AND c.TABLE_NAME = @TableName
        ORDER BY
            c.ORDINAL_POSITION
        FOR XML PATH('')
    )

SET @Body = REPLACE(@Body, ' IF @', @CrLf + @CrLf + '    IF @')
SET @Body = REPLACE(@Body, ' UPDATE [', @CrLf + '        UPDATE [') 

--PRINT @Body

DECLARE @Sql VARCHAR(MAX)

SET @Sql = 'CREATE PROCEDURE ' + @ProcedureName + '
    @ColumnName nvarchar(128)
    , @CellValue nvarchar(255)' + @Header +'
AS
BEGIN' + @Body + '

END
'

PRINT @Sql

IF @ExecuteScript = 1
    BEGIN
    IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(@ProcedureName) AND [type] in (N'P', N'PC'))
        EXEC (@Sql)
    
    END

END

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: The procedure generates event handler procedures
-- =============================================

CREATE PROCEDURE [etl01].[uspGenerateGenegicHandler]
    @TableSchema nvarchar(128) = NULL
    , @TableName nvarchar(128) = NULL
    , @TargetSchema nvarchar(128) = NULL
    , @EventName nvarchar(128) = NULL
    , @NameSuffix nvarchar(128) = NULL
    , @ExecuteScript bit = 0
AS
BEGIN
    
DECLARE @Tab varchar(4)

SET @Tab = REPLICATE(' ', 4)

DECLARE @CrLf char(2)

SET @CrLf = CHAR(13) + CHAR(10)

IF @TableSchema IS NULL OR @TableName IS NULL OR @TargetSchema IS NULL
    BEGIN
    SELECT 'Use SQL Server Management Studio to execute this procedure' AS [Message]
    UNION ALL
    SELECT 'Specify all parameters of the procedure' AS [Message]
    RETURN
    END

SET NOCOUNT ON

IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(@TableSchema + '.' + @TableName) AND [type] in (N'U', N'V'))
    BEGIN
    SELECT 'Table or view ' + @TableSchema + '.' + @TableName + ' does not exist' AS [Message]
    RETURN
    END

DECLARE @ProcedureName nvarchar(128)

SET @ProcedureName = '[' + @TargetSchema + '].[uspExcelEvent_'
    + ISNULL(@EventName, 'ContextMenu') + ' _' + @TableSchema + '_' + @TableName + ISNULL('_' + @NameSuffix, '') + ']'

DECLARE @Header VARCHAR(MAX)

SELECT @Header = (
        SELECT
            ', @' + c.COLUMN_NAME
                + ' ' + c.DATA_TYPE
                + CASE WHEN c.CHARACTER_MAXIMUM_LENGTH IS NULL THEN '' ELSE '(' + CAST(c.CHARACTER_MAXIMUM_LENGTH AS varchar(5)) + ')' END
        FROM
            INFORMATION_SCHEMA.COLUMNS c
        WHERE
            c.TABLE_SCHEMA = @TableSchema
            AND c.TABLE_NAME = @TableName
        ORDER BY
            c.ORDINAL_POSITION
        FOR XML PATH('')
    )

SET @Header = REPLACE(@Header, ',', @CrLf + '    ,')

--PRINT @Header

DECLARE @Sql VARCHAR(MAX)

SET @Sql = 'CREATE PROCEDURE ' + @ProcedureName + '
    @ColumnName nvarchar(128)
    , @CellValue nvarchar(255)' + @Header +'
AS
BEGIN

-- Add code here

END
'

PRINT @Sql

IF @ExecuteScript = 1
    BEGIN
    IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(@ProcedureName) AND [type] in (N'P', N'PC'))
        EXEC (@Sql)
    
    END

END
GO

print N'EventHandlers objects have been created';
GO

CREATE TABLE [dbo01].[ParameterValues] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128) NOT NULL,
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [PARAMETER_NAME] [nvarchar](128) NOT NULL,
    [SELECT_SCHEMA] [nvarchar](128),
    [SELECT_NAME] [nvarchar](128) NOT NULL,
    [SELECT_TYPE] [nvarchar](128),
    [SELECT_CODE] [nvarchar](max),
  CONSTRAINT [PK_ParameterValues_dbo01] PRIMARY KEY ([ID])
)

GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_ParameterValues_Schema_Name_Parameter_dbo01] ON [dbo01].[ParameterValues]
(
    [TABLE_SCHEMA],
    [TABLE_NAME],
    [PARAMETER_NAME]
)
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Configuration view of queries of parameter values
-- =============================================

CREATE VIEW [xls01].[viewParameterValues]
AS

SELECT
    t.ID
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.PARAMETER_NAME
    , t.SELECT_SCHEMA
    , t.SELECT_NAME
    , t.SELECT_TYPE
    , t.SELECT_CODE
FROM
    [dbo01].[ParameterValues] t

GO

print N'ParameterValues  objects have been created';
GO

CREATE TABLE [dbo01].[TableFormats] (
    [ID] [int] IDENTITY(1,1) NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128) NOT NULL,
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [TABLE_EXCEL_FORMAT_XML] [xml],
  CONSTRAINT [PK_TableFormat_dbo01] PRIMARY KEY ([ID])
)

GO
CREATE UNIQUE NONCLUSTERED INDEX [IX_TableFormats_Schema_Name_dbo01] ON [dbo01].[TableFormats]
(
    [TABLE_NAME],
    [TABLE_SCHEMA]
)
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: Configuration view of Excel formats of database objects
-- =============================================

CREATE VIEW [xls01].[viewTableFormats]
AS

SELECT
    t.ID
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_EXCEL_FORMAT_XML
FROM
    [dbo01].[TableFormats] t

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: The procedure updates Excel table formats
-- =============================================

CREATE PROCEDURE [dbo01].[uspUpdateTableFormat]
    @Schema nvarchar(128) = NULL
    , @Name nvarchar(128) = NULL
    , @ExcelFormatXML xml = NULL
AS
BEGIN

SET NOCOUNT ON

IF @Schema IS NOT NULL AND @Name IS NOT NULL
    IF @ExcelFormatXML IS NULL
        BEGIN

        DELETE [dbo01].[TableFormats]
        WHERE
            TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name

        END
    ELSE
        BEGIN

        UPDATE [dbo01].[TableFormats]
        SET
            TABLE_EXCEL_FORMAT_XML = @ExcelFormatXML
        WHERE
            TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name

        IF @@ROWCOUNT = 0
            INSERT [dbo01].[TableFormats]
                (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML)
            VALUES
                (@Schema, @Name, @ExcelFormatXML)

        END
                
END
GO

print N'TableFormats objects have been created';
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: The procedure generates SELECT, INSERT, UPDATE and DELETE procedures
-- =============================================

CREATE PROCEDURE [etl01].[uspGenerateEditProcedures]
    @TableSchema nvarchar(128) = NULL
    , @TableName nvarchar(128) = NULL
    , @TargetSchema nvarchar(128) = NULL
    , @ExecuteScript bit = 0
    , @RecreateProceduresIfExist bit = 0
AS
BEGIN
    
IF @TableSchema IS NULL OR @TableName IS NULL OR @TargetSchema IS NULL
    BEGIN
    SELECT 'Use SQL Server Management Studio to execute this procedure' AS [Message]
    UNION ALL
    SELECT 'Specify all parameters of the procedure' AS [Message]
    RETURN
    END

SET NOCOUNT ON

DECLARE @SelectSQL nvarchar(4000)
DECLARE @InsertSQL nvarchar(4000)
DECLARE @UpdateSQL nvarchar(4000)
DECLARE @DeleteSQL nvarchar(4000)

DECLARE @SelectField nvarchar(4000)
DECLARE @UpdateField nvarchar(4000)
DECLARE @InsertField nvarchar(4000)
DECLARE @InsertValue nvarchar(4000)
DECLARE @UpdateParam nvarchar(4000)
DECLARE @DeleteParam nvarchar(4000)
DECLARE @DeleteWhere nvarchar(4000)

DECLARE @SelectJoin nvarchar(4000)
DECLARE @UpdateCode nvarchar(4000)

DECLARE @FullDataType nvarchar(128)

DECLARE @TABLE_SCHEMA nvarchar(128)
DECLARE @TABLE_NAME nvarchar(128)
DECLARE @ORDINAL_POSITION int
DECLARE @COLUMN_NAME nvarchar(128)
DECLARE @DATA_TYPE nvarchar(128)
DECLARE @CHARACTER_MAXIMUM_LENGTH int
DECLARE @IS_NULLABLE varchar(3)
DECLARE @IS_IDENTITY bit
DECLARE @IS_ROWGUIDCOL bit
DECLARE @IS_COMPUTED bit
DECLARE @NUMERIC_PRECISION int
DECLARE @NUMERIC_SCALE int

DECLARE @CONSTRAINT_TYPE nvarchar(128)

DECLARE @LINKED_TABLE_SCHEMA nvarchar(128)
DECLARE @LINKED_TABLE_NAME nvarchar(128)
DECLARE @LINKED_COLUMN_NAME nvarchar(128)

DECLARE @UNIQUE_COLUMN_NAME nvarchar(128)
DECLARE @UNIQUE_IS_NULLABLE varchar(3)
DECLARE @UNIQUE_DATA_TYPE nvarchar(128)
DECLARE @UNIQUE_CHARACTER_MAXIMUM_LENGTH int
DECLARE @UNIQUE_NUMERIC_PRECISION int
DECLARE @UNIQUE_NUMERIC_SCALE int

DECLARE @Tab varchar(4)

SET @Tab = REPLICATE(' ', 4)

DECLARE @CrLf char(2)

SET @CrLf = CHAR(13) + CHAR(10)

DECLARE FieldCursor CURSOR FORWARD_ONLY LOCAL READ_ONLY FOR
    SELECT
        c.TABLE_SCHEMA
        , c.TABLE_NAME

        , c.ORDINAL_POSITION
        , c.COLUMN_NAME
        , c.DATA_TYPE
        , c.CHARACTER_MAXIMUM_LENGTH
        , c.NUMERIC_PRECISION
        , c.NUMERIC_SCALE
        , c.IS_NULLABLE
        , c.is_identity AS IS_IDENTITY
        , c.is_rowguidcol AS IS_ROWGUIDCOL
        , c.is_computed AS IS_COMPUTED

        , c.CONSTRAINT_TYPE

        , c.LINKED_TABLE_SCHEMA
        , c.LINKED_TABLE_NAME
        , c.LINKED_COLUMN_NAME
        
        , c.UNIQUE_COLUMN_NAME
        , c.UNIQUE_IS_NULLABLE
        , c.UNIQUE_DATA_TYPE
        , c.UNIQUE_CHARACTER_MAXIMUM_LENGTH
        , c.UNIQUE_NUMERIC_PRECISION
        , c.UNIQUE_NUMERIC_SCALE
    FROM
    (
    SELECT
        -- Base Table Column
        c.TABLE_SCHEMA
        , c.TABLE_NAME
        , t.TABLE_TYPE
        , c.COLUMN_NAME
        , c.ORDINAL_POSITION
        , c.COLUMN_DEFAULT
        , c.DATA_TYPE
        , c.CHARACTER_MAXIMUM_LENGTH
        , c.NUMERIC_PRECISION
        , c.NUMERIC_SCALE
        , c.IS_NULLABLE
        , sc.is_identity
        , sc.is_rowguidcol
        , sc.is_computed
        , c.CHARACTER_SET_NAME

        -- Base Table Constraint
        , tc.CONSTRAINT_TYPE
        , ccu.CONSTRAINT_SCHEMA
        , ccu.CONSTRAINT_NAME

        -- Linked Table Constraint
        , rc.UNIQUE_CONSTRAINT_SCHEMA   AS LINKED_CONSTRAINT_SCHEMA
        , rc.UNIQUE_CONSTRAINT_NAME     AS LINKED_CONSTRAINT_NAME
        , rc.MATCH_OPTION
        , rc.UPDATE_RULE
        , rc.DELETE_RULE

        -- Linked Table Constraint Column
        , rcu.TABLE_SCHEMA              AS LINKED_TABLE_SCHEMA
        , rcu.TABLE_NAME                AS LINKED_TABLE_NAME
        , rcu.COLUMN_NAME               AS LINKED_COLUMN_NAME
        
        -- Linked Table Unique Column
        , rtc.CONSTRAINT_TYPE           AS UNIQUE_CONSTRAINT_TYPE
        , rtc.CONSTRAINT_SCHEMA         AS UNIQUE_CONSTRAINT_SCHEMA
        , rtc.CONSTRAINT_NAME           AS UNIQUE_CONSTRAINT_NAME
        , rccu.COLUMN_NAME              AS UNIQUE_COLUMN_NAME
        , rcc.ORDINAL_POSITION          AS UNIQUE_ORDINAL_POSITION
        , rcc.COLUMN_DEFAULT            AS UNIQUE_COLUMN_DEFAULT
        , rcc.IS_NULLABLE               AS UNIQUE_IS_NULLABLE
        , rcc.DATA_TYPE                 AS UNIQUE_DATA_TYPE
        , rcc.CHARACTER_MAXIMUM_LENGTH  AS UNIQUE_CHARACTER_MAXIMUM_LENGTH
        , rcc.NUMERIC_PRECISION         AS UNIQUE_NUMERIC_PRECISION
        , rcc.NUMERIC_SCALE             AS UNIQUE_NUMERIC_SCALE
        , rcc.CHARACTER_SET_NAME        AS UNIQUE_CHARACTER_SET_NAME
    FROM 
        -- Base Table Column
        INFORMATION_SCHEMA.COLUMNS c
        INNER JOIN
        INFORMATION_SCHEMA.TABLES t
            ON t.TABLE_SCHEMA = c.TABLE_SCHEMA AND t.TABLE_NAME = c.TABLE_NAME

        -- SQL Server specific data for column
        INNER JOIN sys.columns sc
            ON sc.[object_id] = OBJECT_ID('[' + c.TABLE_SCHEMA + '].[' + c.TABLE_NAME + ']') AND sc.name = c.COLUMN_NAME

        -- Base Table Constraint
        LEFT OUTER JOIN
        INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE ccu
            ON ccu.TABLE_SCHEMA = c.TABLE_SCHEMA AND ccu.TABLE_NAME = c.TABLE_NAME
                AND ccu.COLUMN_NAME = c.COLUMN_NAME
        LEFT OUTER JOIN
        INFORMATION_SCHEMA.TABLE_CONSTRAINTS tc
            ON tc.TABLE_SCHEMA = c.TABLE_SCHEMA AND tc.TABLE_NAME = c.TABLE_NAME
                AND tc.CONSTRAINT_SCHEMA = ccu.CONSTRAINT_SCHEMA AND tc.CONSTRAINT_NAME = ccu.CONSTRAINT_NAME

        -- Linked Table Constraint
        LEFT OUTER JOIN
        INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS rc
            ON rc.CONSTRAINT_SCHEMA = ccu.CONSTRAINT_SCHEMA AND rc.CONSTRAINT_NAME = ccu.CONSTRAINT_NAME
        LEFT OUTER JOIN
        INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE rcu
            ON rcu.CONSTRAINT_SCHEMA = rc.UNIQUE_CONSTRAINT_SCHEMA AND rcu.CONSTRAINT_NAME = rc.UNIQUE_CONSTRAINT_NAME

        -- Linked Table Unique Column
        LEFT OUTER JOIN
        INFORMATION_SCHEMA.TABLE_CONSTRAINTS rtc
            ON rtc.TABLE_SCHEMA = rcu.TABLE_SCHEMA AND rtc.TABLE_NAME = rcu.TABLE_NAME
                AND rtc.CONSTRAINT_TYPE = 'UNIQUE'
        LEFT OUTER JOIN
        INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE rccu
            ON rccu.TABLE_SCHEMA = rtc.TABLE_SCHEMA AND rccu.TABLE_NAME = rtc.TABLE_NAME
                AND rccu.CONSTRAINT_SCHEMA = rtc.CONSTRAINT_SCHEMA AND rccu.CONSTRAINT_NAME = rtc.CONSTRAINT_NAME
        
        LEFT OUTER JOIN
        INFORMATION_SCHEMA.COLUMNS rcc
            ON rcc.TABLE_SCHEMA = rccu.TABLE_SCHEMA AND rcc.TABLE_NAME = rccu.TABLE_NAME
                AND rcc.COLUMN_NAME = rccu.COLUMN_NAME
    WHERE
        c.TABLE_SCHEMA = @TableSchema
        AND c.TABLE_NAME = @TableName
    ) c
    ORDER BY
        c.TABLE_SCHEMA
        , c.TABLE_NAME
        , c.ORDINAL_POSITION

SET @SelectField = ''
SET @UpdateField = ''
SET @InsertField = ''
SET @InsertValue = ''
SET @UpdateParam = ''
SET @DeleteParam = ''
SET @DeleteWhere = ''

SET @SelectJoin = ''
SET @UpdateCode = ''

OPEN FieldCursor
FETCH NEXT FROM FieldCursor
INTO 
    @TABLE_SCHEMA
    , @TABLE_NAME
    , @ORDINAL_POSITION
    , @COLUMN_NAME
    , @DATA_TYPE
    , @CHARACTER_MAXIMUM_LENGTH
    , @NUMERIC_PRECISION
    , @NUMERIC_SCALE
    , @IS_NULLABLE
    , @IS_IDENTITY
    , @IS_ROWGUIDCOL
    , @IS_COMPUTED

    , @CONSTRAINT_TYPE

    , @LINKED_TABLE_SCHEMA
    , @LINKED_TABLE_NAME
    , @LINKED_COLUMN_NAME
    
    , @UNIQUE_COLUMN_NAME
    , @UNIQUE_IS_NULLABLE
    , @UNIQUE_DATA_TYPE
    , @UNIQUE_CHARACTER_MAXIMUM_LENGTH
    , @UNIQUE_NUMERIC_PRECISION
    , @UNIQUE_NUMERIC_SCALE
WHILE @@FETCH_STATUS = 0
    BEGIN

    IF @UNIQUE_COLUMN_NAME IS NULL
        BEGIN

        IF @DATA_TYPE = 'uniqueidentifier'
            SET @SelectField = @SelectField + @Tab + @Tab+ ', CAST(t.[' + @COLUMN_NAME +'] AS varchar(56)) AS [' + @COLUMN_NAME +']'+ @CrLf
        ELSE
            SET @SelectField = @SelectField + @Tab + @Tab+ ', t.[' + @COLUMN_NAME +'] AS [' + @COLUMN_NAME +']'+ @CrLf

        SET @UpdateParam = @UpdateParam + @Tab + ', @' + @COLUMN_NAME + ' ' + @DATA_TYPE

        IF ISNULL(@CHARACTER_MAXIMUM_LENGTH, 0) > 0
            SET @UpdateParam = @UpdateParam + '(' + CAST(@CHARACTER_MAXIMUM_LENGTH AS varchar(10)) + ')'

        IF @IS_NULLABLE = 'YES'
            SET @UpdateParam = @UpdateParam + ' = NULL'

        END
    ELSE
        BEGIN
        IF @UNIQUE_DATA_TYPE = 'uniqueidentifier'
            SET @SelectField = @SelectField + @Tab + @Tab+ ', CAST(' + @LINKED_TABLE_SCHEMA + '.' + @LINKED_TABLE_NAME + '.[' + @UNIQUE_COLUMN_NAME +'] AS varchar(56)) AS [' + @LINKED_TABLE_NAME + @COLUMN_NAME +']'+ @CrLf
        ELSE
            SET @SelectField = @SelectField + @Tab + @Tab+ ', ' + @LINKED_TABLE_SCHEMA + '.' + @LINKED_TABLE_NAME + '.[' + @UNIQUE_COLUMN_NAME +'] AS [' + @LINKED_TABLE_NAME + @UNIQUE_COLUMN_NAME +']'+ @CrLf

        SET @UpdateParam = @UpdateParam + @Tab + ', @' + @LINKED_TABLE_NAME + @UNIQUE_COLUMN_NAME + ' ' + @UNIQUE_DATA_TYPE

        IF ISNULL(@UNIQUE_CHARACTER_MAXIMUM_LENGTH, 0) > 0
            SET @UpdateParam = @UpdateParam + '(' + CAST(@UNIQUE_CHARACTER_MAXIMUM_LENGTH AS varchar(10)) + ')'

        IF @UNIQUE_IS_NULLABLE = 'YES'
            SET @UpdateParam = @UpdateParam + ' = NULL'
            
        SET @SelectJoin = @SelectJoin
                + @Tab + @Tab + 'LEFT OUTER JOIN ' + @LINKED_TABLE_SCHEMA + '.' + @LINKED_TABLE_NAME
                + ' ON ' + @LINKED_TABLE_SCHEMA + '.' + @LINKED_TABLE_NAME + '.[' + @LINKED_COLUMN_NAME + ']'
                + ' = t.[' + @COLUMN_NAME + ']' + @CrLf

        SET @FullDataType = @DATA_TYPE
        IF ISNULL(@CHARACTER_MAXIMUM_LENGTH, 0) > 0
            SET @FullDataType = @FullDataType + '(' + CAST(@CHARACTER_MAXIMUM_LENGTH AS varchar(10)) + ')'
                
        SET @UpdateCode = @UpdateCode
                        + @Tab + 'DECLARE @' + @COLUMN_NAME  + ' ' + @FullDataType + @CrLf + @CrLf
                        
                        + @Tab + 'IF @' + @LINKED_TABLE_NAME + @UNIQUE_COLUMN_NAME + ' IS NULL' + @CrLf
                        + @Tab + @Tab + 'SET @' + @COLUMN_NAME + ' = NULL' + @CrLf
                        + @Tab + 'ELSE' + @CrLf
                        + @Tab + @Tab + 'BEGIN' + @CrLf
                        + @Tab + @Tab + 'SET @' + @COLUMN_NAME + ' = (SELECT [' + @LINKED_COLUMN_NAME + ']'
                        + ' FROM ' + @LINKED_TABLE_SCHEMA + '.' + @LINKED_TABLE_NAME + ''
                        + ' WHERE [' + @UNIQUE_COLUMN_NAME + '] = @' + @LINKED_TABLE_NAME + @UNIQUE_COLUMN_NAME
                        + ')' + @CrLf+ @CrLf
                        
                        + @Tab + @Tab + 'IF @'+ @COLUMN_NAME + ' IS NULL ' + @CrLf
                        + @Tab + @Tab + @Tab + 'BEGIN' + @CrLf

                        + @Tab + @Tab + @Tab + 'INSERT ' + @LINKED_TABLE_SCHEMA + '.' + @LINKED_TABLE_NAME + '' + @CrLf
                        + @Tab + @Tab + @Tab + @Tab + '([' + @UNIQUE_COLUMN_NAME + '])' + @CrLf
                        + @Tab + @Tab + @Tab + 'VALUES' + @CrLf
                        + @Tab + @Tab + @Tab + @Tab + '(@' + @LINKED_TABLE_NAME + @UNIQUE_COLUMN_NAME + ')' + @CrLf + @CrLf

                        + @Tab + @Tab + @Tab + 'SET @' + @COLUMN_NAME + ' = (SELECT [' + @LINKED_COLUMN_NAME + ']'
                        + ' FROM ' + @LINKED_TABLE_SCHEMA + '.' + @LINKED_TABLE_NAME + ''
                        + ' WHERE [' + @UNIQUE_COLUMN_NAME + '] = @' + @LINKED_TABLE_NAME + @UNIQUE_COLUMN_NAME
                        + ')' + @CrLf

                        + @Tab + @Tab + @Tab + 'END' + @CrLf
                        + @Tab + @Tab + 'END' + @CrLf + @CrLf + @CrLf

        END
    
    IF NOT (@IS_IDENTITY = 1 OR @IS_COMPUTED = 1)
        BEGIN
        SET @InsertField = @InsertField + @Tab + @Tab+ ', [' + @COLUMN_NAME + ']' + @CrLf
        SET @InsertValue = @InsertValue + @Tab + @Tab+ ', @' + @COLUMN_NAME + @CrLf
        END

    SET @UpdateParam = @UpdateParam + @CrLf

    IF ISNULL(@CONSTRAINT_TYPE, '') = 'PRIMARY KEY'
        BEGIN
        SET @DeleteParam = @DeleteParam + @Tab + ', @' + @COLUMN_NAME + ' ' + @DATA_TYPE
        IF NOT @CHARACTER_MAXIMUM_LENGTH IS NULL
            SET @DeleteParam = @DeleteParam + '(' + CAST(@CHARACTER_MAXIMUM_LENGTH AS varchar(10)) + ')'

        SET @DeleteParam = @DeleteParam + @CrLf
        
        SET @DeleteWhere = @DeleteWhere + @Tab + @Tab + 'AND [' + @COLUMN_NAME + '] = @' + @COLUMN_NAME + @CrLf
        END
    ELSE
        BEGIN
        SET @UpdateField = @UpdateField + @Tab + @Tab+ ', [' + @COLUMN_NAME + '] = @' + @COLUMN_NAME + @CrLf
        END

    FETCH NEXT FROM FieldCursor
    INTO
        @TABLE_SCHEMA
        , @TABLE_NAME
        , @ORDINAL_POSITION
        , @COLUMN_NAME
        , @DATA_TYPE
        , @CHARACTER_MAXIMUM_LENGTH
        , @NUMERIC_PRECISION
        , @NUMERIC_SCALE
        , @IS_NULLABLE
        , @IS_IDENTITY
        , @IS_ROWGUIDCOL
        , @IS_COMPUTED

        , @CONSTRAINT_TYPE

        , @LINKED_TABLE_SCHEMA
        , @LINKED_TABLE_NAME
        , @LINKED_COLUMN_NAME
        
        , @UNIQUE_COLUMN_NAME
        , @UNIQUE_IS_NULLABLE
        , @UNIQUE_DATA_TYPE
        , @UNIQUE_CHARACTER_MAXIMUM_LENGTH
        , @UNIQUE_NUMERIC_PRECISION
        , @UNIQUE_NUMERIC_SCALE
    END

CLOSE FieldCursor
DEALLOCATE FieldCursor

-- Remove commas
SET @SelectField = @Tab + @Tab + ' ' + SUBSTRING(@SelectField, 10, LEN(@SelectField))
SET @InsertField = @Tab + @Tab + '(' + SUBSTRING(@InsertField, 10, LEN(@InsertField)) + @Tab + @Tab + ')'+@CrLf
SET @InsertValue = @Tab + @Tab + '(' + SUBSTRING(@InsertValue, 10, LEN(@InsertValue)) + @Tab + @Tab + ')'+@CrLf
SET @UpdateField = @Tab + @Tab + ' ' + SUBSTRING(@UpdateField, 10, LEN(@UpdateField))
SET @UpdateParam = @Tab + ' ' + SUBSTRING(@UpdateParam, 6, LEN(@UpdateParam))
SET @DeleteParam = @Tab + ' ' + SUBSTRING(@DeleteParam, 6, LEN(@DeleteParam))
SET @DeleteWhere = @Tab + @Tab + SUBSTRING(@DeleteWhere, 13, LEN(@DeleteWhere))

DECLARE @SelectName nvarchar(128)
DECLARE @InsertName nvarchar(128)
DECLARE @UpdateName nvarchar(128)
DECLARE @DeleteName nvarchar(128)

SET @SelectName = @TargetSchema + '.[usp' + @TABLE_NAME + '_select]'
SET @InsertName = @TargetSchema + '.[usp' + @TABLE_NAME + '_insert]'
SET @UpdateName = @TargetSchema + '.[usp' + @TABLE_NAME + '_update]'
SET @DeleteName = @TargetSchema + '.[usp' + @TABLE_NAME + '_delete]'

DECLARE @HeaderText nvarchar(4000)
SET @HeaderText = ''

SET @SelectSQL = ''
        + @HeaderText
        + 'CREATE PROCEDURE ' + @SelectName + @CrLf
        + 'AS' + @CrLf
        + 'BEGIN' + @CrLf
        + @CrLf
        + @Tab + 'SELECT' + @CrLf
        + @SelectField
        + @Tab + 'FROM'+ @CrLf
        + @Tab + @Tab + ''+ @TABLE_SCHEMA + '.' + @TABLE_NAME + ' t' + @CrLf
        + @SelectJoin
        + @CrLf
        + 'END' + @CrLf

SET @InsertSQL =  ''
        + @HeaderText
        + 'CREATE PROCEDURE ' + @InsertName + @CrLf
        + @UpdateParam
        + 'AS' + @CrLf
        + 'BEGIN' + @CrLf
        + @Tab + 'SET NOCOUNT ON' + @CrLf
        + @CrLf
        + @UpdateCode
        + @Tab + 'INSERT INTO ' + @TABLE_SCHEMA + '.' + @TABLE_NAME + ''+  @CrLf
        + @InsertField
        + @Tab + 'VALUES' + @CrLf
        + @InsertValue
        + @CrLf
        + 'END' + @CrLf

SET @UpdateSQL = ''
        + @HeaderText
        + 'CREATE PROCEDURE ' + @UpdateName + @CrLf
        + @UpdateParam
        + 'AS' + @CrLf
        + 'BEGIN' + @CrLf
        + @Tab + 'SET NOCOUNT ON' + @CrLf
        + @CrLf
        + @UpdateCode
        + @Tab + 'UPDATE ' + @TABLE_SCHEMA + '.' + @TABLE_NAME + '' + @CrLf
        + @Tab + 'SET' + @CrLf
        + @UpdateField
        + @Tab + 'WHERE' + @CrLf
        + @DeleteWhere
        + @CrLf
        + 'END' + @CrLf

SET @DeleteSQL = ''
        + @HeaderText
        + 'CREATE PROCEDURE ' + @DeleteName + @CrLf
        + @DeleteParam
        + 'AS' + @CrLf
        + 'BEGIN' + @CrLf
        + @Tab + 'SET NOCOUNT ON' + @CrLf
        + @CrLf
        + @Tab + 'DELETE ' + @TABLE_SCHEMA + '.' + @TABLE_NAME + '' + @CrLf
        + @Tab + 'WHERE' + @CrLf
        + @DeleteWhere
        + @CrLf
        + 'END' + @CrLf

DECLARE @DeleteSelectSQL nvarchar(4000)
DECLARE @DeleteInsertSQL nvarchar(4000)
DECLARE @DeleteUpdateSQL nvarchar(4000)
DECLARE @DeleteDeleteSQL nvarchar(4000)

SET @DeleteSelectSQL = ''
    + 'IF EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N''' + @SelectName + ''') AND [type] in (N''P'', N''PC''))' + @CrLf
    + @Tab + 'DROP PROCEDURE '+ @SelectName + @CrLf + @CrLf

SET @DeleteInsertSQL = ''
    + 'IF EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N''' + @InsertName + ''') AND [type] in (N''P'', N''PC''))' + @CrLf
    + @Tab + 'DROP PROCEDURE '+ @InsertName + @CrLf + @CrLf

SET @DeleteUpdateSQL = ''
    + 'IF EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N''' + @UpdateName + ''') AND [type] in (N''P'', N''PC''))' + @CrLf
    + @Tab + 'DROP PROCEDURE '+ @UpdateName + @CrLf + @CrLf

SET @DeleteDeleteSQL = ''
    + 'IF EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N''' + @DeleteName + ''') AND [type] in (N''P'', N''PC''))' + @CrLf
    + @Tab + 'DROP PROCEDURE '+ @DeleteName + @CrLf + @CrLf

-- Debug print
--PRINT 'SelectField:' + @CrLf + @SelectField
--PRINT 'InsertField:' + @CrLf + @InsertField
--PRINT 'InsertValue:' + @CrLf + @InsertValue
--PRINT 'UpdateField:' + @CrLf + @UpdateField
--PRINT 'UpdateParam:' + @CrLf + @UpdateParam
--PRINT 'DeleteParam:' + @CrLf + @DeleteParam
--PRINT 'DeleteWhere:' + @CrLf + @DeleteWhere
--PRINT 'SelectJoin:'  + @CrLf + @SelectJoin
--PRINT 'UpdateCode:'  + @CrLf + @UpdateCode

PRINT @DeleteSelectSQL
PRINT @SelectSQL
PRINT @DeleteInsertSQL
PRINT @InsertSQL
PRINT @DeleteUpdateSQL
PRINT @UpdateSQL
PRINT @DeleteDeleteSQL
PRINT @DeleteSQL

IF @ExecuteScript = 1
    BEGIN
    IF @RecreateProceduresIfExist = 1
        BEGIN
        EXEC (@DeleteSelectSQL)
        EXEC (@DeleteInsertSQL)
        EXEC (@DeleteUpdateSQL)
        EXEC (@DeleteDeleteSQL)
        END

    IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(@SelectName) AND [type] in (N'P', N'PC'))
        EXEC (@SelectSQL)
    IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(@InsertName) AND [type] in (N'P', N'PC'))
        EXEC (@InsertSQL)
    IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(@UpdateName) AND [type] in (N'P', N'PC'))
        EXEC (@UpdateSQL)
    IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(@DeleteName) AND [type] in (N'P', N'PC'))
        EXEC (@DeleteSQL)
    
    END

END
GO

print N'EditProcedures objects have been created';
GO

CREATE ROLE [SaveToDB_developers] AUTHORIZATION [dbo]
GO
CREATE ROLE [SaveToDB_users] AUTHORIZATION [dbo]
GO

GRANT SELECT, EXECUTE, INSERT, UPDATE, DELETE, VIEW DEFINITION ON SCHEMA::[dbo01] TO [SaveToDB_developers] AS [dbo]
GO
GRANT SELECT, EXECUTE, VIEW DEFINITION ON SCHEMA::[etl01] TO [SaveToDB_developers] AS [dbo]
GO
GRANT SELECT, EXECUTE, VIEW DEFINITION ON SCHEMA::[xls01] TO [SaveToDB_developers] AS [dbo]
GO
GRANT SELECT, EXECUTE ON SCHEMA::[xls01] TO [SaveToDB_users] AS [dbo]
GO

print N'Roles have been created';
GO

SET NOCOUNT ON;

INSERT INTO [dbo01].[QueryList] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'xls01', N'viewTableFormats',      N'VIEW', NULL, N'dbo01.TableFormats', N'dbo01.TableFormats', N'dbo01.TableFormats', N'TABLE');
INSERT INTO [dbo01].[QueryList] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'xls01', N'viewParameterValues',   N'VIEW', NULL, N'dbo01.ParameterValues', N'dbo01.ParameterValues', N'dbo01.ParameterValues', N'TABLE');
INSERT INTO [dbo01].[QueryList] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'xls01', N'viewEventHandlers',     N'VIEW', NULL, N'dbo01.EventHandlers', N'dbo01.EventHandlers', N'dbo01.EventHandlers', N'TABLE');
INSERT INTO [dbo01].[QueryList] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'xls01', N'viewObjectDescription', N'VIEW', NULL, N'dbo01.ObjectTranslation', N'dbo01.ObjectTranslation', N'dbo01.ObjectTranslation', N'TABLE');
INSERT INTO [dbo01].[QueryList] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'xls01', N'viewObjectTranslation', N'VIEW', NULL, N'dbo01.ObjectTranslation', N'dbo01.ObjectTranslation', N'dbo01.ObjectTranslation', N'TABLE');
INSERT INTO [dbo01].[QueryList] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'xls01', N'viewColumnTranslation', N'VIEW', NULL, N'dbo01.ColumnTranslation', N'dbo01.ColumnTranslation', N'dbo01.ColumnTranslation', N'TABLE');

INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'ColumnTranslation', NULL, N'Actions', N'etl01', N'uspUpdateColumnTranslation', N'PROCEDURE', NULL, N'_Reload', 1, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'ColumnTranslation', NULL, N'Actions', N'etl01', N'uspUpdateColumnTranslation_Group', N'PROCEDURE', NULL, N'_Reload', 2, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'ColumnTranslation', NULL, N'Actions', NULL, N'MenuSeparator', N'MENUSEPARATOR', NULL, NULL, 10, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'ColumnTranslation', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/help4/configuring-translation.htm', NULL, 11, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'ObjectTranslation', NULL, N'Actions', N'etl01', N'uspUpdateObjectTranslationAbsent', N'PROCEDURE', NULL, N'_Reload', 1, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'ObjectTranslation', NULL, N'Actions', N'etl01', N'uspUpdateObjectTranslation', N'PROCEDURE', NULL, N'_Reload', 2, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'ObjectTranslation', NULL, N'Actions', NULL, N'MenuSeparator', N'MENUSEPARATOR', NULL, NULL, 10, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'ObjectTranslation', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/help4/configuring-translation.htm', NULL, 11, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'EventHandlers', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/help4/configuring-event-handlers.htm', NULL, 11, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'ParameterValues', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/help4/configuring-parameter-values.htm', NULL, 11, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'QueryList', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/help4/configuring-query-list.htm', NULL, 11, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'TableFormats', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/help4/configuring-table-formats.htm', NULL, 11, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls01', N'viewColumnTranslation', NULL, N'Actions', N'etl01', N'uspUpdateColumnTranslation', N'PROCEDURE', NULL, N'_Reload', 1, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls01', N'viewColumnTranslation', NULL, N'Actions', N'etl01', N'uspUpdateColumnTranslation_Group', N'PROCEDURE', NULL, N'_Reload', 2, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls01', N'viewColumnTranslation', NULL, N'Actions', NULL, N'MenuSeparator', N'MENUSEPARATOR', NULL, NULL, 10, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls01', N'viewColumnTranslation', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/help4/configuring-translation.htm', NULL, 11, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls01', N'viewObjectTranslation', NULL, N'Actions', N'etl01', N'uspUpdateObjectTranslationAbsent', N'PROCEDURE', NULL, N'_Reload', 1, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls01', N'viewObjectTranslation', NULL, N'Actions', N'etl01', N'uspUpdateObjectTranslation', N'PROCEDURE', NULL, N'_Reload', 2, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls01', N'viewObjectTranslation', NULL, N'Actions', NULL, N'MenuSeparator', N'MENUSEPARATOR', NULL, NULL, 10, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls01', N'viewObjectTranslation', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/help4/configuring-translation.htm', NULL, 11, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls01', N'viewEventHandlers', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/help4/configuring-event-handlers.htm', NULL, 11, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls01', N'viewParameterValues', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/help4/configuring-parameter-values.htm', NULL, 11, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'viewQueryList', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/help4/configuring-query-list.htm', NULL, 11, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls01', N'viewQueryList', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/help4/configuring-query-list.htm', NULL, 11, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'xls01', N'viewTableFormats', NULL, N'Actions', N'http01', N'Online Help', N'HTTP', N'http://www.savetodb.com/help4/configuring-table-formats.htm', NULL, 11, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'QueryList', NULL, N'Actions', NULL, N'MenuSeparator', N'MENUSEPARATOR', NULL, NULL, 10, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'QueryList', NULL, N'Actions', N'tools01', N'Update Types', N'CODE', N'UPDATE dbo01.QueryList
SET
    TABLE_SCHEMA = t.TABLE_SCHEMA
    , TABLE_NAME = t.TABLE_NAME
    , TABLE_TYPE = t.TABLE_TYPE
    , TABLE_CODE = t.TABLE_CODE
    , INSERT_PROCEDURE = t.INSERT_PROCEDURE
    , UPDATE_PROCEDURE = t.UPDATE_PROCEDURE
    , DELETE_PROCEDURE = t.DELETE_PROCEDURE
    , PROCEDURE_TYPE = t.PROCEDURE_TYPE
FROM
    dbo01.QueryList c
    INNER JOIN (
        SELECT
            c.ID
            , COALESCE(t.TABLE_SCHEMA, r.ROUTINE_SCHEMA, c.TABLE_SCHEMA) AS TABLE_SCHEMA
            , COALESCE(t.TABLE_NAME, r.ROUTINE_NAME, c.TABLE_NAME) AS TABLE_NAME
            , COALESCE(t.TABLE_TYPE, r.ROUTINE_TYPE, c.TABLE_TYPE) AS TABLE_TYPE
            , c.TABLE_CODE
            , COALESCE(t1.TABLE_SCHEMA + ''.'' + t1.TABLE_NAME, r1.ROUTINE_SCHEMA + ''.'' + r1.ROUTINE_NAME, c.INSERT_PROCEDURE) AS INSERT_PROCEDURE
            , COALESCE(t2.TABLE_SCHEMA + ''.'' + t2.TABLE_NAME, r2.ROUTINE_SCHEMA + ''.'' + r2.ROUTINE_NAME, c.UPDATE_PROCEDURE) AS UPDATE_PROCEDURE
            , COALESCE(t3.TABLE_SCHEMA + ''.'' + t3.TABLE_NAME, r3.ROUTINE_SCHEMA + ''.'' + r3.ROUTINE_NAME, c.DELETE_PROCEDURE) AS DELETE_PROCEDURE
            , CASE
                WHEN c.INSERT_PROCEDURE IS NULL THEN NULL
                WHEN r3.ROUTINE_NAME IS NOT NULL THEN ''PROCEDURE''
                WHEN t3.TABLE_NAME IS NOT NULL THEN ''TABLE''
                WHEN c.DELETE_PROCEDURE IS NOT NULL THEN ''CODE''
                WHEN r1.ROUTINE_NAME IS NOT NULL THEN ''PROCEDURE''
                WHEN t1.TABLE_NAME IS NOT NULL THEN ''MERGE''
                ELSE ''CODE''
                END AS PROCEDURE_TYPE
        FROM
            dbo01.QueryList c
            LEFT OUTER JOIN INFORMATION_SCHEMA.TABLES t ON UPPER(t.TABLE_SCHEMA) = UPPER(c.TABLE_SCHEMA) AND UPPER(t.TABLE_NAME) = UPPER(c.TABLE_NAME)
            LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES r ON UPPER(r.ROUTINE_SCHEMA) = UPPER(c.TABLE_SCHEMA) AND UPPER(r.ROUTINE_NAME) = UPPER(c.TABLE_NAME)
            LEFT OUTER JOIN INFORMATION_SCHEMA.TABLES t1 ON UPPER(t1.TABLE_SCHEMA + ''.'' + t1.TABLE_NAME) = UPPER(c.INSERT_PROCEDURE)
            LEFT OUTER JOIN INFORMATION_SCHEMA.TABLES t2 ON UPPER(t2.TABLE_SCHEMA + ''.'' + t2.TABLE_NAME) = UPPER(c.UPDATE_PROCEDURE)
            LEFT OUTER JOIN INFORMATION_SCHEMA.TABLES t3 ON UPPER(t3.TABLE_SCHEMA + ''.'' + t3.TABLE_NAME) = UPPER(c.DELETE_PROCEDURE)
            LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES r1 ON UPPER(r1.ROUTINE_SCHEMA + ''.'' + r1.ROUTINE_NAME) = UPPER(c.INSERT_PROCEDURE)
            LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES r2 ON UPPER(r2.ROUTINE_SCHEMA + ''.'' + r2.ROUTINE_NAME) = UPPER(c.UPDATE_PROCEDURE)
            LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES r3 ON UPPER(r3.ROUTINE_SCHEMA + ''.'' + r3.ROUTINE_NAME) = UPPER(c.DELETE_PROCEDURE)
    ) t ON t.ID = c.ID
', N'_Reload', 1, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'EventHandlers', NULL, N'Actions', NULL, N'MenuSeparator', N'MENUSEPARATOR', NULL, NULL, 10, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'EventHandlers', NULL, N'Actions', N'tools01', N'Update Types', N'CODE', N'UPDATE dbo01.EventHandlers
SET
    TABLE_SCHEMA = t.TABLE_SCHEMA
    , TABLE_NAME = t.TABLE_NAME
    , COLUMN_NAME = t.COLUMN_NAME
    , EVENT_NAME = t.EVENT_NAME
    , HANDLER_SCHEMA = t.HANDLER_SCHEMA
    , HANDLER_NAME = t.HANDLER_NAME
    , HANDLER_TYPE = t.HANDLER_TYPE
    , HANDLER_CODE = t.HANDLER_CODE
    , TARGET_WORKSHEET = t.TARGET_WORKSHEET
    , MENU_ORDER = t.MENU_ORDER
    , EDIT_PARAMETERS = t.EDIT_PARAMETERS
    , IS_ACTIVE = t.IS_ACTIVE
FROM
    dbo01.EventHandlers c
    INNER JOIN (
        SELECT
            c.ID
            , COALESCE(t.TABLE_SCHEMA, r.ROUTINE_SCHEMA, c.TABLE_SCHEMA) AS TABLE_SCHEMA
            , COALESCE(t.TABLE_NAME, r.ROUTINE_NAME, c.TABLE_NAME) AS TABLE_NAME
            , CASE UPPER(c.COLUMN_NAME)
                WHEN ''ACTIONS'' THEN ''Actions''
                WHEN ''CHANGE'' THEN ''Change''
                WHEN ''CONTEXTMENU'' THEN ''ContextMenu''
                WHEN ''DOUBLECLICK'' THEN ''DoubleClick''
                WHEN ''SELECTIONCHANGE'' THEN ''SelectionChange''
                ELSE c.COLUMN_NAME
                END AS COLUMN_NAME
            , c.EVENT_NAME
            , COALESCE(t1.TABLE_SCHEMA, r1.ROUTINE_SCHEMA, t2.TABLE_SCHEMA, r2.ROUTINE_SCHEMA, c.HANDLER_SCHEMA, CASE
                WHEN c.HANDLER_TYPE IN (''HTTP'', ''TEXT'', ''CODE'', ''MACRO'', ''CMD'') THEN LOWER(c.HANDLER_TYPE)
                WHEN CHARINDEX(''http://'', c.HANDLER_CODE) = 1 THEN ''http''
                WHEN CHARINDEX(''https://'', c.HANDLER_CODE) = 1 THEN ''http''
                ELSE NULL
                END) AS HANDLER_SCHEMA
            , COALESCE(t1.TABLE_NAME, r1.ROUTINE_NAME, t2.TABLE_NAME, r2.ROUTINE_NAME, c.HANDLER_NAME) AS HANDLER_NAME
            , COALESCE(t1.TABLE_TYPE, r1.ROUTINE_TYPE, t2.TABLE_TYPE, r2.ROUTINE_TYPE, c.HANDLER_TYPE, CASE
                WHEN CHARINDEX(''http://'', c.HANDLER_CODE) = 1 THEN ''HTTP''
                WHEN CHARINDEX(''https://'', c.HANDLER_CODE) = 1 THEN ''HTTP''
                WHEN UPPER(c.HANDLER_NAME) = ''MENUSEPARATOR'' THEN ''MENUSEPARATOR''
                ELSE NULL
                END) AS HANDLER_TYPE
            , c.HANDLER_CODE
            , c.TARGET_WORKSHEET
            , c.MENU_ORDER
            , c.EDIT_PARAMETERS
            , c.IS_ACTIVE
        FROM
            dbo01.EventHandlers c
            LEFT OUTER JOIN INFORMATION_SCHEMA.TABLES t ON UPPER(t.TABLE_SCHEMA) = UPPER(c.TABLE_SCHEMA) AND UPPER(t.TABLE_NAME) = UPPER(c.TABLE_NAME)
            LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES r ON UPPER(r.ROUTINE_SCHEMA) = UPPER(c.TABLE_SCHEMA) AND UPPER(r.ROUTINE_NAME) = UPPER(c.TABLE_NAME)
            LEFT OUTER JOIN INFORMATION_SCHEMA.TABLES t1 ON UPPER(t1.TABLE_SCHEMA) = UPPER(c.HANDLER_SCHEMA) AND UPPER(t1.TABLE_NAME) = UPPER(c.HANDLER_NAME)
            LEFT OUTER JOIN INFORMATION_SCHEMA.TABLES t2 ON UPPER(t2.TABLE_SCHEMA + ''.'' + t2.TABLE_NAME) = UPPER(c.HANDLER_NAME)
            LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES r1 ON UPPER(r1.ROUTINE_SCHEMA) = UPPER(c.HANDLER_SCHEMA) AND UPPER(r1.ROUTINE_NAME) = UPPER(c.HANDLER_NAME)
            LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES r2 ON UPPER(r2.ROUTINE_SCHEMA + ''.'' + r2.ROUTINE_NAME) = UPPER(c.HANDLER_NAME)
    ) t ON t.ID = c.ID
', N'_Reload', 1, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'ParameterValues', NULL, N'Actions', NULL, N'MenuSeparator', N'MENUSEPARATOR', NULL, NULL, 10, NULL, 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'dbo01', N'ParameterValues', NULL, N'Actions', N'tools01', N'Update Types', N'CODE', N'UPDATE dbo01.ParameterValues
SET
    TABLE_SCHEMA = t.TABLE_SCHEMA
    , TABLE_NAME = t.TABLE_NAME
    , PARAMETER_NAME = t.PARAMETER_NAME
    , SELECT_SCHEMA = t.SELECT_SCHEMA
    , SELECT_NAME = t.SELECT_NAME
    , SELECT_TYPE = t.SELECT_TYPE
    , SELECT_CODE = t.SELECT_CODE
FROM
    dbo01.ParameterValues c
    INNER JOIN (
        SELECT
            c.ID
            , COALESCE(t.TABLE_SCHEMA, r.ROUTINE_SCHEMA, c.TABLE_SCHEMA) AS TABLE_SCHEMA
            , COALESCE(t.TABLE_NAME, r.ROUTINE_NAME, c.TABLE_NAME) AS TABLE_NAME
            , c.PARAMETER_NAME
            , COALESCE(t1.TABLE_SCHEMA, r1.ROUTINE_SCHEMA, t2.TABLE_SCHEMA, r2.ROUTINE_SCHEMA, c.SELECT_SCHEMA, CASE
                WHEN c.SELECT_TYPE IN (''CODE'') THEN ''code''
                ELSE NULL
                END) AS SELECT_SCHEMA
            , COALESCE(t1.TABLE_NAME, r1.ROUTINE_NAME, t2.TABLE_NAME, r2.ROUTINE_NAME, c.SELECT_NAME) AS SELECT_NAME
            , COALESCE(t1.TABLE_TYPE, t2.TABLE_TYPE, r1.ROUTINE_TYPE, r2.ROUTINE_TYPE, c.SELECT_TYPE) AS SELECT_TYPE
            , c.SELECT_CODE
        FROM
            dbo01.ParameterValues c
            LEFT OUTER JOIN INFORMATION_SCHEMA.TABLES t ON UPPER(t.TABLE_SCHEMA) = UPPER(c.TABLE_SCHEMA) AND UPPER(t.TABLE_NAME) = UPPER(c.TABLE_NAME)
            LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES r ON UPPER(r.ROUTINE_SCHEMA) = UPPER(c.TABLE_SCHEMA) AND UPPER(r.ROUTINE_NAME) = UPPER(c.TABLE_NAME)
            LEFT OUTER JOIN INFORMATION_SCHEMA.TABLES t1 ON UPPER(t1.TABLE_SCHEMA) = UPPER(c.SELECT_SCHEMA) AND UPPER(t1.TABLE_NAME) = UPPER(c.SELECT_NAME)
            LEFT OUTER JOIN INFORMATION_SCHEMA.TABLES t2 ON UPPER(t2.TABLE_SCHEMA + ''.'' + t2.TABLE_NAME) = UPPER(c.SELECT_NAME)
            LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES r1 ON UPPER(r1.ROUTINE_SCHEMA) = UPPER(c.SELECT_SCHEMA) AND UPPER(r1.ROUTINE_NAME) = UPPER(c.SELECT_NAME)
            LEFT OUTER JOIN INFORMATION_SCHEMA.ROUTINES r2 ON UPPER(r2.ROUTINE_SCHEMA + ''.'' + r2.ROUTINE_NAME) = UPPER(c.SELECT_NAME)
    ) t ON t.ID = c.ID
', N'_Reload', 1, NULL, 1);

INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'dbo01', N'ColumnTranslation', 'en', NULL, N'Configuration Table of Column Translation', N'The table defines translation for Excel table headers and ribbon fields');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'dbo01', N'EventHandlers', 'en', NULL, N'Configuration Table of Excel Event Handlers', N'The table defines Excel event handlers and Actions and Context Menu items');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'dbo01', N'ObjectTranslation', 'en', NULL, N'Configuration Table of Object Translation', N'The table defines translation for Query List, Actions and Context Menu items');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'dbo01', N'ParameterValues', 'en', NULL, N'Configuration Table of Parameter Value Queries', N'The table defines objects to select ribbon parameter values');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'dbo01', N'QueryList', 'en', NULL, N'Configuration Table of Query List', N'The table defines configuration of Query List objects');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'dbo01', N'TableFormats', 'en', NULL, N'Configuration Table of Excel Table Formats', N'The table contains Excel formats of database objects');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'dbo01', N'uspUpdateTableFormat', 'en', NULL, N'Configuration Procedure to Save Table Formats', N'The procedure is used to save Excel formats of database objects');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'dbo01', N'viewQueryList', N'en', N'Base Framework Query List', N'Configuration View of Query List with All Database Objects', N'The view selects all the database objects and is used as a source for other query list views');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'dbo01', N'viewQueryListTools', N'en', N'Framework Tools Query List', N'Configuration View of Query List of Framework Tools', N'The view selects SaveToDB Framework Tools objects');

INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'etl01', N'uspGenerateChangeHandler', N'en', NULL, N'Procedure to Generate Cell Change Handler', N'The procedure is used to generate a cell change handler.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'etl01', N'uspGenerateGenegicHandler', N'en', NULL, N'Procedure to Generate Generic Handler', N'The procedure is used to generate a generic handler.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'etl01', N'uspGenerateEditProcedures', 'en', NULL, N'Procedure to Generate CRUD Procedures', N'The procedure is used to generate SELECT, INSERT, UPDATE and DELETE procedures.
The result code includes related tables of primary keys also.
Use SQL Server Management Studio to generate and edit the procedures.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'etl01', N'uspUpdateColumnTranslation', 'en', N'Add Column Translation', N'Procedure to Insert Column Translations', N'The procedure is used to insert new column translation data into the ColumnTranslation table.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'etl01', N'uspUpdateColumnTranslation_Group', 'en', N'Add Column Group Translation', N'Procedure to Insert Column Group Translations', N'The procedure is used to insert new translation data for group of columns and parameters into the ColumnTranslation table.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'etl01', N'uspUpdateEventHandlers', 'en', NULL, N'Procedure to Insert Event Handlers', N'The procedure is used to insert new event handler data into the EventHandlers table from viewEventHandlersSuggest.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'etl01', N'uspUpdateObjectTranslation', 'en', N'Add New Schema or Language Translation', N'Procedure to Insert New Schema or Language Object Translation', N'The procedure is used to insert translation data for new schemas or languages into the ObjectTranslation table.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'etl01', N'uspUpdateObjectTranslationAbsent', 'en', N'Add New Object Translation', N'Procedure to Insert New Object Translation of Existing Schema and Languages', N'The procedure is used to insert translation data for new objects of existing schemas and languages into
the ObjectTranslation table. viewObjectTranslationSuggest is used as a data source.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'etl01', N'viewEventHandlersSuggest', 'en', NULL, N'Data to Insert into EventHandlers Table', N'This view suggests possible new Excel event handlers based on a table relation analysis.');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'etl01', N'viewObjectTranslationSuggest', 'en', NULL, N'Data to Insert into ObjectTranslation Table', N'This view selects database objects that have no translation data in the ObjectTranslation table.
The uspUpdateObjectTranslationAbsent procedure is used to insert the data into the ObjectTranslation table.');

INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls01', N'viewColumnTranslation', N'en', NULL, N'Configuration View of Column Translation', N'The view selects column translation data used by the SaveToDB add-in');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls01', N'viewEventHandlers', N'en', NULL, N'Configuration View of Excel Event Handlers', N'The view selects event handler configurations used by the SaveToDB add-in');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls01', N'viewObjectDescription', N'en', N'Object Descriptions', N'Database Object Descriptions', N'You may use Query List to connect to these objects');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls01', N'viewObjectTranslation', N'en', NULL, N'Configuration View of Object Translation', N'The view selects object translation data used by the SaveToDB add-in');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls01', N'viewParameterValues', N'en', NULL, N'Configuration View of Parameter Value Queries', N'The view selects parameter configurations used by the SaveToDB add-in');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls01', N'viewQueryList', N'en', N'Framework Query List', N'Configuration View of Query List', N'The view selects a database object list used by the SaveToDB add-in');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'xls01', N'viewTableFormats', N'en', NULL, N'Configuration View of Excel Table Formats', N'The view selects saved table formats used by the SaveToDB add-in');

INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (N'http01', N'Online Help', N'en', N'Online Help', NULL, NULL);

INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ColumnTranslation', N'COLUMN_NAME', 'en', NULL, N'Column or parameter name');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ColumnTranslation', N'ID', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ColumnTranslation', N'LANGUAGE_NAME', 'en', NULL, N'Two-char language code');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ColumnTranslation', N'TABLE_NAME', 'en', NULL, N'Database object name or NULL for entire schema scope');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ColumnTranslation', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema or NULL for entire database scope');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ColumnTranslation', N'TRANSLATED_DESC', 'en', NULL, N'Text for Excel table header comments and ribbon parameter SuperTips');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ColumnTranslation', N'TRANSLATED_NAME', 'en', NULL, N'Translated name for Excel table headers and ribbon parameters');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'EventHandlers', N'COLUMN_NAME', 'en', NULL, N'Column name or NULL to use the handler for entire table');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'EventHandlers', N'EDIT_PARAMETERS', 'en', NULL, N'Show the Edit Parameters dialog box for Actions and Context Menu items: True/False/NULL (default behavior)');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'EventHandlers', N'EVENT_NAME', 'en', NULL, N'Actions, Change, ContextMenu, DoubleClick, or SelectionChange');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'EventHandlers', N'HANDLER_NAME', 'en', NULL, N'Database object name, unique name for SQL-code and http-query, or MenuSeparator');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'EventHandlers', N'HANDLER_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'EventHandlers', N'HANDLER_TYPE', 'en', NULL, N'Database object type, CODE for SQL-code, HTTP for http-query, or NULL for MenuSeparator');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'EventHandlers', N'ID', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'EventHandlers', N'IS_ACTIVE', 'en', NULL, N'True if the handler is active.');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'EventHandlers', N'MENU_ORDER', 'en', NULL, N'Sort order of Actions and Context Menu items');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'EventHandlers', N'TABLE_NAME', 'en', NULL, N'Database object name, SQL-code name, or http-query name');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'EventHandlers', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'EventHandlers', N'TARGET_WORKSHEET', 'en', NULL, N'NULL, sheet name, _new, _self, _reload. Additions: _RightWindow, _LeftWindow, _TopWindow, _BottomWindow');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ObjectTranslation', N'ID', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ObjectTranslation', N'LANGUAGE_NAME', 'en', NULL, N'Two-char language code');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ObjectTranslation', N'TABLE_NAME', 'en', NULL, N'Database object name or a name of SQL-code or http-query specified in Query List and Event Handlers');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ObjectTranslation', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ObjectTranslation', N'TRANSLATED_COMMENT', 'en', NULL, N'Text for SuperTips and SaveToDB_Comment named cells');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ObjectTranslation', N'TRANSLATED_DESC', 'en', NULL, N'Text for ScreenTips and SaveToDB_Desc named cells');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ObjectTranslation', N'TRANSLATED_NAME', 'en', NULL, N'Translated name for Query List, Actions and Context Menus');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ParameterValues', N'ID', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ParameterValues', N'PARAMETER_NAME', 'en', NULL, N'Column or parameter name');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ParameterValues', N'SELECT_NAME', 'en', NULL, N'Database object name or name for SQL-code');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ParameterValues', N'SELECT_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ParameterValues', N'SELECT_TYPE', 'en', NULL, N'Database object type or CODE for SQL-code');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ParameterValues', N'TABLE_NAME', 'en', NULL, N'Database object name');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'ParameterValues', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'QueryList', N'DELETE_PROCEDURE', 'en', NULL, N'Delete procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'QueryList', N'ID', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'QueryList', N'INSERT_PROCEDURE', 'en', NULL, N'Insert procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'QueryList', N'TABLE_NAME', 'en', NULL, N'Database object name or unique name for SQL-code and http-query');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'QueryList', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'QueryList', N'TABLE_TYPE', 'en', NULL, N'Database object type, CODE for SQL-code, or HTTP for http-query');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'QueryList', N'UPDATE_PROCEDURE', 'en', NULL, N'Update procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'TableFormats', N'ID', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'TableFormats', N'TABLE_EXCEL_FORMAT_XML', 'en', NULL, N'Excel table format XML');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'TableFormats', N'TABLE_NAME', 'en', NULL, N'Database object name');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'TableFormats', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'uspUpdateTableFormat', N'ExcelFormatXML', 'en', NULL, N'Excel table format XML');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'uspUpdateTableFormat', N'Name', 'en', NULL, N'Database object name');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'dbo01', N'uspUpdateTableFormat', N'Schema', 'en', NULL, N'Database object schema');

INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewColumnTranslation', N'COLUMN_NAME', 'en', NULL, N'Column or parameter name');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewColumnTranslation', N'ID', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewColumnTranslation', N'LANGUAGE_NAME', 'en', NULL, N'Two-char language code');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewColumnTranslation', N'TABLE_NAME', 'en', NULL, N'Database object name or NULL for entire schema scope');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewColumnTranslation', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema or NULL for entire database scope');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewColumnTranslation', N'TRANSLATED_DESC', 'en', NULL, N'Text for Excel table header comments and ribbon parameter SuperTips');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewColumnTranslation', N'TRANSLATED_NAME', 'en', NULL, N'Translated name for Excel table headers and ribbon parameters');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewEventHandlers', N'COLUMN_NAME', 'en', NULL, N'Column name or NULL to use the handler for entire table');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewEventHandlers', N'EDIT_PARAMETERS', 'en', NULL, N'Show the Edit Parameters dialog box for Actions and Context Menu items: True/False/NULL (default behavior)');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewEventHandlers', N'EVENT_NAME', 'en', NULL, N'Actions, Change, ContextMenu, DoubleClick, or SelectionChange');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewEventHandlers', N'HANDLER_NAME', 'en', NULL, N'Database object name, unique name for SQL-code and http-query, or MenuSeparator');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewEventHandlers', N'HANDLER_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewEventHandlers', N'HANDLER_TYPE', 'en', NULL, N'Database object type, CODE for SQL-code, HTTP for http-query, or NULL for MenuSeparator');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewEventHandlers', N'ID', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewEventHandlers', N'IS_ACTIVE', 'en', NULL, N'True if the handler is active.');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewEventHandlers', N'MENU_ORDER', 'en', NULL, N'Sort order of Actions and Context Menu items');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewEventHandlers', N'TABLE_NAME', 'en', NULL, N'Database object name, SQL-code name, or http-query name');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewEventHandlers', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewEventHandlers', N'TARGET_WORKSHEET', 'en', NULL, N'NULL, sheet name, _new, _self, _reload. Additions: _RightWindow, _LeftWindow, _TopWindow, _BottomWindow');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewObjectDescription', N'LANGUAGE_NAME', 'en', N'Language', N'Two-char language code');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewObjectDescription', N'TABLE_NAME', 'en', N'Object Name', N'Database object name');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewObjectDescription', N'TABLE_SCHEMA', 'en', N'Schema', N'Database object schema');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewObjectDescription', N'TRANSLATED_COMMENT', 'en', N'Comment', N'Text for SuperTips and SaveToDB_Comment named cells');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewObjectDescription', N'TRANSLATED_NAME', 'en', N'Name', N'Translated name for Query List, Actions and Context Menus');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewObjectTranslation', N'ID', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewObjectTranslation', N'LANGUAGE_NAME', 'en', NULL, N'Two-char language code');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewObjectTranslation', N'TABLE_NAME', 'en', NULL, N'Database object name or a name of SQL-code or http-query specified in Query List and Event Handlers');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewObjectTranslation', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewObjectTranslation', N'TRANSLATED_COMMENT', 'en', NULL, N'Text for SuperTips and SaveToDB_Comment named cells');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewObjectTranslation', N'TRANSLATED_DESC', 'en', NULL, N'Text for ScreenTips and SaveToDB_Desc named cells');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewObjectTranslation', N'TRANSLATED_NAME', 'en', NULL, N'Translated name for Query List, Actions and Context Menus');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewParameterValues', N'ID', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewParameterValues', N'PARAMETER_NAME', 'en', NULL, N'Column or parameter name');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewParameterValues', N'SELECT_NAME', 'en', NULL, N'Database object name or name for SQL-code');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewParameterValues', N'SELECT_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewParameterValues', N'SELECT_TYPE', 'en', NULL, N'Database object type or CODE for SQL-code');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewParameterValues', N'TABLE_NAME', 'en', NULL, N'Database object name');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewParameterValues', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewQueryList', N'DELETE_PROCEDURE', 'en', NULL, N'Delete procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewQueryList', N'ID', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewQueryList', N'INSERT_PROCEDURE', 'en', NULL, N'Insert procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewQueryList', N'TABLE_NAME', 'en', NULL, N'Database object name or unique name for SQL-code and http-query');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewQueryList', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewQueryList', N'TABLE_TYPE', 'en', NULL, N'Database object type, CODE for SQL-code, or HTTP for http-query');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewQueryList', N'UPDATE_PROCEDURE', 'en', NULL, N'Update procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewTableFormats', N'ID', 'en', NULL, NULL);
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewTableFormats', N'TABLE_EXCEL_FORMAT_XML', 'en', NULL, N'Excel table format XML');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewTableFormats', N'TABLE_NAME', 'en', NULL, N'Database object name');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (N'xls01', N'viewTableFormats', N'TABLE_SCHEMA', 'en', NULL, N'Database object schema');

INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo01', N'ColumnTranslation', '<table name="dbo01.ColumnTranslation"><columnFormats><column name="" property="ListObjectName" value="ColumnTranslation_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="21.71" type="Double"/><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="COLUMN_NAME" property="Address" value="$F$7" type="String"/><column name="COLUMN_NAME" property="ColumnWidth" value="25.57" type="Double"/><column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double"/><column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double"/><column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String"/><column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="LANGUAGE_NAME" property="Address" value="$G$7" type="String"/><column name="LANGUAGE_NAME" property="ColumnWidth" value="19.57" type="Double"/><column name="LANGUAGE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="LANGUAGE_NAME" property="Validation.Type" value="6" type="Double"/><column name="LANGUAGE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="LANGUAGE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="LANGUAGE_NAME" property="Validation.Formula1" value="2" type="String"/><column name="LANGUAGE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="LANGUAGE_NAME" property="Validation.ErrorMessage" value="The column requires values of the char(2) datatype." type="String"/><column name="LANGUAGE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TRANSLATED_NAME" property="Address" value="$H$7" type="String"/><column name="TRANSLATED_NAME" property="ColumnWidth" value="20.71" type="Double"/><column name="TRANSLATED_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TRANSLATED_NAME" property="Validation.Type" value="6" type="Double"/><column name="TRANSLATED_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TRANSLATED_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TRANSLATED_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TRANSLATED_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TRANSLATED_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TRANSLATED_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TRANSLATED_DESC" property="Address" value="$I$7" type="String"/><column name="TRANSLATED_DESC" property="ColumnWidth" value="70.71" type="Double"/><column name="TRANSLATED_DESC" property="VerticalAlignment" value="-4160" type="Double"/><column name="TRANSLATED_DESC" property="Validation.Type" value="6" type="Double"/><column name="TRANSLATED_DESC" property="Validation.AlertStyle" value="1" type="Double"/><column name="TRANSLATED_DESC" property="Validation.Operator" value="8" type="Double"/><column name="TRANSLATED_DESC" property="Validation.Formula1" value="1024" type="String"/><column name="TRANSLATED_DESC" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TRANSLATED_DESC" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(1024) datatype." type="String"/><column name="TRANSLATED_DESC" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$212,$F$7:$G$212" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SortFields(1)" property="KeyfieldName" value="LANGUAGE_NAME" type="String"/><column name="SortFields(1)" property="SortOn" value="0" type="Double"/><column name="SortFields(1)" property="Order" value="1" type="Double"/><column name="SortFields(1)" property="DataOption" value="0" type="Double"/><column name="SortFields(2)" property="KeyfieldName" value="TABLE_SCHEMA" type="String"/><column name="SortFields(2)" property="SortOn" value="0" type="Double"/><column name="SortFields(2)" property="Order" value="1" type="Double"/><column name="SortFields(2)" property="DataOption" value="0" type="Double"/><column name="SortFields(3)" property="KeyfieldName" value="TABLE_NAME" type="String"/><column name="SortFields(3)" property="SortOn" value="0" type="Double"/><column name="SortFields(3)" property="Order" value="1" type="Double"/><column name="SortFields(3)" property="DataOption" value="0" type="Double"/><column name="SortFields(4)" property="KeyfieldName" value="COLUMN_NAME" type="String"/><column name="SortFields(4)" property="SortOn" value="0" type="Double"/><column name="SortFields(4)" property="Order" value="1" type="Double"/><column name="SortFields(4)" property="DataOption" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo01', N'EventHandlers', '<table name="dbo01.EventHandlers"><columnFormats><column name="" property="ListObjectName" value="EventHandlers_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="21.71" type="Double"/><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="COLUMN_NAME" property="Address" value="$F$7" type="String"/><column name="COLUMN_NAME" property="ColumnWidth" value="18.57" type="Double"/><column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double"/><column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double"/><column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String"/><column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="EVENT_NAME" property="Address" value="$G$7" type="String"/><column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double"/><column name="EVENT_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="EVENT_NAME" property="Validation.Type" value="3" type="Double"/><column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="EVENT_NAME" property="Validation.Operator" value="8" type="Double"/><column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange" type="String"/><column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="EVENT_NAME" property="Validation.ErrorMessage" value="The column requires values of the varchar(50) datatype." type="String"/><column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_SCHEMA" property="Address" value="$H$7" type="String"/><column name="HANDLER_SCHEMA" property="ColumnWidth" value="19.71" type="Double"/><column name="HANDLER_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="HANDLER_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_NAME" property="Address" value="$I$7" type="String"/><column name="HANDLER_NAME" property="ColumnWidth" value="57.57" type="Double"/><column name="HANDLER_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double"/><column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_NAME" property="Validation.Formula1" value="128" type="String"/><column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_TYPE" property="Address" value="$J$7" type="String"/><column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double"/><column name="HANDLER_TYPE" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double"/><column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_TYPE" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;REFRESH;MENUSEPARATOR" type="String"/><column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_CODE" property="Address" value="$K$7" type="String"/><column name="HANDLER_CODE" property="ColumnWidth" value="45" type="Double"/><column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TARGET_WORKSHEET" property="Address" value="$L$7" type="String"/><column name="TARGET_WORKSHEET" property="ColumnWidth" value="21.71" type="Double"/><column name="TARGET_WORKSHEET" property="VerticalAlignment" value="-4160" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Formula1" value="128" type="String"/><column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TARGET_WORKSHEET" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean"/><column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="MENU_ORDER" property="Address" value="$M$7" type="String"/><column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double"/><column name="MENU_ORDER" property="VerticalAlignment" value="-4160" type="Double"/><column name="MENU_ORDER" property="Validation.Type" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.Operator" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.Formula1" value="-2147483648" type="String"/><column name="MENU_ORDER" property="Validation.Formula2" value="2147483647" type="String"/><column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="MENU_ORDER" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean"/><column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="EDIT_PARAMETERS" property="Address" value="$N$7" type="String"/><column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double"/><column name="EDIT_PARAMETERS" property="VerticalAlignment" value="-4160" type="Double"/><column name="IS_ACTIVE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="IS_ACTIVE" property="Address" value="$O$7" type="String"/><column name="IS_ACTIVE" property="ColumnWidth" value="11.43" type="Double"/><column name="IS_ACTIVE" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$446" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).AppliesTo.Address" value="$D$7:$D$446" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Priority" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$446,$G$7:$G$446,$I$7:$I$446" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Priority" value="3" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SortFields(1)" property="KeyfieldName" value="TABLE_SCHEMA" type="String"/><column name="SortFields(1)" property="SortOn" value="0" type="Double"/><column name="SortFields(1)" property="Order" value="1" type="Double"/><column name="SortFields(1)" property="DataOption" value="0" type="Double"/><column name="SortFields(2)" property="KeyfieldName" value="TABLE_NAME" type="String"/><column name="SortFields(2)" property="SortOn" value="0" type="Double"/><column name="SortFields(2)" property="Order" value="1" type="Double"/><column name="SortFields(2)" property="DataOption" value="0" type="Double"/><column name="SortFields(3)" property="KeyfieldName" value="EVENT_NAME" type="String"/><column name="SortFields(3)" property="SortOn" value="0" type="Double"/><column name="SortFields(3)" property="Order" value="1" type="Double"/><column name="SortFields(3)" property="DataOption" value="0" type="Double"/><column name="SortFields(4)" property="KeyfieldName" value="MENU_ORDER" type="String"/><column name="SortFields(4)" property="SortOn" value="0" type="Double"/><column name="SortFields(4)" property="Order" value="1" type="Double"/><column name="SortFields(4)" property="DataOption" value="0" type="Double"/><column name="SortFields(5)" property="KeyfieldName" value="HANDLER_NAME" type="String"/><column name="SortFields(5)" property="SortOn" value="0" type="Double"/><column name="SortFields(5)" property="Order" value="1" type="Double"/><column name="SortFields(5)" property="DataOption" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo01', N'ObjectTranslation', '<table name="dbo01.ObjectTranslation"><columnFormats><column name="" property="ListObjectName" value="ObjectTranslation_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="33.86" type="Double"/><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="LANGUAGE_NAME" property="Address" value="$F$7" type="String"/><column name="LANGUAGE_NAME" property="ColumnWidth" value="19.57" type="Double"/><column name="LANGUAGE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="LANGUAGE_NAME" property="Validation.Type" value="6" type="Double"/><column name="LANGUAGE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="LANGUAGE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="LANGUAGE_NAME" property="Validation.Formula1" value="2" type="String"/><column name="LANGUAGE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="LANGUAGE_NAME" property="Validation.ErrorMessage" value="The column requires values of the char(2) datatype." type="String"/><column name="LANGUAGE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="LANGUAGE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TRANSLATED_NAME" property="Address" value="$G$7" type="String"/><column name="TRANSLATED_NAME" property="ColumnWidth" value="38" type="Double"/><column name="TRANSLATED_NAME" property="Validation.Type" value="6" type="Double"/><column name="TRANSLATED_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TRANSLATED_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TRANSLATED_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TRANSLATED_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TRANSLATED_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TRANSLATED_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TRANSLATED_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TRANSLATED_DESC" property="Address" value="$H$7" type="String"/><column name="TRANSLATED_DESC" property="ColumnWidth" value="70.71" type="Double"/><column name="TRANSLATED_DESC" property="Validation.Type" value="6" type="Double"/><column name="TRANSLATED_DESC" property="Validation.AlertStyle" value="1" type="Double"/><column name="TRANSLATED_DESC" property="Validation.Operator" value="8" type="Double"/><column name="TRANSLATED_DESC" property="Validation.Formula1" value="255" type="String"/><column name="TRANSLATED_DESC" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TRANSLATED_DESC" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String"/><column name="TRANSLATED_DESC" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TRANSLATED_DESC" property="Validation.ShowError" value="True" type="Boolean"/><column name="TRANSLATED_COMMENT" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TRANSLATED_COMMENT" property="Address" value="$I$7" type="String"/><column name="TRANSLATED_COMMENT" property="ColumnWidth" value="70.71" type="Double"/><column name="TRANSLATED_COMMENT" property="Validation.Type" value="6" type="Double"/><column name="TRANSLATED_COMMENT" property="Validation.AlertStyle" value="1" type="Double"/><column name="TRANSLATED_COMMENT" property="Validation.Operator" value="8" type="Double"/><column name="TRANSLATED_COMMENT" property="Validation.Formula1" value="4000" type="String"/><column name="TRANSLATED_COMMENT" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TRANSLATED_COMMENT" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TRANSLATED_COMMENT" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TRANSLATED_COMMENT" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(4000) datatype." type="String"/><column name="TRANSLATED_COMMENT" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TRANSLATED_COMMENT" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="FormatConditions(1).ColumnsCount" value="3" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$F$167" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SortFields(1)" property="KeyfieldName" value="LANGUAGE_NAME" type="String"/><column name="SortFields(1)" property="SortOn" value="0" type="Double"/><column name="SortFields(1)" property="Order" value="1" type="Double"/><column name="SortFields(1)" property="DataOption" value="0" type="Double"/><column name="SortFields(2)" property="KeyfieldName" value="TABLE_SCHEMA" type="String"/><column name="SortFields(2)" property="SortOn" value="0" type="Double"/><column name="SortFields(2)" property="Order" value="1" type="Double"/><column name="SortFields(2)" property="DataOption" value="0" type="Double"/><column name="SortFields(3)" property="KeyfieldName" value="TABLE_NAME" type="String"/><column name="SortFields(3)" property="SortOn" value="0" type="Double"/><column name="SortFields(3)" property="Order" value="1" type="Double"/><column name="SortFields(3)" property="DataOption" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo01', N'ParameterValues', '<table name="dbo01.ParameterValues"><columnFormats><column name="" property="ListObjectName" value="ParameterValues_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="26.29" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="PARAMETER_NAME" property="Address" value="$F$7" type="String"/><column name="PARAMETER_NAME" property="ColumnWidth" value="20.29" type="Double"/><column name="PARAMETER_NAME" property="Validation.Type" value="6" type="Double"/><column name="PARAMETER_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="PARAMETER_NAME" property="Validation.Operator" value="8" type="Double"/><column name="PARAMETER_NAME" property="Validation.Formula1" value="128" type="String"/><column name="PARAMETER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="PARAMETER_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="PARAMETER_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_SCHEMA" property="Address" value="$G$7" type="String"/><column name="SELECT_SCHEMA" property="ColumnWidth" value="17.29" type="Double"/><column name="SELECT_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="SELECT_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="SELECT_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="SELECT_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="SELECT_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="SELECT_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="SELECT_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_NAME" property="Address" value="$H$7" type="String"/><column name="SELECT_NAME" property="ColumnWidth" value="34.86" type="Double"/><column name="SELECT_NAME" property="Validation.Type" value="6" type="Double"/><column name="SELECT_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="SELECT_NAME" property="Validation.Operator" value="8" type="Double"/><column name="SELECT_NAME" property="Validation.Formula1" value="128" type="String"/><column name="SELECT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="SELECT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="SELECT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="SELECT_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="SELECT_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="SELECT_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_TYPE" property="Address" value="$I$7" type="String"/><column name="SELECT_TYPE" property="ColumnWidth" value="13.86" type="Double"/><column name="SELECT_TYPE" property="Validation.Type" value="3" type="Double"/><column name="SELECT_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="SELECT_TYPE" property="Validation.Operator" value="8" type="Double"/><column name="SELECT_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP" type="String"/><column name="SELECT_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="SELECT_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="SELECT_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="SELECT_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="SELECT_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="SELECT_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_CODE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_CODE" property="Address" value="$J$7" type="String"/><column name="SELECT_CODE" property="ColumnWidth" value="70.71" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$63" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).AppliesTo.Address" value="$D$7:$D$63" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Priority" value="7" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$G$7:$G$63,$I$7:$I$63" type="String"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Priority" value="4" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(G7)" type="String"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo01', N'QueryList', '<table name="dbo01.QueryList"><columnFormats><column name="" property="ListObjectName" value="QueryList_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="28.29" type="Double"/><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_TYPE" property="Address" value="$F$7" type="String"/><column name="TABLE_TYPE" property="ColumnWidth" value="13.14" type="Double"/><column name="TABLE_TYPE" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_TYPE" property="Validation.Type" value="3" type="Double"/><column name="TABLE_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_TYPE" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;CODE;HTTP;TEXT" type="String"/><column name="TABLE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_CODE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_CODE" property="Address" value="$G$7" type="String"/><column name="TABLE_CODE" property="ColumnWidth" value="21.57" type="Double"/><column name="INSERT_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="INSERT_PROCEDURE" property="Address" value="$H$7" type="String"/><column name="INSERT_PROCEDURE" property="ColumnWidth" value="23.43" type="Double"/><column name="INSERT_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double"/><column name="INSERT_PROCEDURE" property="Validation.Type" value="6" type="Double"/><column name="INSERT_PROCEDURE" property="Validation.AlertStyle" value="1" type="Double"/><column name="INSERT_PROCEDURE" property="Validation.Operator" value="8" type="Double"/><column name="INSERT_PROCEDURE" property="Validation.Formula1" value="2000" type="String"/><column name="INSERT_PROCEDURE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="INSERT_PROCEDURE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="INSERT_PROCEDURE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="INSERT_PROCEDURE" property="Validation.ShowError" value="True" type="Boolean"/><column name="UPDATE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="UPDATE_PROCEDURE" property="Address" value="$I$7" type="String"/><column name="UPDATE_PROCEDURE" property="ColumnWidth" value="23.43" type="Double"/><column name="UPDATE_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double"/><column name="UPDATE_PROCEDURE" property="Validation.Type" value="6" type="Double"/><column name="UPDATE_PROCEDURE" property="Validation.AlertStyle" value="1" type="Double"/><column name="UPDATE_PROCEDURE" property="Validation.Operator" value="8" type="Double"/><column name="UPDATE_PROCEDURE" property="Validation.Formula1" value="2000" type="String"/><column name="UPDATE_PROCEDURE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="UPDATE_PROCEDURE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="UPDATE_PROCEDURE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="UPDATE_PROCEDURE" property="Validation.ShowError" value="True" type="Boolean"/><column name="DELETE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="DELETE_PROCEDURE" property="Address" value="$J$7" type="String"/><column name="DELETE_PROCEDURE" property="ColumnWidth" value="23.43" type="Double"/><column name="DELETE_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double"/><column name="DELETE_PROCEDURE" property="Validation.Type" value="6" type="Double"/><column name="DELETE_PROCEDURE" property="Validation.AlertStyle" value="1" type="Double"/><column name="DELETE_PROCEDURE" property="Validation.Operator" value="8" type="Double"/><column name="DELETE_PROCEDURE" property="Validation.Formula1" value="2000" type="String"/><column name="DELETE_PROCEDURE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="DELETE_PROCEDURE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="DELETE_PROCEDURE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="DELETE_PROCEDURE" property="Validation.ShowError" value="True" type="Boolean"/><column name="PROCEDURE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="PROCEDURE_TYPE" property="Address" value="$K$7" type="String"/><column name="PROCEDURE_TYPE" property="ColumnWidth" value="18.86" type="Double"/><column name="PROCEDURE_TYPE" property="Validation.Type" value="3" type="Double"/><column name="PROCEDURE_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="PROCEDURE_TYPE" property="Validation.Operator" value="8" type="Double"/><column name="PROCEDURE_TYPE" property="Validation.Formula1" value="TABLE;PROCEDURE;CODE;MERGE" type="String"/><column name="PROCEDURE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="PROCEDURE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="PROCEDURE_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="PROCEDURE_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$37" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).NumberFormat" value="General" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$37" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_NAME" property="FormatConditions(2).AppliesTo.Address" value="$E$7:$E$37" type="String"/><column name="TABLE_NAME" property="FormatConditions(2).Type" value="2" type="Double"/><column name="TABLE_NAME" property="FormatConditions(2).Priority" value="3" type="Double"/><column name="TABLE_NAME" property="FormatConditions(2).Formula1" value="=ISBLANK(E7)" type="String"/><column name="TABLE_NAME" property="FormatConditions(2).NumberFormat" value="General" type="String"/><column name="TABLE_NAME" property="FormatConditions(2).Interior.Color" value="65535" type="Double"/><column name="TABLE_NAME" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo01', N'TableFormats', '<table name="dbo01.TableFormats"><columnFormats><column name="" property="ListObjectName" value="DevObjects_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="6" type="Double"/><column name="ID" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="43.14" type="Double"/><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_EXCEL_FORMAT_XML" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_EXCEL_FORMAT_XML" property="Address" value="$F$7" type="String"/><column name="TABLE_EXCEL_FORMAT_XML" property="ColumnWidth" value="70.71" type="Double"/><column name="TABLE_EXCEL_FORMAT_XML" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$103" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).NumberFormat" value="General" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$103" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Priority" value="2" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SortFields(1)" property="KeyfieldName" value="TABLE_SCHEMA" type="String"/><column name="SortFields(1)" property="SortOn" value="0" type="Double"/><column name="SortFields(1)" property="Order" value="1" type="Double"/><column name="SortFields(1)" property="DataOption" value="2" type="Double"/><column name="SortFields(2)" property="KeyfieldName" value="TABLE_NAME" type="String"/><column name="SortFields(2)" property="SortOn" value="0" type="Double"/><column name="SortFields(2)" property="Order" value="1" type="Double"/><column name="SortFields(2)" property="DataOption" value="2" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/><column name="" property="PageSetup.PaperSize" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'xls01', N'viewObjectDescription', N'<table name="xls01.viewObjectDescription"><columnFormats><column name="" property="ListObjectName" value="UserObjects_Table1" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$7" type="String" /><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" /><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ID" property="Address" value="$C$7" type="String" /><column name="ID" property="ColumnWidth" value="0.08" type="Double" /><column name="ID" property="VerticalAlignment" value="-4160" type="Double" /><column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="LANGUAGE_NAME" property="Address" value="$D$7" type="String" /><column name="LANGUAGE_NAME" property="VerticalAlignment" value="-4160" type="Double" /><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="TABLE_SCHEMA" property="Address" value="$E$7" type="String" /><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" /><column name="TABLE_NAME" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="TABLE_NAME" property="Address" value="$F$7" type="String" /><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" /><column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="TRANSLATED_NAME" property="Address" value="$G$7" type="String" /><column name="TRANSLATED_NAME" property="ColumnWidth" value="24.29" type="Double" /><column name="TRANSLATED_NAME" property="VerticalAlignment" value="-4160" type="Double" /><column name="TRANSLATED_COMMENT" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="TRANSLATED_COMMENT" property="Address" value="$H$7" type="String" /><column name="TRANSLATED_COMMENT" property="ColumnWidth" value="114" type="Double" /><column name="TRANSLATED_COMMENT" property="VerticalAlignment" value="-4160" type="Double" /><column name="TRANSLATED_COMMENT" property="WrapText" value="True" type="Boolean" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /><column name="" property="PageSetup.PaperSize" value="1" type="Double" /></columnFormats></table>')

print N'SaveToDB Framework data have been added';
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     5.0, 2015-04-13
-- Description: SaveToDB Query List view
-- =============================================

CREATE VIEW [dbo01].[viewQueryListTools]
AS

SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_TYPE
    , t.TABLE_CODE
    , t.INSERT_PROCEDURE
    , t.UPDATE_PROCEDURE
    , t.DELETE_PROCEDURE
    , t.PROCEDURE_TYPE
FROM
    [dbo01].[viewQueryList] t
WHERE
    t.TABLE_SCHEMA IN ('tools01')

GO

INSERT [dbo01].[QueryList] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'tools01', N'DatabaseObjects', N'CODE', N'SELECT
    so.[object_id] AS ID
    , QUOTENAME(SCHEMA_NAME(so.[schema_id])) + ''.'' + QUOTENAME(so.name) AS ObjectName
    , SCHEMA_NAME(so.[schema_id]) AS [Schema]
    , so.name AS Name
    , [Type] = CASE so.type_desc
        WHEN ''USER_TABLE'' THEN ''table''
        WHEN ''VIEW'' THEN ''view''
        WHEN ''SQL_STORED_PROCEDURE'' THEN ''procedure''
        WHEN ''SQL_TRIGGER'' THEN ''trigger''
        ELSE so.type_desc
        END
    , t.TRANSLATED_NAME AS [TranslatedName]
    , t.TRANSLATED_DESC AS [TranslatedDescription]
    , t.TRANSLATED_COMMENT AS [TranslatedComment]
    , CASE
        WHEN HAS_PERMS_BY_NAME(QUOTENAME(DB_NAME())+''.''+QUOTENAME(SCHEMA_NAME(so.[schema_id]))+''.''+QUOTENAME(so.name), ''OBJECT'', ''ALTER'') = 1 THEN ''yes''
        ELSE NULL
        END AS Alterable
    , so.create_date AS CreateDate
    , so.modify_date AS ModifyDate
FROM
    sys.objects so
    LEFT OUTER JOIN dbo01.ObjectTranslation t ON t.TABLE_SCHEMA = SCHEMA_NAME(so.[schema_id]) AND t.TABLE_NAME = so.name
        AND t.LANGUAGE_NAME = @Language
WHERE
    NOT SCHEMA_NAME(so.[schema_id]) = ''sys''
    AND (type_desc = ''SQL_STORED_PROCEDURE''
        OR type_desc = ''SQL_TRIGGER''
        OR type_desc = ''USER_TABLE''
        OR type_desc = ''VIEW''
    )
    AND NOT (so.name LIKE ''sp_%'' AND SCHEMA_NAME(so.[schema_id]) = ''dbo'')
    AND so.name NOT LIKE ''sys%''
    AND SCHEMA_NAME(so.[schema_id]) NOT IN (''dbo01'', ''etl01'', ''xls01'')
', NULL, NULL, NULL, NULL)
GO
INSERT [dbo01].[QueryList] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'tools01', N'RoleMembers', N'CODE', N'DECLARE @List varchar(MAX)

SELECT @List = (
    SELECT '', ['' + name + '']'' FROM (
        SELECT DISTINCT p.name, p.is_fixed_role FROM sys.database_principals p
            WHERE name NOT IN (''db_owner'', ''public'', ''SaveToDB_Developers'', ''SaveToDB_Users'') AND p.[type] IN (''R'') AND p.is_fixed_role = 0
        ) AS t ORDER BY t.is_fixed_role, t.name
    FOR XML PATH('''')
    )

DECLARE @Query varchar(MAX)

SET @Query = ''
SELECT
    LOWER(p.[Type]) AS [Type]
    , p.[Name]
    , [SaveToDB_Developers], [SaveToDB_Users]'' + COALESCE(@List, '''') + ''
FROM
    (
    SELECT
        p.name AS [Role]
        , m.type_desc AS [Type]
        , m.name AS [Name]
        , 1 AS [include]
    FROM
        sys.database_principals m
        LEFT JOIN sys.database_role_members rm ON rm.member_principal_id = m.principal_id
        LEFT JOIN sys.database_principals p ON p.principal_id = rm.role_principal_id
    WHERE
        m.[type] IN (''''S'''', ''''U'''', ''''R'''')
        AND m.is_fixed_role = 0
        AND NOT m.name IN (''''dbo'''', ''''sys'''', ''''guest'''', ''''public'''', ''''INFORMATION_SCHEMA'''', ''''SaveToDB_Developers'''', ''''SaveToDB_Users'''')
    ) s PIVOT (
        SUM([include]) FOR [Role] IN ([SaveToDB_Developers], [SaveToDB_Users]''+ COALESCE(@List, '''') + '')
    ) p
ORDER BY
    p.[Type]
    , p.[Name]
''

EXEC(@Query)
', NULL, NULL, NULL, NULL)
GO
INSERT [dbo01].[QueryList] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [TABLE_CODE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'tools01', N'Permissions', N'CODE', N'WITH cte (object_schema, [object_name], object_type_desc,
    principal_name, principal_type_desc,
    permission_type_desc, state_desc,
    grantee_principal_id, sort_order)
AS 
    (
    SELECT
        [object_schema] = CASE p.class
            WHEN 4 THEN NULL
            WHEN 3 THEN SCHEMA_NAME(p.major_id)
            WHEN 1 THEN OBJECT_SCHEMA_NAME(p.major_id)
            WHEN 0 THEN NULL
            ELSE NULL
            END
        , [object_name] = CASE p.class
            WHEN 4 THEN USER_NAME(p.major_id)
            WHEN 3 THEN NULL
            WHEN 1 THEN OBJECT_NAME(p.major_id)
            WHEN 0 THEN DB_NAME()
            ELSE NULL
            END
        , [object_type_desc] = CASE
            WHEN p.class = 4 THEN dp.type_desc
            WHEN p.class = 3 THEN p.class_desc
            WHEN p.class = 1 AND p.major_id < 0 THEN so.type_desc
            WHEN p.class = 1 THEN o.type_desc
            WHEN p.class = 0 THEN p.class_desc
            ELSE p.class_desc
            END
        , r.name AS principal_name
        , r.type_desc AS principal_type_desc
        , p.[permission_name] AS permission_type_desc
        , p.state_desc
        , p.grantee_principal_id
        , sort_order = CASE
            WHEN p.class = 4 THEN 2
            WHEN p.class = 3 THEN 3
            WHEN p.class = 1 AND p.major_id < 0 THEN 10
            WHEN p.class = 1 THEN CASE o.type_desc
                WHEN ''SQL_STORED_PROCEDURE'' THEN 13
                WHEN ''SQL_SCALAR_FUNCTION'' THEN 14
                WHEN ''USER_TABLE'' THEN 11
                WHEN ''VIEW'' THEN 12
                ELSE 15
                END 
            WHEN p.class = 0 THEN 1
            ELSE 20
            END
    FROM
        sys.database_permissions p
        LEFT OUTER JOIN sys.objects o ON o.[object_id] = p.major_id AND p.class = 1
        LEFT OUTER JOIN sys.system_objects so ON so.[object_id] = p.major_id AND p.class = 1
        LEFT OUTER JOIN sys.database_principals dp ON dp.principal_id = p.major_id AND p.class = 4
        INNER JOIN sys.database_principals r ON r.principal_id = p.grantee_principal_id
    WHERE
        p.class IN (0, 1, 3, 4)
        AND NOT (so.[object_id] IS NULL AND p.major_id < 0 AND p.class = 1)
        AND NOT SCHEMA_NAME(p.major_id) IN (''sys'')
    )

SELECT
    principal_type_desc AS PrincipalType
    , principal_name AS Principal
    , object_schema AS [Schema]
    , [object_name] AS Name
    , object_type_desc AS [Type]
    , CASE WHEN state_mask >= 1000 THEN ''direct'' ELSE ''indirect'' END AS GrantType
    , [SELECT], [INSERT], [UPDATE], [DELETE]
    , [EXECUTE]
    , [VIEW DEFINITION]
    , [ALTER], [CONTROL], [REFERENCES], [TAKE OWNERSHIP]
    , [IMPERSONATE]
    , [CONNECT]
FROM
    (
        SELECT
            p.object_schema
            , p.[object_name]
            , object_type_desc = CASE MAX(p.object_type_desc)
                WHEN ''SQL_STORED_PROCEDURE'' THEN ''procedure''
                WHEN ''SQL_SCALAR_FUNCTION'' THEN ''function''
                WHEN ''USER_TABLE'' THEN ''table''
                WHEN ''VIEW'' THEN ''view''
                ELSE LOWER(MAX(p.object_type_desc))
                END 
            , p.principal_name
            , principal_type_desc = LOWER(MAX(p.principal_type_desc))
            , p.permission_type_desc
            , MAX(p.[state_mask]) AS state_mask
            , sort_order = CASE MAX(p.object_type_desc)
                WHEN ''SQL_STORED_PROCEDURE'' THEN 13
                WHEN ''SQL_SCALAR_FUNCTION'' THEN 14
                WHEN ''USER_TABLE'' THEN 11
                WHEN ''VIEW'' THEN 12
                ELSE MAX(p.sort_order)
                END 
            , state_desc = CASE MAX(p.[state_mask])
                WHEN 2000 THEN ''GRANT''
                WHEN 1000 THEN ''DENY''
                WHEN  200 THEN ''GRANT r''
                WHEN  100 THEN ''DENY  r''
                WHEN   20 THEN ''GRANT s''
                WHEN   10 THEN ''DENY  s''
                WHEN    2 THEN ''GRANT sr''
                WHEN    1 THEN ''DENY  sr''
                ELSE NULL
                END 
        FROM
            (
                SELECT
                    cte.object_schema
                    , cte.[object_name]
                    , cte.object_type_desc
                    , ''DIRECT'' AS [object_control]
                    , cte.principal_name
                    , cte.principal_type_desc
                    , ''DIRECT'' AS [principal_control]
                    , cte.permission_type_desc
                    , cte.state_desc
                    , cte.sort_order
                    , state_mask = CASE cte.state_desc WHEN ''DENY'' THEN 1000 ELSE 2000 END
                FROM
                    cte

                UNION ALL
                SELECT
                    cte.object_schema
                    , cte.[object_name]
                    , MAX(cte.object_type_desc) AS object_type_desc
                    , ''DIRECT'' AS [object_control]
                    , u.name AS principal_name
                    , MAX(u.type_desc) AS principal_type_desc
                    , ''BY ROLE'' AS [principal_control]
                    , cte.permission_type_desc
                    , cte.state_desc
                    , MAX(cte.sort_order) AS sort_order
                    , state_mask = CASE cte.state_desc WHEN ''DENY'' THEN 100 ELSE 200 END
                FROM
                    cte
                    INNER JOIN sys.database_role_members rm ON rm.role_principal_id = cte.grantee_principal_id
                    LEFT OUTER JOIN sys.database_principals u ON u.principal_id = rm.member_principal_id
                GROUP BY
                    object_schema
                    , [object_name]
                    , u.name
                    , permission_type_desc
                    , state_desc

                UNION ALL
                SELECT
                    cte.object_schema
                    , o.name AS [object_name]
                    , o.type_desc AS object_type_desc
                    , ''BY SCHEMA'' AS [object_control]
                    , cte.principal_name
                    , cte.principal_type_desc
                    , ''DIRECT'' AS [principal_control]
                    , cte.permission_type_desc
                    , cte.state_desc
                    , cte.sort_order
                    , state_mask = CASE cte.state_desc WHEN ''DENY'' THEN 10 ELSE 20 END
                FROM
                    cte
                    INNER JOIN sys.objects o ON OBJECT_SCHEMA_NAME(o.[object_id]) = cte.object_schema
                WHERE
                    o.[type] IN (''U'', ''V'', ''P'')
                    AND cte.[object_name] IS NULL
                    AND ((o.[type] IN (''U'', ''V'') AND cte.permission_type_desc NOT IN (''EXECUTE''))
                        OR (o.[type] = ''P'' AND cte.permission_type_desc NOT IN (''SELECT'', ''INSERT'', ''UPDATE'', ''DELETE'')))
        
                UNION ALL
                SELECT
                    cte.object_schema
                    , o.name AS [object_name]
                    , MAX(o.type_desc) AS object_type_desc
                    , ''BY SCHEMA'' AS [object_control]
                    , u.name AS principal_name
                    , MAX(u.type_desc) AS principal_type_desc
                    , ''BY ROLE'' AS [principal_control]
                    , cte.permission_type_desc
                    , cte.state_desc
                    , MAX(cte.sort_order) AS sort_order
                    , state_mask = CASE cte.state_desc WHEN ''DENY'' THEN 1 ELSE 2 END
                FROM
                    cte
                    INNER JOIN sys.objects o ON OBJECT_SCHEMA_NAME(o.[object_id]) = cte.object_schema
                    INNER JOIN sys.database_role_members rm ON rm.role_principal_id = cte.grantee_principal_id
                    LEFT OUTER JOIN sys.database_principals u ON u.principal_id = rm.member_principal_id
                WHERE
                    o.[type] IN (''U'', ''V'', ''P'')
                    AND cte.[object_name] IS NULL
                    AND ((o.[type] IN (''U'', ''V'') AND cte.permission_type_desc NOT IN (''EXECUTE''))
                        OR (o.[type] = ''P'' AND cte.permission_type_desc NOT IN (''SELECT'', ''INSERT'', ''UPDATE'', ''DELETE'')))
                GROUP BY
                    object_schema
                    , o.name
                    , u.name
                    , permission_type_desc
                    , state_desc
        ) p
        GROUP BY
            p.object_schema
            , p.[object_name]
            , p.principal_name
            , p.permission_type_desc
    ) s PIVOT (
        MAX(state_desc)
        FOR permission_type_desc IN (
            [SELECT], [INSERT], [UPDATE], [DELETE]
            , [EXECUTE]
            , [VIEW DEFINITION]
            , [ALTER], [CONTROL], [REFERENCES], [TAKE OWNERSHIP]
            , [IMPERSONATE]
            , [CONNECT]
            )
    ) p
WHERE
    COALESCE(p.object_schema, '''') = COALESCE(@Schema, p.object_schema, '''')
    AND COALESCE(p.object_type_desc, '''') = COALESCE(@Type, p.object_type_desc, '''')
    AND COALESCE(p.principal_name, '''') = COALESCE(@Principal, p.principal_name, '''')
    AND CASE WHEN state_mask >= 1000 THEN ''direct'' ELSE ''indirect'' END = COALESCE(@GrantType, CASE WHEN state_mask >= 1000 THEN ''direct'' ELSE ''indirect'' END, '''')
ORDER BY
    p.principal_type_desc
    , p.principal_name
    , p.object_schema
    , p.sort_order
    , p.object_type_desc
    , p.[object_name]
', NULL, NULL, NULL, NULL)
GO

INSERT [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'tools01', N'DatabaseObjects', N'Name', N'Change', N'tools01', N'DatabaseObjects_Name_Change', N'CODE', N'IF @ColumnName = ''Name''
    BEGIN
    EXEC sp_rename @ObjectName, @Name
    
    UPDATE dbo01.ObjectTranslation
    SET
        TABLE_NAME = @Name
    WHERE
        QUOTENAME(TABLE_SCHEMA) + ''.'' + QUOTENAME(TABLE_NAME) = @ObjectName

    UPDATE dbo01.ColumnTranslation
    SET
        TABLE_NAME = @Name
    WHERE
        QUOTENAME(TABLE_SCHEMA) + ''.'' + QUOTENAME(TABLE_NAME) = @ObjectName

    UPDATE dbo01.EventHandlers
    SET
        TABLE_NAME = @Name
    WHERE
        QUOTENAME(TABLE_SCHEMA) + ''.'' + QUOTENAME(TABLE_NAME) = @ObjectName

    UPDATE dbo01.ParameterValues
    SET
        TABLE_NAME = @Name
    WHERE
        QUOTENAME(TABLE_SCHEMA) + ''.'' + QUOTENAME(TABLE_NAME) = @ObjectName

    UPDATE dbo01.TableFormats
    SET
        TABLE_NAME = @Name
    WHERE
        QUOTENAME(TABLE_SCHEMA) + ''.'' + QUOTENAME(TABLE_NAME) = @ObjectName
    END
', N'_Reload', NULL, NULL, 1)
GO
INSERT [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'tools01', N'DatabaseObjects', N'TranslatedName', N'Change', N'tools01', N'DatabaseObjects_TranslatedName_Change', N'CODE', N'IF @ColumnName = ''TranslatedName''

    UPDATE dbo01.ObjectTranslation
    SET
        TRANSLATED_NAME = @TranslatedName
    WHERE
        TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name AND LANGUAGE_NAME = @Language

ELSE IF @ColumnName = ''TranslatedDescription''

    UPDATE dbo01.ObjectTranslation
    SET
        TRANSLATED_DESC = @TranslatedDescription
    WHERE
        TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name AND LANGUAGE_NAME = @Language

ELSE IF @ColumnName = ''TranslatedComment''

    UPDATE dbo01.ObjectTranslation
    SET
        TRANSLATED_COMMENT = @TranslatedComment
    WHERE
        TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name AND LANGUAGE_NAME = @Language

IF @@ROWCOUNT = 0 AND @CellValue IS NOT NULL

    INSERT INTO dbo01.ObjectTranslation
        (TABLE_SCHEMA, TABLE_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT)
    VALUES
        (@Schema, @Name, @Language, @TranslatedName, @TranslatedDescription, @TranslatedComment)

', NULL, NULL, NULL, 1)
GO
INSERT [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'tools01', N'DatabaseObjects', N'TranslatedDesc', N'Change', N'tools01', N'DatabaseObjects_TranslatedDesc_Change', N'CODE', N'IF @ColumnName = ''TranslatedName''

    UPDATE dbo01.ObjectTranslation
    SET
        TRANSLATED_NAME = @TranslatedName
    WHERE
        TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name AND LANGUAGE_NAME = @Language

ELSE IF @ColumnName = ''TranslatedDescription''

    UPDATE dbo01.ObjectTranslation
    SET
        TRANSLATED_DESC = @TranslatedDescription
    WHERE
        TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name AND LANGUAGE_NAME = @Language

ELSE IF @ColumnName = ''TranslatedComment''

    UPDATE dbo01.ObjectTranslation
    SET
        TRANSLATED_COMMENT = @TranslatedComment
    WHERE
        TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name AND LANGUAGE_NAME = @Language

IF @@ROWCOUNT = 0 AND @CellValue IS NOT NULL

    INSERT INTO dbo01.ObjectTranslation
        (TABLE_SCHEMA, TABLE_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT)
    VALUES
        (@Schema, @Name, @Language, @TranslatedName, @TranslatedDescription, @TranslatedComment)

', NULL, NULL, NULL, 1)
GO
INSERT [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'tools01', N'DatabaseObjects', N'TranslatedComment', N'Change', N'tools01', N'DatabaseObjects_TranslatedComment_Change', N'CODE', N'IF @ColumnName = ''TranslatedName''

    UPDATE dbo01.ObjectTranslation
    SET
        TRANSLATED_NAME = @TranslatedName
    WHERE
        TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name AND LANGUAGE_NAME = @Language

ELSE IF @ColumnName = ''TranslatedDescription''

    UPDATE dbo01.ObjectTranslation
    SET
        TRANSLATED_DESC = @TranslatedDescription
    WHERE
        TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name AND LANGUAGE_NAME = @Language

ELSE IF @ColumnName = ''TranslatedComment''

    UPDATE dbo01.ObjectTranslation
    SET
        TRANSLATED_COMMENT = @TranslatedComment
    WHERE
        TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name AND LANGUAGE_NAME = @Language

IF @@ROWCOUNT = 0 AND @CellValue IS NOT NULL

    INSERT INTO dbo01.ObjectTranslation
        (TABLE_SCHEMA, TABLE_NAME, LANGUAGE_NAME, TRANSLATED_NAME, TRANSLATED_DESC, TRANSLATED_COMMENT)
    VALUES
        (@Schema, @Name, @Language, @TranslatedName, @TranslatedDescription, @TranslatedComment)

', NULL, NULL, NULL, 1)
GO
INSERT [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'tools01', N'DatabaseObjects', N'Schema', N'Change', N'tools01', N'DatabaseObjects_Schema_Change', N'CODE', N'IF @ColumnName = ''Schema''
    BEGIN
    EXECUTE (''ALTER SCHEMA ['' + @Schema + ''] TRANSFER '' + @ObjectName)

    UPDATE dbo01.ObjectTranslation
    SET
        TABLE_SCHEMA = @Schema
    WHERE
        QUOTENAME(TABLE_SCHEMA) + ''.'' + QUOTENAME(TABLE_NAME) = @ObjectName

    UPDATE dbo01.ColumnTranslation
    SET
        TABLE_SCHEMA = @Schema
    WHERE
        QUOTENAME(TABLE_SCHEMA) + ''.'' + QUOTENAME(TABLE_NAME) = @ObjectName

    UPDATE dbo01.EventHandlers
    SET
        TABLE_SCHEMA = @Schema
    WHERE
        QUOTENAME(TABLE_SCHEMA) + ''.'' + QUOTENAME(TABLE_NAME) = @ObjectName

    UPDATE dbo01.ParameterValues
    SET
        TABLE_SCHEMA = @Schema
    WHERE
        QUOTENAME(TABLE_SCHEMA) + ''.'' + QUOTENAME(TABLE_NAME) = @ObjectName

    UPDATE dbo01.TableFormats
    SET
        TABLE_SCHEMA = @Schema
    WHERE
        QUOTENAME(TABLE_SCHEMA) + ''.'' + QUOTENAME(TABLE_NAME) = @ObjectName
    END
', N'_Reload', NULL, NULL, 1)
GO
INSERT [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'tools01', N'RoleMembers', NULL, N'Change', N'tools01', N'RoleMembers_Change', N'CODE', N'IF DATABASE_PRINCIPAL_ID(@ColumnName) IS NULL
    BEGIN
    RAISERROR(N''The role %s is not exists'', 10, 1, @ColumnName)
    RETURN
    END

IF DATABASE_PRINCIPAL_ID(@Name) IS NULL
    BEGIN
    RAISERROR(N''The user %s is not exists'', 10, 2, @User)
    RETURN
    END

IF @CellValue IS NULL
    EXEC sp_droprolemember @ColumnName, @Name
ELSE
    EXEC sp_addrolemember @ColumnName, @Name
', NULL, NULL, NULL, 1)
GO
INSERT [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS], [IS_ACTIVE]) VALUES (N'tools01', N'Permissions', NULL, N'Change', 'tools01', N'Permissions_Change', N'CODE', N'SET NOCOUNT ON

DECLARE @Permission varchar(128)
DECLARE @State varchar(128)

SET @Permission = UPPER(@ColumnName)
SET @State = UPPER(@CellValue)

IF CHARINDEX(''-'' + @Permission + ''-'',
    ''-SELECT-INSERT-UPDATE-DELETE-EXECUTE-VIEW DEFINITION-ALTER-CONTROL-IMPERSONATE-REFERENCES-TAKE OWNERSHIP-CONNECT-'') = 0
    RETURN

IF @State IS NULL
    SET @State = ''REVOKE''
ELSE IF @State = ''GRANT'' OR @State = ''G''
    SET @State = ''GRANT''
ELSE IF @State = ''DENY'' OR @State = ''D''
    SET @State = ''DENY''
ELSE IF @State = ''REVOKE'' OR @State = ''R''
    SET @State = ''REVOKE''
ELSE
    RETURN
        
DECLARE @Query varchar(max)

IF @Schema IS NULL
    BEGIN
    IF UPPER(@object_type_desc) = ''DATABASE''
        SET @Query = @State + '' '' + @Permission + '' TO '' + @Principal
    ELSE IF UPPER(@object_type_desc) = ''SQL_USER'' OR UPPER(@object_type_desc) = ''WINDOWS_USER''
        SET @Query = @State + '' '' + @Permission + '' ON USER::'' + QUOTENAME(@Name) + '' TO '' + @Principal
    ELSE IF UPPER(@object_type_desc) = ''DATABASE_ROLE'' OR UPPER(@object_type_desc) = ''APPLICATION_ROLE''
        SET @Query = @State + '' '' + @Permission + '' ON ROLE::'' + QUOTENAME(@Name) + '' TO '' + @Principal
    ELSE
        RETURN
    END
ELSE IF @Name IS NULL
    SET @Query = @State + '' '' + @Permission + '' ON SCHEMA::'' + QUOTENAME(@Schema) + '' TO '' + @Principal
ELSE
    SET @Query = @State + '' '' + @Permission + '' ON OBJECT::'' + 
        QUOTENAME(@Schema) + ''.'' + QUOTENAME(@Name) + '' TO '' + @Principal

EXEC (@Query)
', N'_Reload', NULL, NULL, 1)
GO

INSERT INTO [dbo01].[ParameterValues] ([TABLE_SCHEMA], [TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE], [SELECT_CODE]) VALUES (N'tools01', N'Permissions', N'Schema', N'tools01', N'Permissions_Schema', N'CODE', N'SELECT NULL AS [Schema] UNION ALL SELECT DISTINCT SCHEMA_NAME(p.major_id) FROM sys.database_permissions p WHERE p.class = 3')
INSERT INTO [dbo01].[ParameterValues] ([TABLE_SCHEMA], [TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE], [SELECT_CODE]) VALUES (N'tools01', N'Permissions', N'Principal', N'tools01', N'Permissions_Principal', N'CODE', N'SELECT NULL AS [Schema] UNION ALL SELECT name FROM sys.database_principals r WHERE r.is_fixed_role = 0 AND NOT r.name IN (''dbo'', ''sys'', ''public'', ''guest'', ''INFORMATION_SCHEMA'')')
INSERT INTO [dbo01].[ParameterValues] ([TABLE_SCHEMA], [TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE], [SELECT_CODE]) VALUES (N'tools01', N'Permissions', N'Type', N'tools01', N'Permissions_Type', N'CODE', N'SELECT NULL AS [Type] UNION SELECT ''schema'' UNION SELECT ''table'' UNION SELECT ''view''  UNION SELECT ''procedure'' UNION SELECT ''function'' UNION SELECT ''database_role'' UNION SELECT ''database_role'' UNION SELECT ''sql_user'' UNION SELECT ''windows_user''')
INSERT INTO [dbo01].[ParameterValues] ([TABLE_SCHEMA], [TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE], [SELECT_CODE]) VALUES (N'tools01', N'Permissions', N'GrantType', N'tools01', N'Permissions_GrantType', N'CODE', N'SELECT NULL AS GrantType UNION ALL SELECT ''direct''')

INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'tools01', N'DatabaseObjects', N'<table name="tools01.DatabaseObjects"><columnFormats><column name="" property="ListObjectName" value="DatabaseObjects" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$3" type="String" /><column name="ID" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="ID" property="Address" value="$C$3" type="String" /><column name="ObjectName" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="ObjectName" property="Address" value="$D$3" type="String" /><column name="Schema" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Schema" property="Address" value="$E$3" type="String" /><column name="Schema" property="ColumnWidth" value="9.43" type="Double" /><column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Name" property="Address" value="$F$3" type="String" /><column name="Name" property="ColumnWidth" value="57.57" type="Double" /><column name="Type" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Type" property="Address" value="$G$3" type="String" /><column name="Type" property="ColumnWidth" value="9.43" type="Double" /><column name="TranslatedName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="TranslatedName" property="Address" value="$H$3" type="String" /><column name="TranslatedName" property="ColumnWidth" value="30" type="Double" /><column name="TranslatedDescription" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="TranslatedDescription" property="Address" value="$I$3" type="String" /><column name="TranslatedDescription" property="ColumnWidth" value="43" type="Double" /><column name="TranslatedComment" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="TranslatedComment" property="Address" value="$J$3" type="String" /><column name="TranslatedComment" property="ColumnWidth" value="41.43" type="Double" /><column name="Alterable" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Alterable" property="Address" value="$K$3" type="String" /><column name="Alterable" property="ColumnWidth" value="10.86" type="Double" /><column name="CreateDate" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="CreateDate" property="Address" value="$L$3" type="String" /><column name="CreateDate" property="ColumnWidth" value="12.57" type="Double" /><column name="CreateDate" property="NumberFormat" value="m/d/yyyy" type="String" /><column name="ModifyDate" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ModifyDate" property="Address" value="$M$3" type="String" /><column name="ModifyDate" property="ColumnWidth" value="13.14" type="Double" /><column name="ModifyDate" property="NumberFormat" value="m/d/yyyy" type="String" /><column name="SortFields(1)" property="KeyfieldName" value="Schema" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="2" type="Double" /><column name="SortFields(2)" property="KeyfieldName" value="Name" type="String" /><column name="SortFields(2)" property="SortOn" value="0" type="Double" /><column name="SortFields(2)" property="Order" value="1" type="Double" /><column name="SortFields(2)" property="DataOption" value="2" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>')
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'tools01', N'RoleMembers', N'<table name="tools01.RoleMembers"><columnFormats><column name="" property="ListObjectName" value="RoleMembers" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="Type" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Type" property="Address" value="$C$4" type="String" /><column name="Type" property="ColumnWidth" value="13" type="Double" /><column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Name" property="Address" value="$D$4" type="String" /><column name="Name" property="ColumnWidth" value="22.57" type="Double" /><column name="SaveToDB_Developers" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SaveToDB_Developers" property="Address" value="$E$4" type="String" /><column name="SaveToDB_Developers" property="ColumnWidth" value="22.71" type="Double" /><column name="SaveToDB_Users" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SaveToDB_Users" property="Address" value="$F$4" type="String" /><column name="SaveToDB_Users" property="ColumnWidth" value="17.43" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="2" type="Double" /><column name="" property="PageSetup.Orientation" value="2" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>')
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'tools01', N'Permissions', N'<table name="tools01.Permissions"><columnFormats><column name="" property="ListObjectName" value="Permissions" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="PrincipalType" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="PrincipalType" property="Address" value="$C$4" type="String" /><column name="PrincipalType" property="ColumnWidth" value="14.71" type="Double" /><column name="Principal" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Principal" property="Address" value="$D$4" type="String" /><column name="Principal" property="ColumnWidth" value="22.57" type="Double" /><column name="Schema" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Schema" property="Address" value="$E$4" type="String" /><column name="Schema" property="ColumnWidth" value="9.43" type="Double" /><column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Name" property="Address" value="$F$4" type="String" /><column name="Name" property="ColumnWidth" value="41.57" type="Double" /><column name="Type" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Type" property="Address" value="$G$4" type="String" /><column name="Type" property="ColumnWidth" value="9.43" type="Double" /><column name="GrantType" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="GrantType" property="Address" value="$H$4" type="String" /><column name="GrantType" property="ColumnWidth" value="11.86" type="Double" /><column name="SELECT" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SELECT" property="Address" value="$I$4" type="String" /><column name="SELECT" property="ColumnWidth" value="8.71" type="Double" /><column name="INSERT" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="INSERT" property="Address" value="$J$4" type="String" /><column name="INSERT" property="ColumnWidth" value="8.71" type="Double" /><column name="UPDATE" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="UPDATE" property="Address" value="$K$4" type="String" /><column name="UPDATE" property="ColumnWidth" value="9.71" type="Double" /><column name="DELETE" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="DELETE" property="Address" value="$L$4" type="String" /><column name="DELETE" property="ColumnWidth" value="8.71" type="Double" /><column name="EXECUTE" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="EXECUTE" property="Address" value="$M$4" type="String" /><column name="EXECUTE" property="ColumnWidth" value="10.29" type="Double" /><column name="VIEW DEFINITION" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="VIEW DEFINITION" property="Address" value="$N$4" type="String" /><column name="VIEW DEFINITION" property="ColumnWidth" value="18.29" type="Double" /><column name="ALTER" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ALTER" property="Address" value="$O$4" type="String" /><column name="ALTER" property="ColumnWidth" value="7.86" type="Double" /><column name="CONTROL" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="CONTROL" property="Address" value="$P$4" type="String" /><column name="CONTROL" property="ColumnWidth" value="11" type="Double" /><column name="REFERENCES" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="REFERENCES" property="Address" value="$Q$4" type="String" /><column name="REFERENCES" property="ColumnWidth" value="13.43" type="Double" /><column name="TAKE OWNERSHIP" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="TAKE OWNERSHIP" property="Address" value="$R$4" type="String" /><column name="TAKE OWNERSHIP" property="ColumnWidth" value="18.57" type="Double" /><column name="IMPERSONATE" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="IMPERSONATE" property="Address" value="$S$4" type="String" /><column name="IMPERSONATE" property="ColumnWidth" value="15.57" type="Double" /><column name="CONNECT" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="CONNECT" property="Address" value="$T$4" type="String" /><column name="CONNECT" property="ColumnWidth" value="11.14" type="Double" /><column name="SELECT" property="FormatConditions(1).ColumnsCount" value="12" type="Double" /><column name="SELECT" property="FormatConditions(1).AppliesTo.Address" value="$I$4:$T$951" type="String" /><column name="SELECT" property="FormatConditions(1).Type" value="9" type="Double" /><column name="SELECT" property="FormatConditions(1).Priority" value="5" type="Double" /><column name="SELECT" property="FormatConditions(1).StopIfTrue" value="True" type="Boolean" /><column name="SELECT" property="FormatConditions(1).Formula1" value="=NOT(ISERROR(SEARCH(&quot;DENY &quot;;I4)))" type="String" /><column name="SELECT" property="FormatConditions(1).Text" value="DENY " type="String" /><column name="SELECT" property="FormatConditions(1).Font.Color" value="393372" type="Double" /><column name="SELECT" property="FormatConditions(1).Interior.Color" value="13551615" type="Double" /><column name="SELECT" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" /><column name="SELECT" property="FormatConditions(2).ColumnsCount" value="12" type="Double" /><column name="SELECT" property="FormatConditions(2).AppliesTo.Address" value="$I$4:$T$951" type="String" /><column name="SELECT" property="FormatConditions(2).Type" value="9" type="Double" /><column name="SELECT" property="FormatConditions(2).Priority" value="6" type="Double" /><column name="SELECT" property="FormatConditions(2).StopIfTrue" value="True" type="Boolean" /><column name="SELECT" property="FormatConditions(2).Formula1" value="=NOT(ISERROR(SEARCH(&quot;GRANT &quot;;I4)))" type="String" /><column name="SELECT" property="FormatConditions(2).Text" value="GRANT " type="String" /><column name="SELECT" property="FormatConditions(2).Font.Color" value="24832" type="Double" /><column name="SELECT" property="FormatConditions(2).Interior.Color" value="13561798" type="Double" /><column name="SELECT" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" /><column name="SELECT" property="FormatConditions(3).ColumnsCount" value="12" type="Double" /><column name="SELECT" property="FormatConditions(3).AppliesTo.Address" value="$I$4:$T$951" type="String" /><column name="SELECT" property="FormatConditions(3).Type" value="1" type="Double" /><column name="SELECT" property="FormatConditions(3).Priority" value="7" type="Double" /><column name="SELECT" property="FormatConditions(3).StopIfTrue" value="True" type="Boolean" /><column name="SELECT" property="FormatConditions(3).Formula1" value="=&quot;DENY&quot;" type="String" /><column name="SELECT" property="FormatConditions(3).Operator" value="3" type="Double" /><column name="SELECT" property="FormatConditions(3).Interior.Color" value="255" type="Double" /><column name="SELECT" property="FormatConditions(3).Interior.PatternThemeColor" value="-1" type="Double" /><column name="SELECT" property="FormatConditions(4).ColumnsCount" value="12" type="Double" /><column name="SELECT" property="FormatConditions(4).AppliesTo.Address" value="$I$4:$T$951" type="String" /><column name="SELECT" property="FormatConditions(4).Type" value="1" type="Double" /><column name="SELECT" property="FormatConditions(4).Priority" value="8" type="Double" /><column name="SELECT" property="FormatConditions(4).StopIfTrue" value="True" type="Boolean" /><column name="SELECT" property="FormatConditions(4).Formula1" value="=&quot;GRANT&quot;" type="String" /><column name="SELECT" property="FormatConditions(4).Operator" value="3" type="Double" /><column name="SELECT" property="FormatConditions(4).Interior.Color" value="5287936" type="Double" /><column name="SELECT" property="FormatConditions(4).Interior.PatternThemeColor" value="-1" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="2" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>')

print N'SaveToDB Framework tools has been added';
GO

print N'SaveToDB Framework has been installed';
GO
